package Locale::CLDR::Transformations::Any::My::My_fonipa;
# This file auto generated from Data\common\transforms\my-my_FONIPA.xml
#	on Sun  3 Dec 10:04:59 am GMT

use strict;
use warnings;
use version;

our $VERSION = version->declare('v0.34.4');

use v5.10.1;
use mro 'c3';
use utf8;
use if $^V ge v5.12.0, feature => 'unicode_strings';
use Types::Standard qw( Str Int HashRef ArrayRef CodeRef RegexpRef );
use Moo;

BEGIN {
	die "Transliteration requires Perl 5.18 or above"
		unless $^V ge v5.18.0;
}

no warnings 'experimental::regex_sets';
has 'transforms' => (
	is => 'ro',
	isa => ArrayRef,
	init_arg => undef,
	default => sub { [
		qr/(?^um:\G.)/,
		{
			type => 'transform',
			data => [
				{
					from => q(Any),
					to => q(NFC),
				},
			],
		},
		{
			type => 'conversion',
			data => [
				{
					before  => q(),
					after   => q(),
					replace => q(ါ),
					result  => q(ာ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(င်္),
					result  => q(င်),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(္),
					result  => q(်),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ဿ),
					result  => q(သ်သ),
					revisit => 0,
				},
			],
		},
		{
			type => 'transform',
			data => [
				{
					from => q(Any),
					to => q(Null),
				},
			],
		},
		{
			type => 'conversion',
			data => [
				{
					before  => q([^.$]),
					after   => q([က-ဪ ဿ ၌-၏ ၐ-ၕ]([့ျ-ှ])*[^်]),
					replace => q(),
					result  => q(\.),
					revisit => 0,
				},
			],
		},
		{
			type => 'transform',
			data => [
				{
					from => q(Any),
					to => q(Null),
				},
			],
		},
		{
			type => 'conversion',
			data => [
				{
					before  => q(),
					after   => q([$]),
					replace => q(([က-အဿ][ျ-ှ]*)),
					result  => q($1a̰),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(\.),
					replace => q(([က-အဿ][ျ-ှ]*)),
					result  => q($1ə),
					revisit => 0,
				},
			],
		},
		{
			type => 'transform',
			data => [
				{
					from => q(Any),
					to => q(Null),
				},
			],
		},
		{
			type => 'conversion',
			data => [
				{
					before  => q(်(း)?[က-ဪ]),
					after   => q(),
					replace => q(်),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(၎င်း),
					result  => q(lə\.ɡáʊ̯ɴ),
					revisit => 0,
				},
			],
		},
		{
			type => 'transform',
			data => [
				{
					from => q(Any),
					to => q(Null),
				},
			],
		},
		{
			type => 'conversion',
			data => [
				{
					before  => q(),
					after   => q(),
					replace => q(က်),
					result  => q(ɛʔ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ဂ်),
					result  => q(ɛʔ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(င့်),
					result  => q(ɪ̰ɴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(င်း),
					result  => q(ɪ́ɴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(င်),
					result  => q(ɪ̀ɴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(စ်),
					result  => q(ɪʔ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ဉ့်),
					result  => q(ɪ̰ɴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ဉ်း),
					result  => q(ɪ́ɴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ဉ်),
					result  => q(ɪ̀ɴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ည့်),
					result  => q(ɛ̰),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ည်း),
					result  => q(ɛ́),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ည်),
					result  => q(ɛ̀),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ဏ့်),
					result  => q(a̰ɴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ဏ်း),
					result  => q(áɴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ဏ်),
					result  => q(àɴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(တ်),
					result  => q(aʔ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(န့်),
					result  => q(a̰ɴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(န်း),
					result  => q(áɴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(န်),
					result  => q(àɴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ပ်),
					result  => q(aʔ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(မ့်),
					result  => q(a̰ɴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(မ်း),
					result  => q(áɴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(မ်),
					result  => q(àɴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ယ့်),
					result  => q(ɛ̰),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ယ်း),
					result  => q(ɛ́),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ယ်),
					result  => q(ɛ̀),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(သ်),
					result  => q(aʔ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ာဉ့်),
					result  => q(ɪ̰ɴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ာဉ်း),
					result  => q(ɪ́ɴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ာဉ်),
					result  => q(ɪ̀ɴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ာတ်),
					result  => q(aʔ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ာဏ့်),
					result  => q(a̰ɴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ာဏ်း),
					result  => q(áɴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ာဏ်),
					result  => q(àɴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ာန့်),
					result  => q(a̰ɴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ာန်း),
					result  => q(áɴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ာန်),
					result  => q(àɴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ာပ်),
					result  => q(aʔ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ာယ့်),
					result  => q(ɛ̰),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ာယ်း),
					result  => q(ɛ́),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ာယ်),
					result  => q(ɛ̀),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ာ့),
					result  => q(a̰),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ား),
					result  => q(á),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ာ),
					result  => q(à),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ိက်),
					result  => q(eɪ̯ʔ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ိစ်),
					result  => q(eɪ̯ʔ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ိတ်),
					result  => q(eɪ̯ʔ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ိန့်),
					result  => q(ḛɪ̯ɴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ိန်း),
					result  => q(éɪ̯ɴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ိန်),
					result  => q(èɪ̯ɴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ိပ်),
					result  => q(eɪ̯ʔ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ိမ့်),
					result  => q(ḛɪ̯ɴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ိမ်း),
					result  => q(éɪ̯ɴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ိမ်),
					result  => q(èɪ̯ɴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ိုက်),
					result  => q(aɪ̯ʔ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ိုင့်),
					result  => q(a̰ɪ̯ɴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ိုင်း),
					result  => q(áɪ̯ɴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ိုင်),
					result  => q(àɪ̯ɴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ိုဏ့်),
					result  => q(a̰ɪ̯ɴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ိုဏ်း),
					result  => q(áɪ̯ɴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ိုဏ်),
					result  => q(àɪ̯ɴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ိုယ့်),
					result  => q(o̰),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ိုယ်း),
					result  => q(ó),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ိုယ်),
					result  => q(ò),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ို့),
					result  => q(o̰),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ိုး),
					result  => q(ó),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ို),
					result  => q(ò),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ိံ့),
					result  => q(ḛɪ̯ɴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ိံး),
					result  => q(éɪ̯ɴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ိံ),
					result  => q(èɪ̯ɴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ိ),
					result  => q(ḭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ီ့),
					result  => q(ḭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ီး),
					result  => q(í),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ီ),
					result  => q(ì),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ုက်),
					result  => q(oʊ̯ʔ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ုဂ်),
					result  => q(oʊ̯ʔ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ုဏ့်),
					result  => q(o̰ʊ̯ɴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ုဏ်း),
					result  => q(óʊ̯ɴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ုဏ်),
					result  => q(òʊ̯ɴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ုတ်),
					result  => q(oʊ̯ʔ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ုန့်),
					result  => q(o̰ʊ̯ɴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ုန်း),
					result  => q(óʊ̯ɴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ုန်),
					result  => q(òʊ̯ɴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ုပ်),
					result  => q(oʊ̯ʔ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ုမ့်),
					result  => q(o̰ʊ̯ɴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ုမ်း),
					result  => q(óʊ̯ɴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ုမ်),
					result  => q(òʊ̯ɴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ုံ့),
					result  => q(o̰ʊ̯ɴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ုံး),
					result  => q(óʊ̯ɴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ုံ),
					result  => q(òʊ̯ɴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ု),
					result  => q(ṵ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ူ့),
					result  => q(ṵ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ူး),
					result  => q(ú),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ူ),
					result  => q(ù),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ေတ်),
					result  => q(ɪʔ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ောက်),
					result  => q(aʊ̯ʔ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ောင့်),
					result  => q(a̰ʊ̯ɴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ောင်း),
					result  => q(áʊ̯ɴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ောင်),
					result  => q(àʊ̯ɴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ော့),
					result  => q(ɔ̰),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ေား),
					result  => q(ɔ́),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ော်),
					result  => q(ɔ̀),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ော),
					result  => q(ɔ́),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ေ့),
					result  => q(ḛ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ေး),
					result  => q(é),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ေ),
					result  => q(è),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ဲ့),
					result  => q(ɛ̰),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ဲး),
					result  => q(ɛ́),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ဲ),
					result  => q(ɛ́),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ံ့),
					result  => q(a̰ɴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ံး),
					result  => q(áɴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ံ),
					result  => q(àɴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ွတ်),
					result  => q(ʊʔ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ွန့်),
					result  => q(ʊ̰ɴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ွန်း),
					result  => q(ʊ́ɴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ွန်),
					result  => q(ʊ̀ɴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ွပ်),
					result  => q(ʊʔ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ွမ့်),
					result  => q(ʊ̰ɴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ွမ်း),
					result  => q(ʊ́ɴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ွမ်),
					result  => q(ʊ̀ɴ),
					revisit => 0,
				},
			],
		},
		{
			type => 'transform',
			data => [
				{
					from => q(Any),
					to => q(Null),
				},
			],
		},
		{
			type => 'conversion',
			data => [
				{
					before  => q(),
					after   => q(),
					replace => q(ကျ),
					result  => q(t͡ɕ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ချ),
					result  => q(t͡ɕʰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ဂျ),
					result  => q(d͡ʑ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ဃျ),
					result  => q(d͡ʑ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ကြ),
					result  => q(t͡ɕ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ခြ),
					result  => q(t͡ɕʰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ဂြ),
					result  => q(d͡ʑ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ဃြ),
					result  => q(d͡ʑ),
					revisit => 0,
				},
				{
					before  => q(ယ),
					after   => q(),
					replace => q([ျြ]),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ွှ),
					result  => q(\u103E\u103D),
					revisit => 0,
				},
			],
		},
		{
			type => 'transform',
			data => [
				{
					from => q(Any),
					to => q(Null),
				},
			],
		},
		{
			type => 'conversion',
			data => [
				{
					before  => q(),
					after   => q(),
					replace => q(သျှ),
					result  => q(ʃ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(လျှ),
					result  => q(ʃ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ြှ),
					result  => q(\u103E\u103C),
					revisit => 0,
				},
			],
		},
		{
			type => 'transform',
			data => [
				{
					from => q(Any),
					to => q(Null),
				},
			],
		},
		{
			type => 'conversion',
			data => [
				{
					before  => q(),
					after   => q(),
					replace => q(ျှ),
					result  => q(\u103E\u103B),
					revisit => 0,
				},
			],
		},
		{
			type => 'transform',
			data => [
				{
					from => q(Any),
					to => q(Null),
				},
			],
		},
		{
			type => 'conversion',
			data => [
				{
					before  => q(),
					after   => q(),
					replace => q(ငှ),
					result  => q(ŋ̊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ဉှ),
					result  => q(ɲ̥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ညှ),
					result  => q(ɲ̥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ဏှ),
					result  => q(n̥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(နှ),
					result  => q(n̥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(မှ),
					result  => q(m̥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ယှ),
					result  => q(ʃ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ရှ),
					result  => q(ʃ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(လှ),
					result  => q(l̥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ဝှ),
					result  => q(w̥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ဠှ),
					result  => q(l̥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ှ),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(ွ),
					replace => q(ျ),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(ွ),
					replace => q(ြ),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ျ),
					result  => q(j),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ြ),
					result  => q(j),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ွ),
					result  => q(w),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(က),
					result  => q(k),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ခ),
					result  => q(kʰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ဂ),
					result  => q(ɡ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ဃ),
					result  => q(ɡ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(င),
					result  => q(ŋ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(စ),
					result  => q(s),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ဆ),
					result  => q(sʰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ဇ),
					result  => q(z),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ဈ),
					result  => q(z),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ဉ),
					result  => q(ɲ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ည),
					result  => q(ɲ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ဋ),
					result  => q(t),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ဌ),
					result  => q(tʰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ဍ),
					result  => q(d),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ဎ),
					result  => q(d),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ဏ),
					result  => q(n),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(တ),
					result  => q(t),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ထ),
					result  => q(tʰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ဒ),
					result  => q(d),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ဓ),
					result  => q(d),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(န),
					result  => q(n),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ပ),
					result  => q(p),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ဖ),
					result  => q(pʰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ဗ),
					result  => q(b),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ဘ),
					result  => q(b),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(မ),
					result  => q(m),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ယ),
					result  => q(j),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ရ),
					result  => q(j),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(လ်),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(လ),
					result  => q(l),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ဝ),
					result  => q(w),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(သ),
					result  => q(θ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ဟ),
					result  => q(h),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ဠ),
					result  => q(l),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(အ),
					result  => q(ʔ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ဣ့),
					result  => q(ʔḭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ဣး),
					result  => q(ʔí),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ဣ),
					result  => q(ʔḭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ဤ့),
					result  => q(ʔḭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ဤး),
					result  => q(ʔí),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ဤ),
					result  => q(ʔì),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ဥ့),
					result  => q(ʔṵ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ဥး),
					result  => q(ʔú),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ဥ),
					result  => q(ʔṵ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ဦ့),
					result  => q(ʔṵ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ဦး),
					result  => q(ʔú),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ဦ),
					result  => q(ʔù),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ဧ့),
					result  => q(ʔḛ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ဧး),
					result  => q(ʔé),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ဧ),
					result  => q(ʔè),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ဩ့),
					result  => q(ʔɔ̰),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ဩး),
					result  => q(ʔɔ́),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ဩ),
					result  => q(ʔɔ́),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ဪ့),
					result  => q(ʔɔ̰),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ဪး),
					result  => q(ʔɔ́),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ဪ),
					result  => q(ʔɔ̀),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(၌),
					result  => q(n̥aɪ̯ʔ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(၍),
					result  => q(jwḛ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(၏),
					result  => q(ʔḭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(်),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q([​-‍]),
					result  => q(),
					revisit => 0,
				},
			],
		},
		{
			type => 'transform',
			data => [
				{
					from => q(Any),
					to => q(NFC),
				},
			]
		},
	] },
);

no Moo;

1;

# vim: tabstop=4
