package Locale::CLDR::Transformations::Any::Fullwidth::Halfwidth;
# This file auto generated from Data\common\transforms\Fullwidth-Halfwidth.xml
#	on Sun  3 Dec 10:04:54 am GMT

use strict;
use warnings;
use version;

our $VERSION = version->declare('v0.34.4');

use v5.10.1;
use mro 'c3';
use utf8;
use if $^V ge v5.12.0, feature => 'unicode_strings';
use Types::Standard qw( Str Int HashRef ArrayRef CodeRef RegexpRef );
use Moo;

BEGIN {
	die "Transliteration requires Perl 5.18 or above"
		unless $^V ge v5.18.0;
}

no warnings 'experimental::regex_sets';
has 'transforms' => (
	is => 'ro',
	isa => ArrayRef,
	init_arg => undef,
	default => sub { [
		qr/(?^um:\G.)/,
		{
			type => 'transform',
			data => [
			],
		},
		{
			type => 'conversion',
			data => [
				{
					before  => q(),
					after   => q(),
					replace => q(ガ),
					result  => q(ｶﾞ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ギ),
					result  => q(ｷﾞ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(グ),
					result  => q(ｸﾞ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ゲ),
					result  => q(ｹﾞ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ゴ),
					result  => q(ｺﾞ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ザ),
					result  => q(ｻﾞ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ジ),
					result  => q(ｼﾞ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ズ),
					result  => q(ｽﾞ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ゼ),
					result  => q(ｾﾞ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ゾ),
					result  => q(ｿﾞ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ダ),
					result  => q(ﾀﾞ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ヂ),
					result  => q(ﾁﾞ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ヅ),
					result  => q(ﾂﾞ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(デ),
					result  => q(ﾃﾞ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ド),
					result  => q(ﾄﾞ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(バ),
					result  => q(ﾊﾞ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(パ),
					result  => q(ﾊﾟ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ビ),
					result  => q(ﾋﾞ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ピ),
					result  => q(ﾋﾟ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ブ),
					result  => q(ﾌﾞ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(プ),
					result  => q(ﾌﾟ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ベ),
					result  => q(ﾍﾞ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ペ),
					result  => q(ﾍﾟ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ボ),
					result  => q(ﾎﾞ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ポ),
					result  => q(ﾎﾟ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ヴ),
					result  => q(ｳﾞ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ヷ),
					result  => q(ﾜﾞ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ヺ),
					result  => q(ｦﾞ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(！),
					result  => q(\'),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(＂),
					result  => q(\'),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(＃),
					result  => q(\'),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(＄),
					result  => q(\'),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(％),
					result  => q(\'),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(＆),
					result  => q(\'),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(＇),
					result  => q('),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(（),
					result  => q(\'),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(）),
					result  => q(\'),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(＊),
					result  => q(\'),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(＋),
					result  => q(\'),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(，),
					result  => q(\'),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(－),
					result  => q(\'),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(．),
					result  => q(\'),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(／),
					result  => q(\'),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(０),
					result  => q(\'),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(１),
					result  => q(\'),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(２),
					result  => q(\'),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(３),
					result  => q(\'),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(４),
					result  => q(\'),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(５),
					result  => q(\'),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(６),
					result  => q(\'),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(７),
					result  => q(\'),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(８),
					result  => q(\'),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(９),
					result  => q(\'),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(：),
					result  => q(\'),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(；),
					result  => q(\'),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(＜),
					result  => q(\'),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(＝),
					result  => q(\'),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(＞),
					result  => q(\'),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(？),
					result  => q(\'),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(＠),
					result  => q(\'),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Ａ),
					result  => q(A),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Ｂ),
					result  => q(B),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Ｃ),
					result  => q(C),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Ｄ),
					result  => q(D),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Ｅ),
					result  => q(E),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Ｆ),
					result  => q(F),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Ｇ),
					result  => q(G),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Ｈ),
					result  => q(H),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Ｉ),
					result  => q(I),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Ｊ),
					result  => q(J),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Ｋ),
					result  => q(K),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Ｌ),
					result  => q(L),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Ｍ),
					result  => q(M),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Ｎ),
					result  => q(N),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Ｏ),
					result  => q(O),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Ｐ),
					result  => q(P),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Ｑ),
					result  => q(Q),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Ｒ),
					result  => q(R),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Ｓ),
					result  => q(S),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Ｔ),
					result  => q(T),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Ｕ),
					result  => q(U),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Ｖ),
					result  => q(V),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Ｗ),
					result  => q(W),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Ｘ),
					result  => q(X),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Ｙ),
					result  => q(Y),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Ｚ),
					result  => q(Z),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(［),
					result  => q(\'),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(］),
					result  => q(\'),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(＾),
					result  => q(\'),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(＿),
					result  => q(\'),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(｀),
					result  => q(\'),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ａ),
					result  => q(a),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ｂ),
					result  => q(b),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ｃ),
					result  => q(c),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ｄ),
					result  => q(d),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ｅ),
					result  => q(e),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ｆ),
					result  => q(f),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ｇ),
					result  => q(g),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ｈ),
					result  => q(h),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ｉ),
					result  => q(i),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ｊ),
					result  => q(j),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ｋ),
					result  => q(k),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ｌ),
					result  => q(l),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ｍ),
					result  => q(m),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ｎ),
					result  => q(n),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ｏ),
					result  => q(o),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ｐ),
					result  => q(p),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ｑ),
					result  => q(q),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ｒ),
					result  => q(r),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ｓ),
					result  => q(s),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ｔ),
					result  => q(t),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ｕ),
					result  => q(u),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ｖ),
					result  => q(v),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ｗ),
					result  => q(w),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ｘ),
					result  => q(x),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ｙ),
					result  => q(y),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ｚ),
					result  => q(z),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(｛),
					result  => q(\'),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(｜),
					result  => q(\'),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(｝),
					result  => q(\'),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(～),
					result  => q(\'),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(。),
					result  => q(｡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(「),
					result  => q(｢),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(」),
					result  => q(｣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(、),
					result  => q(､),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(・),
					result  => q(･),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ヲ),
					result  => q(ｦ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ァ),
					result  => q(ｧ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ィ),
					result  => q(ｨ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ゥ),
					result  => q(ｩ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ェ),
					result  => q(ｪ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ォ),
					result  => q(ｫ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ャ),
					result  => q(ｬ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ュ),
					result  => q(ｭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ョ),
					result  => q(ｮ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ッ),
					result  => q(ｯ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ー),
					result  => q(ｰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ア),
					result  => q(ｱ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(イ),
					result  => q(ｲ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ウ),
					result  => q(ｳ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(エ),
					result  => q(ｴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(オ),
					result  => q(ｵ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(カ),
					result  => q(ｶ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(キ),
					result  => q(ｷ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ク),
					result  => q(ｸ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ケ),
					result  => q(ｹ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(コ),
					result  => q(ｺ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(サ),
					result  => q(ｻ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(シ),
					result  => q(ｼ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ス),
					result  => q(ｽ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(セ),
					result  => q(ｾ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ソ),
					result  => q(ｿ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(タ),
					result  => q(ﾀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(チ),
					result  => q(ﾁ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ツ),
					result  => q(ﾂ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(テ),
					result  => q(ﾃ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ト),
					result  => q(ﾄ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ナ),
					result  => q(ﾅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ニ),
					result  => q(ﾆ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ヌ),
					result  => q(ﾇ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ネ),
					result  => q(ﾈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ノ),
					result  => q(ﾉ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ハ),
					result  => q(ﾊ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ヒ),
					result  => q(ﾋ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(フ),
					result  => q(ﾌ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ヘ),
					result  => q(ﾍ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ホ),
					result  => q(ﾎ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(マ),
					result  => q(ﾏ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ミ),
					result  => q(ﾐ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ム),
					result  => q(ﾑ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(メ),
					result  => q(ﾒ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(モ),
					result  => q(ﾓ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ヤ),
					result  => q(ﾔ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ユ),
					result  => q(ﾕ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ヨ),
					result  => q(ﾖ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ラ),
					result  => q(ﾗ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(リ),
					result  => q(ﾘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ル),
					result  => q(ﾙ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(レ),
					result  => q(ﾚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ロ),
					result  => q(ﾛ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ワ),
					result  => q(ﾜ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ン),
					result  => q(ﾝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(゙),
					result  => q(ﾞ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(゚),
					result  => q(ﾟ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᅠ),
					result  => q(\uFFA0),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᄀ),
					result  => q(ﾡ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᄁ),
					result  => q(ﾢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᆪ),
					result  => q(ﾣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᄂ),
					result  => q(ﾤ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᆬ),
					result  => q(ﾥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᆭ),
					result  => q(ﾦ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᄃ),
					result  => q(ﾧ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᄄ),
					result  => q(ﾨ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᄅ),
					result  => q(ﾩ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᆰ),
					result  => q(ﾪ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᆱ),
					result  => q(ﾫ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᆲ),
					result  => q(ﾬ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᆳ),
					result  => q(ﾭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᆴ),
					result  => q(ﾮ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᆵ),
					result  => q(ﾯ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᄚ),
					result  => q(ﾰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᄆ),
					result  => q(ﾱ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᄇ),
					result  => q(ﾲ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᄈ),
					result  => q(ﾳ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᄡ),
					result  => q(ﾴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᄉ),
					result  => q(ﾵ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᄊ),
					result  => q(ﾶ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᄋ),
					result  => q(ﾷ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᄌ),
					result  => q(ﾸ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᄍ),
					result  => q(ﾹ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᄎ),
					result  => q(ﾺ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᄏ),
					result  => q(ﾻ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᄐ),
					result  => q(ﾼ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᄑ),
					result  => q(ﾽ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᄒ),
					result  => q(ﾾ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᅡ),
					result  => q(ￂ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᅢ),
					result  => q(ￃ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᅣ),
					result  => q(ￄ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᅤ),
					result  => q(ￅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᅥ),
					result  => q(ￆ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᅦ),
					result  => q(ￇ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᅧ),
					result  => q(ￊ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᅨ),
					result  => q(ￋ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᅩ),
					result  => q(ￌ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᅪ),
					result  => q(ￍ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᅫ),
					result  => q(ￎ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᅬ),
					result  => q(ￏ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᅭ),
					result  => q(ￒ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᅮ),
					result  => q(ￓ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᅯ),
					result  => q(ￔ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᅰ),
					result  => q(ￕ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᅱ),
					result  => q(ￖ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᅲ),
					result  => q(ￗ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᅳ),
					result  => q(ￚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᅴ),
					result  => q(ￛ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ᅵ),
					result  => q(ￜ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(￠),
					result  => q(\'),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(￡),
					result  => q(\'),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(￢),
					result  => q(\'),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(￣),
					result  => q(\'),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(　),
					result  => q(\'),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(￤),
					result  => q(\'),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(￥),
					result  => q(\'),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(￦),
					result  => q(₩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(│),
					result  => q(￨),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\'),
					result  => q(\'),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(↑),
					result  => q(￪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\'),
					result  => q(\'),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(↓),
					result  => q(￬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(■),
					result  => q(￭),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(○),
					result  => q(￮),
					revisit => 0,
				},
			]
		},
	] },
);

no Moo;

1;

# vim: tabstop=4
