package Locale::CLDR::Transformations::Any::Latn::Thaa;
# This file auto generated from Data\common\transforms\Thaana-Latin.xml
#	on Sun  3 Dec 10:04:57 am GMT

use strict;
use warnings;
use version;

our $VERSION = version->declare('v0.34.4');

use v5.10.1;
use mro 'c3';
use utf8;
use if $^V ge v5.12.0, feature => 'unicode_strings';
use Types::Standard qw( Str Int HashRef ArrayRef CodeRef RegexpRef );
use Moo;

BEGIN {
	die "Transliteration requires Perl 5.18 or above"
		unless $^V ge v5.18.0;
}

no warnings 'experimental::regex_sets';
has 'transforms' => (
	is => 'ro',
	isa => ArrayRef,
	init_arg => undef,
	default => sub { [
		qr/(?^um:\G.)/,
		{
			type => 'transform',
			data => [
			],
		},
		{
			type => 'conversion',
			data => [
				{
					before  => q(),
					after   => q(),
					replace => q(tta),
					result  => q(ޘަ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ḥa),
					result  => q(ޙަ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(kha),
					result  => q(ޚަ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(dha),
					result  => q(ޛަ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ṣa),
					result  => q(ޞަ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ḏa),
					result  => q(ޟަ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(t̤a),
					result  => q(ޠަ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ʿa),
					result  => q(ޢަ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ǧa),
					result  => q(ޣަ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(qa),
					result  => q(ޤަ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ha),
					result  => q(ހަ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ša),
					result  => q(ށަ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(na),
					result  => q(ނަ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ra),
					result  => q(ރަ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ba),
					result  => q(ބަ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ḷa),
					result  => q(ޅަ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ka),
					result  => q(ކަ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(‘a),
					result  => q(އަ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(va),
					result  => q(ވަ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ma),
					result  => q(މަ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(fa),
					result  => q(ފަ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(da),
					result  => q(ދަ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ta),
					result  => q(ތަ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(la),
					result  => q(ލަ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ga),
					result  => q(ގަ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ña),
					result  => q(ޏަ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(sa),
					result  => q(ސަ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ḍa),
					result  => q(ޑަ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ja),
					result  => q(ޖަ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ča),
					result  => q(ޗަ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(za),
					result  => q(ޒަ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ṭa),
					result  => q(ޓަ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(pa),
					result  => q(ޕަ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ya),
					result  => q(ޔަ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ttā),
					result  => q(ޘާ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ḥā),
					result  => q(ޙާ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(khā),
					result  => q(ޚާ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(dhā),
					result  => q(ޛާ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ṣā),
					result  => q(ޞާ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ḏā),
					result  => q(ޟާ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(t̤ā),
					result  => q(ޠާ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ʿā),
					result  => q(ޢާ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ǧā),
					result  => q(ޣާ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(qā),
					result  => q(ޤާ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(hā),
					result  => q(ހާ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(šā),
					result  => q(ށާ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(nā),
					result  => q(ނާ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(rā),
					result  => q(ރާ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(bā),
					result  => q(ބާ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ḷā),
					result  => q(ޅާ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(kā),
					result  => q(ކާ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(‘ā),
					result  => q(އާ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(vā),
					result  => q(ވާ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(mā),
					result  => q(މާ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(fā),
					result  => q(ފާ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(dā),
					result  => q(ދާ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(tā),
					result  => q(ތާ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(lā),
					result  => q(ލާ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(gā),
					result  => q(ގާ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ñā),
					result  => q(ޏާ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(sā),
					result  => q(ސާ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ḍā),
					result  => q(ޑާ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(jā),
					result  => q(ޖާ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(čā),
					result  => q(ޗާ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(zā),
					result  => q(ޒާ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ṭā),
					result  => q(ޓާ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(pā),
					result  => q(ޕާ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(yā),
					result  => q(ޔާ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(tti),
					result  => q(ޘި),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ḥi),
					result  => q(ޙި),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(khi),
					result  => q(ޚި),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(dhi),
					result  => q(ޛި),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ṣi),
					result  => q(ޞި),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ḏi),
					result  => q(ޟި),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(t̤i),
					result  => q(ޠި),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ʿi),
					result  => q(ޢި),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ǧi),
					result  => q(ޣި),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(qi),
					result  => q(ޤި),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(hi),
					result  => q(ހި),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ši),
					result  => q(ށި),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ni),
					result  => q(ނި),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ri),
					result  => q(ރި),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(bi),
					result  => q(ބި),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ḷi),
					result  => q(ޅި),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ki),
					result  => q(ކި),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(‘i),
					result  => q(އި),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(vi),
					result  => q(ވި),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(mi),
					result  => q(މި),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(fi),
					result  => q(ފި),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(di),
					result  => q(ދި),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ti),
					result  => q(ތި),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(li),
					result  => q(ލި),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(gi),
					result  => q(ގި),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ñi),
					result  => q(ޏި),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(si),
					result  => q(ސި),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ḍi),
					result  => q(ޑި),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ji),
					result  => q(ޖި),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(či),
					result  => q(ޗި),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(zi),
					result  => q(ޒި),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ṭi),
					result  => q(ޓި),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(pi),
					result  => q(ޕި),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(yi),
					result  => q(ޔި),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ttī),
					result  => q(ޘީ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ḥī),
					result  => q(ޙީ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(khī),
					result  => q(ޚީ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(dhī),
					result  => q(ޛީ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ṣī),
					result  => q(ޞީ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ḏī),
					result  => q(ޟީ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(t̤ī),
					result  => q(ޠީ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ʿī),
					result  => q(ޢީ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ǧī),
					result  => q(ޣީ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(qī),
					result  => q(ޤީ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(hī),
					result  => q(ހީ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(šī),
					result  => q(ށީ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(nī),
					result  => q(ނީ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(rī),
					result  => q(ރީ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(bī),
					result  => q(ބީ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ḷī),
					result  => q(ޅީ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(kī),
					result  => q(ކީ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(‘ī),
					result  => q(އީ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(vī),
					result  => q(ވީ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(mī),
					result  => q(މީ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(fī),
					result  => q(ފީ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(dī),
					result  => q(ދީ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(tī),
					result  => q(ތީ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(lī),
					result  => q(ލީ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(gī),
					result  => q(ގީ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ñī),
					result  => q(ޏީ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(sī),
					result  => q(ސީ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ḍī),
					result  => q(ޑީ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(jī),
					result  => q(ޖީ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(čī),
					result  => q(ޗީ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(zī),
					result  => q(ޒީ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ṭī),
					result  => q(ޓީ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(pī),
					result  => q(ޕީ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(yī),
					result  => q(ޔީ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ttu),
					result  => q(ޘު),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ḥu),
					result  => q(ޙު),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(khu),
					result  => q(ޚު),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(dhu),
					result  => q(ޛު),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ṣu),
					result  => q(ޞު),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ḏu),
					result  => q(ޟު),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(t̤u),
					result  => q(ޠު),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ʿu),
					result  => q(ޢު),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ǧu),
					result  => q(ޣު),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(qu),
					result  => q(ޤު),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(hu),
					result  => q(ހު),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(šu),
					result  => q(ށު),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(nu),
					result  => q(ނު),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ru),
					result  => q(ރު),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(bu),
					result  => q(ބު),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ḷu),
					result  => q(ޅު),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ku),
					result  => q(ކު),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(‘u),
					result  => q(އު),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(vu),
					result  => q(ވު),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(mu),
					result  => q(މު),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(fu),
					result  => q(ފު),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(du),
					result  => q(ދު),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(tu),
					result  => q(ތު),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(lu),
					result  => q(ލު),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(gu),
					result  => q(ގު),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ñu),
					result  => q(ޏު),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(su),
					result  => q(ސު),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ḍu),
					result  => q(ޑު),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ju),
					result  => q(ޖު),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ču),
					result  => q(ޗު),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(zu),
					result  => q(ޒު),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ṭu),
					result  => q(ޓު),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(pu),
					result  => q(ޕު),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(yu),
					result  => q(ޔު),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ttū),
					result  => q(ޘޫ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ḥū),
					result  => q(ޙޫ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(khū),
					result  => q(ޚޫ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(dhū),
					result  => q(ޛޫ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ṣū),
					result  => q(ޞޫ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ḏū),
					result  => q(ޟޫ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(t̤ū),
					result  => q(ޠޫ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ʿū),
					result  => q(ޢޫ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ǧū),
					result  => q(ޣޫ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(qū),
					result  => q(ޤޫ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(hū),
					result  => q(ހޫ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(šū),
					result  => q(ށޫ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(nū),
					result  => q(ނޫ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(rū),
					result  => q(ރޫ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(bū),
					result  => q(ބޫ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ḷū),
					result  => q(ޅޫ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(kū),
					result  => q(ކޫ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(‘ū),
					result  => q(އޫ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(vū),
					result  => q(ވޫ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(mū),
					result  => q(މޫ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(fū),
					result  => q(ފޫ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(dū),
					result  => q(ދޫ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(tū),
					result  => q(ތޫ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(lū),
					result  => q(ލޫ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(gū),
					result  => q(ގޫ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ñū),
					result  => q(ޏޫ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(sū),
					result  => q(ސޫ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ḍū),
					result  => q(ޑޫ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(jū),
					result  => q(ޖޫ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(čū),
					result  => q(ޗޫ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(zū),
					result  => q(ޒޫ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ṭū),
					result  => q(ޓޫ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(pū),
					result  => q(ޕޫ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(yū),
					result  => q(ޔޫ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(tte),
					result  => q(ޘެ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ḥe),
					result  => q(ޙެ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(khe),
					result  => q(ޚެ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(dhe),
					result  => q(ޛެ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ṣe),
					result  => q(ޞެ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ḏe),
					result  => q(ޟެ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(t̤e),
					result  => q(ޠެ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ʿe),
					result  => q(ޢެ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ǧe),
					result  => q(ޣެ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(qe),
					result  => q(ޤެ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(he),
					result  => q(ހެ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(še),
					result  => q(ށެ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ne),
					result  => q(ނެ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(re),
					result  => q(ރެ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(be),
					result  => q(ބެ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ḷe),
					result  => q(ޅެ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ke),
					result  => q(ކެ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(‘e),
					result  => q(އެ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ve),
					result  => q(ވެ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(me),
					result  => q(މެ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(fe),
					result  => q(ފެ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(de),
					result  => q(ދެ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(te),
					result  => q(ތެ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(le),
					result  => q(ލެ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ge),
					result  => q(ގެ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ñe),
					result  => q(ޏެ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(se),
					result  => q(ސެ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ḍe),
					result  => q(ޑެ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(je),
					result  => q(ޖެ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(če),
					result  => q(ޗެ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ze),
					result  => q(ޒެ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ṭe),
					result  => q(ޓެ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(pe),
					result  => q(ޕެ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ye),
					result  => q(ޔެ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ttē),
					result  => q(ޘޭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ḥē),
					result  => q(ޙޭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(khē),
					result  => q(ޚޭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(dhē),
					result  => q(ޛޭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ṣē),
					result  => q(ޞޭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ḏē),
					result  => q(ޟޭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(t̤ē),
					result  => q(ޠޭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ʿē),
					result  => q(ޢޭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ǧē),
					result  => q(ޣޭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(qē),
					result  => q(ޤޭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(hē),
					result  => q(ހޭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(šē),
					result  => q(ށޭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(nē),
					result  => q(ނޭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(rē),
					result  => q(ރޭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(bē),
					result  => q(ބޭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ḷē),
					result  => q(ޅޭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(kē),
					result  => q(ކޭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(‘ē),
					result  => q(އޭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(vē),
					result  => q(ވޭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(mē),
					result  => q(މޭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(fē),
					result  => q(ފޭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(dē),
					result  => q(ދޭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(tē),
					result  => q(ތޭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(lē),
					result  => q(ލޭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(gē),
					result  => q(ގޭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ñē),
					result  => q(ޏޭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(sē),
					result  => q(ސޭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ḍē),
					result  => q(ޑޭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(jē),
					result  => q(ޖޭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(čē),
					result  => q(ޗޭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(zē),
					result  => q(ޒޭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ṭē),
					result  => q(ޓޭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(pē),
					result  => q(ޕޭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(yē),
					result  => q(ޔޭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(tto),
					result  => q(ޘޮ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ḥo),
					result  => q(ޙޮ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(kho),
					result  => q(ޚޮ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(dho),
					result  => q(ޛޮ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ṣo),
					result  => q(ޞޮ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ḏo),
					result  => q(ޟޮ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(t̤o),
					result  => q(ޠޮ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ʿo),
					result  => q(ޢޮ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ǧo),
					result  => q(ޣޮ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(qo),
					result  => q(ޤޮ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ho),
					result  => q(ހޮ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(šo),
					result  => q(ށޮ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(no),
					result  => q(ނޮ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ro),
					result  => q(ރޮ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(bo),
					result  => q(ބޮ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ḷo),
					result  => q(ޅޮ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ko),
					result  => q(ކޮ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(‘o),
					result  => q(އޮ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(vo),
					result  => q(ވޮ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(mo),
					result  => q(މޮ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(fo),
					result  => q(ފޮ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(do),
					result  => q(ދޮ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(to),
					result  => q(ތޮ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(lo),
					result  => q(ލޮ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(go),
					result  => q(ގޮ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ño),
					result  => q(ޏޮ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(so),
					result  => q(ސޮ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ḍo),
					result  => q(ޑޮ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(jo),
					result  => q(ޖޮ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(čo),
					result  => q(ޗޮ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(zo),
					result  => q(ޒޮ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ṭo),
					result  => q(ޓޮ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(po),
					result  => q(ޕޮ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(yo),
					result  => q(ޔޮ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ttō),
					result  => q(ޘޯ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ḥō),
					result  => q(ޙޯ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(khō),
					result  => q(ޚޯ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(dhō),
					result  => q(ޛޯ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ṣō),
					result  => q(ޞޯ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ḏō),
					result  => q(ޟޯ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(t̤ō),
					result  => q(ޠޯ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ʿō),
					result  => q(ޢޯ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ǧō),
					result  => q(ޣޯ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(qō),
					result  => q(ޤޯ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(hō),
					result  => q(ހޯ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(šō),
					result  => q(ށޯ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(nō),
					result  => q(ނޯ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(rō),
					result  => q(ރޯ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(bō),
					result  => q(ބޯ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ḷō),
					result  => q(ޅޯ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(kō),
					result  => q(ކޯ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(‘ō),
					result  => q(އޯ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(vō),
					result  => q(ވޯ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(mō),
					result  => q(މޯ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(fō),
					result  => q(ފޯ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(dō),
					result  => q(ދޯ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(tō),
					result  => q(ތޯ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(lō),
					result  => q(ލޯ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(gō),
					result  => q(ގޯ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ñō),
					result  => q(ޏޯ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(sō),
					result  => q(ސޯ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ḍō),
					result  => q(ޑޯ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(jō),
					result  => q(ޖޯ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(čō),
					result  => q(ޗޯ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(zō),
					result  => q(ޒޯ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ṭō),
					result  => q(ޓޯ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(pō),
					result  => q(ޕޯ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(yō),
					result  => q(ޔޯ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(tt),
					result  => q(ޘް),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ḥ),
					result  => q(ޙް),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(kh),
					result  => q(ޚް),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(dh),
					result  => q(ޛް),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ṣ),
					result  => q(ޞް),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ḏ),
					result  => q(ޟް),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(t̤),
					result  => q(ޠް),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ʿ),
					result  => q(ޢް),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ǧ),
					result  => q(ޣް),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(q),
					result  => q(ޤް),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(h),
					result  => q(ހް),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(š),
					result  => q(ށް),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(n),
					result  => q(ން),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(r),
					result  => q(ރް),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(b),
					result  => q(ބް),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ḷ),
					result  => q(ޅް),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(k),
					result  => q(ކް),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(‘),
					result  => q(އް),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(v),
					result  => q(ވް),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(m),
					result  => q(މް),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(f),
					result  => q(ފް),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(d),
					result  => q(ދް),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(t),
					result  => q(ތް),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(l),
					result  => q(ލް),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(g),
					result  => q(ގް),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ñ),
					result  => q(ޏް),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(s),
					result  => q(ސް),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ḍ),
					result  => q(ޑް),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(j),
					result  => q(ޖް),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(č),
					result  => q(ޗް),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(z),
					result  => q(ޒް),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ṭ),
					result  => q(ޓް),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(p),
					result  => q(ޕް),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(y),
					result  => q(ޔް),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(a),
					result  => q(ަ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ā),
					result  => q(ާ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(i),
					result  => q(ި),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ī),
					result  => q(ީ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(u),
					result  => q(ު),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ū),
					result  => q(ޫ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(e),
					result  => q(ެ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ē),
					result  => q(ޭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(o),
					result  => q(ޮ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ō),
					result  => q(ޯ),
					revisit => 0,
				},
			]
		},
	] },
);

no Moo;

1;

# vim: tabstop=4
