package Locale::CLDR::Transformations::Any::Latn::Bopo;
# This file auto generated from Data\common\transforms\Latin-Bopomofo.xml
#	on Sun  3 Dec 10:04:55 am GMT

use strict;
use warnings;
use version;

our $VERSION = version->declare('v0.34.4');

use v5.10.1;
use mro 'c3';
use utf8;
use if $^V ge v5.12.0, feature => 'unicode_strings';
use Types::Standard qw( Str Int HashRef ArrayRef CodeRef RegexpRef );
use Moo;

BEGIN {
	die "Transliteration requires Perl 5.18 or above"
		unless $^V ge v5.18.0;
}

no warnings 'experimental::regex_sets';
has 'transforms' => (
	is => 'ro',
	isa => ArrayRef,
	init_arg => undef,
	default => sub { [
		qr/(?^umi:\G(?:[\p{Latin}\p{Mn}]|[1-5]))/,
		{
			type => 'transform',
			data => [
			],
		},
		{
			type => 'conversion',
			data => [
				{
					before  => q([ln]),
					after   => q(),
					replace => q(v),
					result  => q(ü),
					revisit => 0,
				},
			],
		},
		{
			type => 'transform',
			data => [
				{
					from => q(Latin),
					to => q(NumericPinyin),
				},
			],
		},
		{
			type => 'conversion',
			data => [
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(bang),
					result  => q(ㄅㄤ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(bang),
					result  => q(ㄅㄤ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(beng),
					result  => q(ㄅㄥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(beng),
					result  => q(ㄅㄥ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(biao),
					result  => q(ㄅㄧㄠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(biao),
					result  => q(ㄅㄧㄠ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(bian),
					result  => q(ㄅㄧㄢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(bian),
					result  => q(ㄅㄧㄢ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(bing),
					result  => q(ㄅㄧㄥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(bing),
					result  => q(ㄅㄧㄥ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(bai),
					result  => q(ㄅㄞ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(bai),
					result  => q(ㄅㄞ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(bei),
					result  => q(ㄅㄟ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(bei),
					result  => q(ㄅㄟ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(bao),
					result  => q(ㄅㄠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(bao),
					result  => q(ㄅㄠ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(ban),
					result  => q(ㄅㄢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ban),
					result  => q(ㄅㄢ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(ben),
					result  => q(ㄅㄣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ben),
					result  => q(ㄅㄣ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(bie),
					result  => q(ㄅㄧㄝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(bie),
					result  => q(ㄅㄧㄝ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(bin),
					result  => q(ㄅㄧㄣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(bin),
					result  => q(ㄅㄧㄣ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(bun),
					result  => q(ㄅㄨㄣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(bun),
					result  => q(ㄅㄨㄣ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(ba),
					result  => q(ㄅㄚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ba),
					result  => q(ㄅㄚ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(bo),
					result  => q(ㄅㄛ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(bo),
					result  => q(ㄅㄛ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(bi),
					result  => q(ㄅㄧ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(bi),
					result  => q(ㄅㄧ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(bu),
					result  => q(ㄅㄨ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(bu),
					result  => q(ㄅㄨ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(pang),
					result  => q(ㄆㄤ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(pang),
					result  => q(ㄆㄤ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(peng),
					result  => q(ㄆㄥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(peng),
					result  => q(ㄆㄥ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(piao),
					result  => q(ㄆㄧㄠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(piao),
					result  => q(ㄆㄧㄠ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(pian),
					result  => q(ㄆㄧㄢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(pian),
					result  => q(ㄆㄧㄢ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(ping),
					result  => q(ㄆㄧㄥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ping),
					result  => q(ㄆㄧㄥ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(pai),
					result  => q(ㄆㄞ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(pai),
					result  => q(ㄆㄞ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(pei),
					result  => q(ㄆㄟ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(pei),
					result  => q(ㄆㄟ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(pao),
					result  => q(ㄆㄠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(pao),
					result  => q(ㄆㄠ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(pou),
					result  => q(ㄆㄡ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(pou),
					result  => q(ㄆㄡ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(pan),
					result  => q(ㄆㄢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(pan),
					result  => q(ㄆㄢ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(pen),
					result  => q(ㄆㄣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(pen),
					result  => q(ㄆㄣ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(pie),
					result  => q(ㄆㄧㄝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(pie),
					result  => q(ㄆㄧㄝ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(pin),
					result  => q(ㄆㄧㄣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(pin),
					result  => q(ㄆㄧㄣ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(pa),
					result  => q(ㄆㄚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(pa),
					result  => q(ㄆㄚ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(po),
					result  => q(ㄆㄛ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(po),
					result  => q(ㄆㄛ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(pi),
					result  => q(ㄆㄧ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(pi),
					result  => q(ㄆㄧ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(pu),
					result  => q(ㄆㄨ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(pu),
					result  => q(ㄆㄨ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(mang),
					result  => q(ㄇㄤ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(mang),
					result  => q(ㄇㄤ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(meng),
					result  => q(ㄇㄥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(meng),
					result  => q(ㄇㄥ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(miao),
					result  => q(ㄇㄧㄠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(miao),
					result  => q(ㄇㄧㄠ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(mian),
					result  => q(ㄇㄧㄢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(mian),
					result  => q(ㄇㄧㄢ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(ming),
					result  => q(ㄇㄧㄥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ming),
					result  => q(ㄇㄧㄥ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(mai),
					result  => q(ㄇㄞ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(mai),
					result  => q(ㄇㄞ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(mei),
					result  => q(ㄇㄟ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(mei),
					result  => q(ㄇㄟ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(mao),
					result  => q(ㄇㄠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(mao),
					result  => q(ㄇㄠ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(mou),
					result  => q(ㄇㄡ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(mou),
					result  => q(ㄇㄡ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(man),
					result  => q(ㄇㄢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(man),
					result  => q(ㄇㄢ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(men),
					result  => q(ㄇㄣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(men),
					result  => q(ㄇㄣ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(mie),
					result  => q(ㄇㄧㄝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(mie),
					result  => q(ㄇㄧㄝ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(miu),
					result  => q(ㄇㄧㄡ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(miu),
					result  => q(ㄇㄧㄡ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(min),
					result  => q(ㄇㄧㄣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(min),
					result  => q(ㄇㄧㄣ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(ma),
					result  => q(ㄇㄚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ma),
					result  => q(ㄇㄚ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(mo),
					result  => q(ㄇㄛ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(mo),
					result  => q(ㄇㄛ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(me),
					result  => q(ㄇㄜ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(me),
					result  => q(ㄇㄜ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(mi),
					result  => q(ㄇㄧ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(mi),
					result  => q(ㄇㄧ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(mu),
					result  => q(ㄇㄨ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(mu),
					result  => q(ㄇㄨ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(fang),
					result  => q(ㄈㄤ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(fang),
					result  => q(ㄈㄤ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(feng),
					result  => q(ㄈㄥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(feng),
					result  => q(ㄈㄥ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(fiao),
					result  => q(ㄈㄧㄠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(fiao),
					result  => q(ㄈㄧㄠ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(fei),
					result  => q(ㄈㄟ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(fei),
					result  => q(ㄈㄟ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(fou),
					result  => q(ㄈㄡ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(fou),
					result  => q(ㄈㄡ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(fan),
					result  => q(ㄈㄢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(fan),
					result  => q(ㄈㄢ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(fen),
					result  => q(ㄈㄣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(fen),
					result  => q(ㄈㄣ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(fa),
					result  => q(ㄈㄚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(fa),
					result  => q(ㄈㄚ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(fo),
					result  => q(ㄈㄛ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(fo),
					result  => q(ㄈㄛ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(fu),
					result  => q(ㄈㄨ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(fu),
					result  => q(ㄈㄨ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(diang),
					result  => q(ㄉㄧㄤ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(diang),
					result  => q(ㄉㄧㄤ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(dang),
					result  => q(ㄉㄤ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(dang),
					result  => q(ㄉㄤ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(deng),
					result  => q(ㄉㄥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(deng),
					result  => q(ㄉㄥ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(diao),
					result  => q(ㄉㄧㄠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(diao),
					result  => q(ㄉㄧㄠ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(dian),
					result  => q(ㄉㄧㄢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(dian),
					result  => q(ㄉㄧㄢ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(ding),
					result  => q(ㄉㄧㄥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ding),
					result  => q(ㄉㄧㄥ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(duan),
					result  => q(ㄉㄨㄢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(duan),
					result  => q(ㄉㄨㄢ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(dong),
					result  => q(ㄉㄨㄥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(dong),
					result  => q(ㄉㄨㄥ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(dai),
					result  => q(ㄉㄞ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(dai),
					result  => q(ㄉㄞ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(dei),
					result  => q(ㄉㄟ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(dei),
					result  => q(ㄉㄟ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(dao),
					result  => q(ㄉㄠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(dao),
					result  => q(ㄉㄠ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(dou),
					result  => q(ㄉㄡ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(dou),
					result  => q(ㄉㄡ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(dan),
					result  => q(ㄉㄢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(dan),
					result  => q(ㄉㄢ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(den),
					result  => q(ㄉㄣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(den),
					result  => q(ㄉㄣ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(dia),
					result  => q(ㄉㄧㄚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(dia),
					result  => q(ㄉㄧㄚ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(die),
					result  => q(ㄉㄧㄝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(die),
					result  => q(ㄉㄧㄝ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(diu),
					result  => q(ㄉㄧㄡ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(diu),
					result  => q(ㄉㄧㄡ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(din),
					result  => q(ㄉㄧㄣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(din),
					result  => q(ㄉㄧㄣ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(duo),
					result  => q(ㄉㄨㄛ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(duo),
					result  => q(ㄉㄨㄛ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(dui),
					result  => q(ㄉㄨㄟ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(dui),
					result  => q(ㄉㄨㄟ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(dun),
					result  => q(ㄉㄨㄣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(dun),
					result  => q(ㄉㄨㄣ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(da),
					result  => q(ㄉㄚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(da),
					result  => q(ㄉㄚ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(de),
					result  => q(ㄉㄜ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(de),
					result  => q(ㄉㄜ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(di),
					result  => q(ㄉㄧ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(di),
					result  => q(ㄉㄧ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(du),
					result  => q(ㄉㄨ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(du),
					result  => q(ㄉㄨ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(tang),
					result  => q(ㄊㄤ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(tang),
					result  => q(ㄊㄤ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(teng),
					result  => q(ㄊㄥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(teng),
					result  => q(ㄊㄥ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(tiao),
					result  => q(ㄊㄧㄠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(tiao),
					result  => q(ㄊㄧㄠ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(tian),
					result  => q(ㄊㄧㄢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(tian),
					result  => q(ㄊㄧㄢ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(ting),
					result  => q(ㄊㄧㄥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ting),
					result  => q(ㄊㄧㄥ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(tuan),
					result  => q(ㄊㄨㄢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(tuan),
					result  => q(ㄊㄨㄢ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(tong),
					result  => q(ㄊㄨㄥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(tong),
					result  => q(ㄊㄨㄥ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(tai),
					result  => q(ㄊㄞ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(tai),
					result  => q(ㄊㄞ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(tao),
					result  => q(ㄊㄠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(tao),
					result  => q(ㄊㄠ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(tou),
					result  => q(ㄊㄡ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(tou),
					result  => q(ㄊㄡ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(tan),
					result  => q(ㄊㄢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(tan),
					result  => q(ㄊㄢ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(tie),
					result  => q(ㄊㄧㄝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(tie),
					result  => q(ㄊㄧㄝ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(tuo),
					result  => q(ㄊㄨㄛ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(tuo),
					result  => q(ㄊㄨㄛ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(tui),
					result  => q(ㄊㄨㄟ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(tui),
					result  => q(ㄊㄨㄟ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(tun),
					result  => q(ㄊㄨㄣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(tun),
					result  => q(ㄊㄨㄣ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(ta),
					result  => q(ㄊㄚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ta),
					result  => q(ㄊㄚ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(te),
					result  => q(ㄊㄜ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(te),
					result  => q(ㄊㄜ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(ti),
					result  => q(ㄊㄧ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ti),
					result  => q(ㄊㄧ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(tu),
					result  => q(ㄊㄨ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(tu),
					result  => q(ㄊㄨ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(niang),
					result  => q(ㄋㄧㄤ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(niang),
					result  => q(ㄋㄧㄤ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(nang),
					result  => q(ㄋㄤ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(nang),
					result  => q(ㄋㄤ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(neng),
					result  => q(ㄋㄥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(neng),
					result  => q(ㄋㄥ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(niao),
					result  => q(ㄋㄧㄠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(niao),
					result  => q(ㄋㄧㄠ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(nian),
					result  => q(ㄋㄧㄢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(nian),
					result  => q(ㄋㄧㄢ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(ning),
					result  => q(ㄋㄧㄥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ning),
					result  => q(ㄋㄧㄥ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(nuan),
					result  => q(ㄋㄨㄢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(nuan),
					result  => q(ㄋㄨㄢ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(nong),
					result  => q(ㄋㄨㄥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(nong),
					result  => q(ㄋㄨㄥ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(nai),
					result  => q(ㄋㄞ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(nai),
					result  => q(ㄋㄞ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(nei),
					result  => q(ㄋㄟ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(nei),
					result  => q(ㄋㄟ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(nao),
					result  => q(ㄋㄠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(nao),
					result  => q(ㄋㄠ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(nou),
					result  => q(ㄋㄡ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(nou),
					result  => q(ㄋㄡ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(nan),
					result  => q(ㄋㄢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(nan),
					result  => q(ㄋㄢ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(nen),
					result  => q(ㄋㄣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(nen),
					result  => q(ㄋㄣ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(nia),
					result  => q(ㄋㄧㄚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(nia),
					result  => q(ㄋㄧㄚ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(nie),
					result  => q(ㄋㄧㄝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(nie),
					result  => q(ㄋㄧㄝ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(niu),
					result  => q(ㄋㄧㄡ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(niu),
					result  => q(ㄋㄧㄡ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(nin),
					result  => q(ㄋㄧㄣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(nin),
					result  => q(ㄋㄧㄣ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(nuo),
					result  => q(ㄋㄨㄛ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(nuo),
					result  => q(ㄋㄨㄛ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(nun),
					result  => q(ㄋㄨㄣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(nun),
					result  => q(ㄋㄨㄣ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(nüe),
					result  => q(ㄋㄩㄝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(nüe),
					result  => q(ㄋㄩㄝ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(nue),
					result  => q(ㄋㄩㄝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(nue),
					result  => q(ㄋㄩㄝ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(na),
					result  => q(ㄋㄚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(na),
					result  => q(ㄋㄚ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(ne),
					result  => q(ㄋㄜ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ne),
					result  => q(ㄋㄜ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(ni),
					result  => q(ㄋㄧ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ni),
					result  => q(ㄋㄧ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(nu),
					result  => q(ㄋㄨ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(nu),
					result  => q(ㄋㄨ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(nü),
					result  => q(ㄋㄩ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(nü),
					result  => q(ㄋㄩ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(liang),
					result  => q(ㄌㄧㄤ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(liang),
					result  => q(ㄌㄧㄤ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(lang),
					result  => q(ㄌㄤ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(lang),
					result  => q(ㄌㄤ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(leng),
					result  => q(ㄌㄥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(leng),
					result  => q(ㄌㄥ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(liao),
					result  => q(ㄌㄧㄠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(liao),
					result  => q(ㄌㄧㄠ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(lian),
					result  => q(ㄌㄧㄢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(lian),
					result  => q(ㄌㄧㄢ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(ling),
					result  => q(ㄌㄧㄥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ling),
					result  => q(ㄌㄧㄥ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(luan),
					result  => q(ㄌㄨㄢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(luan),
					result  => q(ㄌㄨㄢ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(long),
					result  => q(ㄌㄨㄥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(long),
					result  => q(ㄌㄨㄥ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(lüan),
					result  => q(ㄌㄩㄢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(lüan),
					result  => q(ㄌㄩㄢ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(lai),
					result  => q(ㄌㄞ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(lai),
					result  => q(ㄌㄞ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(lei),
					result  => q(ㄌㄟ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(lei),
					result  => q(ㄌㄟ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(lao),
					result  => q(ㄌㄠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(lao),
					result  => q(ㄌㄠ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(lou),
					result  => q(ㄌㄡ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(lou),
					result  => q(ㄌㄡ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(lan),
					result  => q(ㄌㄢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(lan),
					result  => q(ㄌㄢ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(lia),
					result  => q(ㄌㄧㄚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(lia),
					result  => q(ㄌㄧㄚ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(lie),
					result  => q(ㄌㄧㄝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(lie),
					result  => q(ㄌㄧㄝ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(liu),
					result  => q(ㄌㄧㄡ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(liu),
					result  => q(ㄌㄧㄡ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(lin),
					result  => q(ㄌㄧㄣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(lin),
					result  => q(ㄌㄧㄣ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(luo),
					result  => q(ㄌㄨㄛ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(luo),
					result  => q(ㄌㄨㄛ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(lun),
					result  => q(ㄌㄨㄣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(lun),
					result  => q(ㄌㄨㄣ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(lüe),
					result  => q(ㄌㄩㄝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(lüe),
					result  => q(ㄌㄩㄝ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(lue),
					result  => q(ㄌㄩㄝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(lue),
					result  => q(ㄌㄩㄝ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(la),
					result  => q(ㄌㄚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(la),
					result  => q(ㄌㄚ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(lo),
					result  => q(ㄌㄛ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(lo),
					result  => q(ㄌㄛ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(le),
					result  => q(ㄌㄜ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(le),
					result  => q(ㄌㄜ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(li),
					result  => q(ㄌㄧ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(li),
					result  => q(ㄌㄧ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(lu),
					result  => q(ㄌㄨ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(lu),
					result  => q(ㄌㄨ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(lü),
					result  => q(ㄌㄩ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(lü),
					result  => q(ㄌㄩ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(guang),
					result  => q(ㄍㄨㄤ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(guang),
					result  => q(ㄍㄨㄤ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(gang),
					result  => q(ㄍㄤ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(gang),
					result  => q(ㄍㄤ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(geng),
					result  => q(ㄍㄥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(geng),
					result  => q(ㄍㄥ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(guai),
					result  => q(ㄍㄨㄞ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(guai),
					result  => q(ㄍㄨㄞ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(guan),
					result  => q(ㄍㄨㄢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(guan),
					result  => q(ㄍㄨㄢ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(gong),
					result  => q(ㄍㄨㄥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(gong),
					result  => q(ㄍㄨㄥ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(gai),
					result  => q(ㄍㄞ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(gai),
					result  => q(ㄍㄞ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(gei),
					result  => q(ㄍㄟ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(gei),
					result  => q(ㄍㄟ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(gao),
					result  => q(ㄍㄠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(gao),
					result  => q(ㄍㄠ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(gou),
					result  => q(ㄍㄡ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(gou),
					result  => q(ㄍㄡ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(gan),
					result  => q(ㄍㄢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(gan),
					result  => q(ㄍㄢ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(gen),
					result  => q(ㄍㄣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(gen),
					result  => q(ㄍㄣ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(gua),
					result  => q(ㄍㄨㄚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(gua),
					result  => q(ㄍㄨㄚ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(guo),
					result  => q(ㄍㄨㄛ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(guo),
					result  => q(ㄍㄨㄛ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(gui),
					result  => q(ㄍㄨㄟ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(gui),
					result  => q(ㄍㄨㄟ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(gun),
					result  => q(ㄍㄨㄣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(gun),
					result  => q(ㄍㄨㄣ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(ga),
					result  => q(ㄍㄚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ga),
					result  => q(ㄍㄚ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(ge),
					result  => q(ㄍㄜ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ge),
					result  => q(ㄍㄜ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(gi),
					result  => q(ㄍㄧ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(gi),
					result  => q(ㄍㄧ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(gu),
					result  => q(ㄍㄨ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(gu),
					result  => q(ㄍㄨ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(kuang),
					result  => q(ㄎㄨㄤ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(kuang),
					result  => q(ㄎㄨㄤ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(kang),
					result  => q(ㄎㄤ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(kang),
					result  => q(ㄎㄤ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(keng),
					result  => q(ㄎㄥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(keng),
					result  => q(ㄎㄥ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(kuai),
					result  => q(ㄎㄨㄞ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(kuai),
					result  => q(ㄎㄨㄞ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(kuan),
					result  => q(ㄎㄨㄢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(kuan),
					result  => q(ㄎㄨㄢ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(kong),
					result  => q(ㄎㄨㄥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(kong),
					result  => q(ㄎㄨㄥ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(kai),
					result  => q(ㄎㄞ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(kai),
					result  => q(ㄎㄞ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(kao),
					result  => q(ㄎㄠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(kao),
					result  => q(ㄎㄠ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(kou),
					result  => q(ㄎㄡ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(kou),
					result  => q(ㄎㄡ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(kan),
					result  => q(ㄎㄢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(kan),
					result  => q(ㄎㄢ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(ken),
					result  => q(ㄎㄣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ken),
					result  => q(ㄎㄣ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(kua),
					result  => q(ㄎㄨㄚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(kua),
					result  => q(ㄎㄨㄚ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(kuo),
					result  => q(ㄎㄨㄛ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(kuo),
					result  => q(ㄎㄨㄛ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(kui),
					result  => q(ㄎㄨㄟ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(kui),
					result  => q(ㄎㄨㄟ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(kun),
					result  => q(ㄎㄨㄣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(kun),
					result  => q(ㄎㄨㄣ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(ka),
					result  => q(ㄎㄚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ka),
					result  => q(ㄎㄚ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(ke),
					result  => q(ㄎㄜ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ke),
					result  => q(ㄎㄜ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(ku),
					result  => q(ㄎㄨ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ku),
					result  => q(ㄎㄨ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(huang),
					result  => q(ㄏㄨㄤ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(huang),
					result  => q(ㄏㄨㄤ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(hang),
					result  => q(ㄏㄤ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(hang),
					result  => q(ㄏㄤ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(heng),
					result  => q(ㄏㄥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(heng),
					result  => q(ㄏㄥ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(huai),
					result  => q(ㄏㄨㄞ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(huai),
					result  => q(ㄏㄨㄞ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(huan),
					result  => q(ㄏㄨㄢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(huan),
					result  => q(ㄏㄨㄢ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(hong),
					result  => q(ㄏㄨㄥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(hong),
					result  => q(ㄏㄨㄥ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(hai),
					result  => q(ㄏㄞ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(hai),
					result  => q(ㄏㄞ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(hei),
					result  => q(ㄏㄟ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(hei),
					result  => q(ㄏㄟ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(hao),
					result  => q(ㄏㄠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(hao),
					result  => q(ㄏㄠ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(hou),
					result  => q(ㄏㄡ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(hou),
					result  => q(ㄏㄡ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(han),
					result  => q(ㄏㄢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(han),
					result  => q(ㄏㄢ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(hen),
					result  => q(ㄏㄣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(hen),
					result  => q(ㄏㄣ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(hua),
					result  => q(ㄏㄨㄚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(hua),
					result  => q(ㄏㄨㄚ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(huo),
					result  => q(ㄏㄨㄛ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(huo),
					result  => q(ㄏㄨㄛ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(hui),
					result  => q(ㄏㄨㄟ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(hui),
					result  => q(ㄏㄨㄟ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(hun),
					result  => q(ㄏㄨㄣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(hun),
					result  => q(ㄏㄨㄣ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(hm),
					result  => q(ㄏㄇ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(hm),
					result  => q(ㄏㄇ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(ha),
					result  => q(ㄏㄚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ha),
					result  => q(ㄏㄚ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(ho),
					result  => q(ㄏㄛ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ho),
					result  => q(ㄏㄛ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(he),
					result  => q(ㄏㄜ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(he),
					result  => q(ㄏㄜ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(hu),
					result  => q(ㄏㄨ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(hu),
					result  => q(ㄏㄨ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(jiang),
					result  => q(ㄐㄧㄤ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(jiang),
					result  => q(ㄐㄧㄤ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(jiong),
					result  => q(ㄐㄩㄥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(jiong),
					result  => q(ㄐㄩㄥ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(jiao),
					result  => q(ㄐㄧㄠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(jiao),
					result  => q(ㄐㄧㄠ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(jian),
					result  => q(ㄐㄧㄢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(jian),
					result  => q(ㄐㄧㄢ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(jing),
					result  => q(ㄐㄧㄥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(jing),
					result  => q(ㄐㄧㄥ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(juan),
					result  => q(ㄐㄩㄢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(juan),
					result  => q(ㄐㄩㄢ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(jia),
					result  => q(ㄐㄧㄚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(jia),
					result  => q(ㄐㄧㄚ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(jie),
					result  => q(ㄐㄧㄝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(jie),
					result  => q(ㄐㄧㄝ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(jiu),
					result  => q(ㄐㄧㄡ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(jiu),
					result  => q(ㄐㄧㄡ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(jin),
					result  => q(ㄐㄧㄣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(jin),
					result  => q(ㄐㄧㄣ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(jue),
					result  => q(ㄐㄩㄝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(jue),
					result  => q(ㄐㄩㄝ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(jun),
					result  => q(ㄐㄩㄣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(jun),
					result  => q(ㄐㄩㄣ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(ji),
					result  => q(ㄐㄧ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ji),
					result  => q(ㄐㄧ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(ju),
					result  => q(ㄐㄩ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ju),
					result  => q(ㄐㄩ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(qiang),
					result  => q(ㄑㄧㄤ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(qiang),
					result  => q(ㄑㄧㄤ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(qiong),
					result  => q(ㄑㄩㄥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(qiong),
					result  => q(ㄑㄩㄥ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(qiao),
					result  => q(ㄑㄧㄠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(qiao),
					result  => q(ㄑㄧㄠ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(qian),
					result  => q(ㄑㄧㄢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(qian),
					result  => q(ㄑㄧㄢ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(qing),
					result  => q(ㄑㄧㄥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(qing),
					result  => q(ㄑㄧㄥ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(quan),
					result  => q(ㄑㄩㄢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(quan),
					result  => q(ㄑㄩㄢ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(qia),
					result  => q(ㄑㄧㄚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(qia),
					result  => q(ㄑㄧㄚ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(qie),
					result  => q(ㄑㄧㄝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(qie),
					result  => q(ㄑㄧㄝ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(qiu),
					result  => q(ㄑㄧㄡ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(qiu),
					result  => q(ㄑㄧㄡ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(qin),
					result  => q(ㄑㄧㄣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(qin),
					result  => q(ㄑㄧㄣ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(que),
					result  => q(ㄑㄩㄝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(que),
					result  => q(ㄑㄩㄝ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(qun),
					result  => q(ㄑㄩㄣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(qun),
					result  => q(ㄑㄩㄣ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(qi),
					result  => q(ㄑㄧ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(qi),
					result  => q(ㄑㄧ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(qu),
					result  => q(ㄑㄩ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(qu),
					result  => q(ㄑㄩ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(xiang),
					result  => q(ㄒㄧㄤ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(xiang),
					result  => q(ㄒㄧㄤ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(xiong),
					result  => q(ㄒㄩㄥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(xiong),
					result  => q(ㄒㄩㄥ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(xiao),
					result  => q(ㄒㄧㄠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(xiao),
					result  => q(ㄒㄧㄠ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(xian),
					result  => q(ㄒㄧㄢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(xian),
					result  => q(ㄒㄧㄢ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(xing),
					result  => q(ㄒㄧㄥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(xing),
					result  => q(ㄒㄧㄥ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(xuan),
					result  => q(ㄒㄩㄢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(xuan),
					result  => q(ㄒㄩㄢ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(xia),
					result  => q(ㄒㄧㄚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(xia),
					result  => q(ㄒㄧㄚ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(xie),
					result  => q(ㄒㄧㄝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(xie),
					result  => q(ㄒㄧㄝ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(xiu),
					result  => q(ㄒㄧㄡ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(xiu),
					result  => q(ㄒㄧㄡ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(xin),
					result  => q(ㄒㄧㄣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(xin),
					result  => q(ㄒㄧㄣ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(xue),
					result  => q(ㄒㄩㄝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(xue),
					result  => q(ㄒㄩㄝ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(xun),
					result  => q(ㄒㄩㄣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(xun),
					result  => q(ㄒㄩㄣ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(xi),
					result  => q(ㄒㄧ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(xi),
					result  => q(ㄒㄧ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(xu),
					result  => q(ㄒㄩ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(xu),
					result  => q(ㄒㄩ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(zhuang),
					result  => q(ㄓㄨㄤ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(zhuang),
					result  => q(ㄓㄨㄤ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(zhang),
					result  => q(ㄓㄤ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(zhang),
					result  => q(ㄓㄤ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(zheng),
					result  => q(ㄓㄥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(zheng),
					result  => q(ㄓㄥ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(zhuai),
					result  => q(ㄓㄨㄞ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(zhuai),
					result  => q(ㄓㄨㄞ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(zhuan),
					result  => q(ㄓㄨㄢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(zhuan),
					result  => q(ㄓㄨㄢ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(zhong),
					result  => q(ㄓㄨㄥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(zhong),
					result  => q(ㄓㄨㄥ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(zhai),
					result  => q(ㄓㄞ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(zhai),
					result  => q(ㄓㄞ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(zhei),
					result  => q(ㄓㄟ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(zhei),
					result  => q(ㄓㄟ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(zhao),
					result  => q(ㄓㄠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(zhao),
					result  => q(ㄓㄠ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(zhou),
					result  => q(ㄓㄡ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(zhou),
					result  => q(ㄓㄡ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(zhan),
					result  => q(ㄓㄢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(zhan),
					result  => q(ㄓㄢ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(zhen),
					result  => q(ㄓㄣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(zhen),
					result  => q(ㄓㄣ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(zhua),
					result  => q(ㄓㄨㄚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(zhua),
					result  => q(ㄓㄨㄚ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(zhuo),
					result  => q(ㄓㄨㄛ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(zhuo),
					result  => q(ㄓㄨㄛ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(zhui),
					result  => q(ㄓㄨㄟ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(zhui),
					result  => q(ㄓㄨㄟ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(zhun),
					result  => q(ㄓㄨㄣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(zhun),
					result  => q(ㄓㄨㄣ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(zha),
					result  => q(ㄓㄚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(zha),
					result  => q(ㄓㄚ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(zhe),
					result  => q(ㄓㄜ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(zhe),
					result  => q(ㄓㄜ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(zhu),
					result  => q(ㄓㄨ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(zhu),
					result  => q(ㄓㄨ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(zhi),
					result  => q(ㄓ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(zhi),
					result  => q(ㄓ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(chuang),
					result  => q(ㄔㄨㄤ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(chuang),
					result  => q(ㄔㄨㄤ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(chang),
					result  => q(ㄔㄤ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(chang),
					result  => q(ㄔㄤ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(cheng),
					result  => q(ㄔㄥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(cheng),
					result  => q(ㄔㄥ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(chuai),
					result  => q(ㄔㄨㄞ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(chuai),
					result  => q(ㄔㄨㄞ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(chuan),
					result  => q(ㄔㄨㄢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(chuan),
					result  => q(ㄔㄨㄢ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(chong),
					result  => q(ㄔㄨㄥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(chong),
					result  => q(ㄔㄨㄥ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(chai),
					result  => q(ㄔㄞ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(chai),
					result  => q(ㄔㄞ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(chao),
					result  => q(ㄔㄠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(chao),
					result  => q(ㄔㄠ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(chou),
					result  => q(ㄔㄡ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(chou),
					result  => q(ㄔㄡ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(chan),
					result  => q(ㄔㄢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(chan),
					result  => q(ㄔㄢ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(chen),
					result  => q(ㄔㄣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(chen),
					result  => q(ㄔㄣ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(chua),
					result  => q(ㄔㄨㄚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(chua),
					result  => q(ㄔㄨㄚ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(chuo),
					result  => q(ㄔㄨㄛ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(chuo),
					result  => q(ㄔㄨㄛ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(chui),
					result  => q(ㄔㄨㄟ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(chui),
					result  => q(ㄔㄨㄟ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(chun),
					result  => q(ㄔㄨㄣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(chun),
					result  => q(ㄔㄨㄣ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(cha),
					result  => q(ㄔㄚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(cha),
					result  => q(ㄔㄚ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(che),
					result  => q(ㄔㄜ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(che),
					result  => q(ㄔㄜ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(chu),
					result  => q(ㄔㄨ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(chu),
					result  => q(ㄔㄨ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(chi),
					result  => q(ㄔ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(chi),
					result  => q(ㄔ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(shuang),
					result  => q(ㄕㄨㄤ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(shuang),
					result  => q(ㄕㄨㄤ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(shong),
					result  => q(ㄕㄡㄥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(shong),
					result  => q(ㄕㄡㄥ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(shang),
					result  => q(ㄕㄤ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(shang),
					result  => q(ㄕㄤ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(sheng),
					result  => q(ㄕㄥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(sheng),
					result  => q(ㄕㄥ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(shuai),
					result  => q(ㄕㄨㄞ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(shuai),
					result  => q(ㄕㄨㄞ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(shuan),
					result  => q(ㄕㄨㄢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(shuan),
					result  => q(ㄕㄨㄢ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(shai),
					result  => q(ㄕㄞ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(shai),
					result  => q(ㄕㄞ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(shei),
					result  => q(ㄕㄟ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(shei),
					result  => q(ㄕㄟ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(shao),
					result  => q(ㄕㄠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(shao),
					result  => q(ㄕㄠ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(shou),
					result  => q(ㄕㄡ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(shou),
					result  => q(ㄕㄡ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(shan),
					result  => q(ㄕㄢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(shan),
					result  => q(ㄕㄢ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(shen),
					result  => q(ㄕㄣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(shen),
					result  => q(ㄕㄣ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(shua),
					result  => q(ㄕㄨㄚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(shua),
					result  => q(ㄕㄨㄚ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(shuo),
					result  => q(ㄕㄨㄛ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(shuo),
					result  => q(ㄕㄨㄛ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(shui),
					result  => q(ㄕㄨㄟ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(shui),
					result  => q(ㄕㄨㄟ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(shun),
					result  => q(ㄕㄨㄣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(shun),
					result  => q(ㄕㄨㄣ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(sha),
					result  => q(ㄕㄚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(sha),
					result  => q(ㄕㄚ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(she),
					result  => q(ㄕㄜ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(she),
					result  => q(ㄕㄜ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(shu),
					result  => q(ㄕㄨ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(shu),
					result  => q(ㄕㄨ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(shi),
					result  => q(ㄕ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(shi),
					result  => q(ㄕ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(rang),
					result  => q(ㄖㄤ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(rang),
					result  => q(ㄖㄤ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(reng),
					result  => q(ㄖㄥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(reng),
					result  => q(ㄖㄥ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(ruan),
					result  => q(ㄖㄨㄢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ruan),
					result  => q(ㄖㄨㄢ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(rong),
					result  => q(ㄖㄨㄥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(rong),
					result  => q(ㄖㄨㄥ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(rao),
					result  => q(ㄖㄠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(rao),
					result  => q(ㄖㄠ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(rou),
					result  => q(ㄖㄡ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(rou),
					result  => q(ㄖㄡ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(ran),
					result  => q(ㄖㄢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ran),
					result  => q(ㄖㄢ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(ren),
					result  => q(ㄖㄣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ren),
					result  => q(ㄖㄣ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(ruo),
					result  => q(ㄖㄨㄛ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ruo),
					result  => q(ㄖㄨㄛ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(rui),
					result  => q(ㄖㄨㄟ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(rui),
					result  => q(ㄖㄨㄟ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(run),
					result  => q(ㄖㄨㄣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(run),
					result  => q(ㄖㄨㄣ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(ra),
					result  => q(ㄖㄚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ra),
					result  => q(ㄖㄚ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(re),
					result  => q(ㄖㄜ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(re),
					result  => q(ㄖㄜ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(ru),
					result  => q(ㄖㄨ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ru),
					result  => q(ㄖㄨ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(ri),
					result  => q(ㄖ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ri),
					result  => q(ㄖ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(zang),
					result  => q(ㄗㄤ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(zang),
					result  => q(ㄗㄤ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(zeng),
					result  => q(ㄗㄥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(zeng),
					result  => q(ㄗㄥ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(zuan),
					result  => q(ㄗㄨㄢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(zuan),
					result  => q(ㄗㄨㄢ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(zong),
					result  => q(ㄗㄨㄥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(zong),
					result  => q(ㄗㄨㄥ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(zai),
					result  => q(ㄗㄞ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(zai),
					result  => q(ㄗㄞ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(zei),
					result  => q(ㄗㄟ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(zei),
					result  => q(ㄗㄟ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(zao),
					result  => q(ㄗㄠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(zao),
					result  => q(ㄗㄠ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(zou),
					result  => q(ㄗㄡ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(zou),
					result  => q(ㄗㄡ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(zan),
					result  => q(ㄗㄢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(zan),
					result  => q(ㄗㄢ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(zen),
					result  => q(ㄗㄣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(zen),
					result  => q(ㄗㄣ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(zuo),
					result  => q(ㄗㄨㄛ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(zuo),
					result  => q(ㄗㄨㄛ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(zui),
					result  => q(ㄗㄨㄟ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(zui),
					result  => q(ㄗㄨㄟ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(zun),
					result  => q(ㄗㄨㄣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(zun),
					result  => q(ㄗㄨㄣ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(za),
					result  => q(ㄗㄚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(za),
					result  => q(ㄗㄚ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(ze),
					result  => q(ㄗㄜ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ze),
					result  => q(ㄗㄜ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(zu),
					result  => q(ㄗㄨ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(zu),
					result  => q(ㄗㄨ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(zi),
					result  => q(ㄗ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(zi),
					result  => q(ㄗ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(cang),
					result  => q(ㄘㄤ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(cang),
					result  => q(ㄘㄤ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(ceng),
					result  => q(ㄘㄥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ceng),
					result  => q(ㄘㄥ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(cuan),
					result  => q(ㄘㄨㄢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(cuan),
					result  => q(ㄘㄨㄢ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(cong),
					result  => q(ㄘㄨㄥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(cong),
					result  => q(ㄘㄨㄥ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(cai),
					result  => q(ㄘㄞ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(cai),
					result  => q(ㄘㄞ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(cao),
					result  => q(ㄘㄠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(cao),
					result  => q(ㄘㄠ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(cou),
					result  => q(ㄘㄡ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(cou),
					result  => q(ㄘㄡ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(can),
					result  => q(ㄘㄢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(can),
					result  => q(ㄘㄢ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(cen),
					result  => q(ㄘㄣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(cen),
					result  => q(ㄘㄣ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(cuo),
					result  => q(ㄘㄨㄛ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(cuo),
					result  => q(ㄘㄨㄛ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(cui),
					result  => q(ㄘㄨㄟ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(cui),
					result  => q(ㄘㄨㄟ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(cun),
					result  => q(ㄘㄨㄣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(cun),
					result  => q(ㄘㄨㄣ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(ca),
					result  => q(ㄘㄚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ca),
					result  => q(ㄘㄚ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(ce),
					result  => q(ㄘㄜ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ce),
					result  => q(ㄘㄜ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(cu),
					result  => q(ㄘㄨ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(cu),
					result  => q(ㄘㄨ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(ci),
					result  => q(ㄘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ci),
					result  => q(ㄘ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(sang),
					result  => q(ㄙㄤ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(sang),
					result  => q(ㄙㄤ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(seng),
					result  => q(ㄙㄥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(seng),
					result  => q(ㄙㄥ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(suan),
					result  => q(ㄙㄨㄢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(suan),
					result  => q(ㄙㄨㄢ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(song),
					result  => q(ㄙㄨㄥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(song),
					result  => q(ㄙㄨㄥ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(sai),
					result  => q(ㄙㄞ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(sai),
					result  => q(ㄙㄞ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(sei),
					result  => q(ㄙㄟ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(sei),
					result  => q(ㄙㄟ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(sao),
					result  => q(ㄙㄠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(sao),
					result  => q(ㄙㄠ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(sou),
					result  => q(ㄙㄡ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(sou),
					result  => q(ㄙㄡ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(san),
					result  => q(ㄙㄢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(san),
					result  => q(ㄙㄢ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(sen),
					result  => q(ㄙㄣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(sen),
					result  => q(ㄙㄣ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(suo),
					result  => q(ㄙㄨㄛ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(suo),
					result  => q(ㄙㄨㄛ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(sui),
					result  => q(ㄙㄨㄟ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(sui),
					result  => q(ㄙㄨㄟ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(sun),
					result  => q(ㄙㄨㄣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(sun),
					result  => q(ㄙㄨㄣ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(sa),
					result  => q(ㄙㄚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(sa),
					result  => q(ㄙㄚ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(se),
					result  => q(ㄙㄜ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(se),
					result  => q(ㄙㄜ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(su),
					result  => q(ㄙㄨ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(su),
					result  => q(ㄙㄨ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(si),
					result  => q(ㄙ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(si),
					result  => q(ㄙ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(yuan),
					result  => q(ㄩㄢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(yuan),
					result  => q(ㄩㄢ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(yong),
					result  => q(ㄩㄥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(yong),
					result  => q(ㄩㄥ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(yue),
					result  => q(ㄩㄝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(yue),
					result  => q(ㄩㄝ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(yun),
					result  => q(ㄩㄣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(yun),
					result  => q(ㄩㄣ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(yu),
					result  => q(ㄩ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(yu),
					result  => q(ㄩ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(yang),
					result  => q(ㄧㄤ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(yang),
					result  => q(ㄧㄤ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(ying),
					result  => q(ㄧㄥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ying),
					result  => q(ㄧㄥ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(yai),
					result  => q(ㄧㄞ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(yai),
					result  => q(ㄧㄞ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(yao),
					result  => q(ㄧㄠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(yao),
					result  => q(ㄧㄠ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(you),
					result  => q(ㄧㄡ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(you),
					result  => q(ㄧㄡ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(yan),
					result  => q(ㄧㄢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(yan),
					result  => q(ㄧㄢ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(yin),
					result  => q(ㄧㄣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(yin),
					result  => q(ㄧㄣ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(ya),
					result  => q(ㄧㄚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ya),
					result  => q(ㄧㄚ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(yo),
					result  => q(ㄧㄛ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(yo),
					result  => q(ㄧㄛ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(ye),
					result  => q(ㄧㄝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ye),
					result  => q(ㄧㄝ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(yi),
					result  => q(ㄧ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(yi),
					result  => q(ㄧ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(wong),
					result  => q(ㄨㄨㄥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(wong),
					result  => q(ㄨㄨㄥ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(wang),
					result  => q(ㄨㄤ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(wang),
					result  => q(ㄨㄤ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(weng),
					result  => q(ㄨㄥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(weng),
					result  => q(ㄨㄥ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(wai),
					result  => q(ㄨㄞ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(wai),
					result  => q(ㄨㄞ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(wei),
					result  => q(ㄨㄟ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(wei),
					result  => q(ㄨㄟ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(wan),
					result  => q(ㄨㄢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(wan),
					result  => q(ㄨㄢ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(wen),
					result  => q(ㄨㄣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(wen),
					result  => q(ㄨㄣ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(wa),
					result  => q(ㄨㄚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(wa),
					result  => q(ㄨㄚ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(wo),
					result  => q(ㄨㄛ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(wo),
					result  => q(ㄨㄛ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(wu),
					result  => q(ㄨ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(wu),
					result  => q(ㄨ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(ang),
					result  => q(ㄤ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ang),
					result  => q(ㄤ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(eng),
					result  => q(ㄥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(eng),
					result  => q(ㄥ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(eh),
					result  => q(ㄝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(eh),
					result  => q(ㄝ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(ea),
					result  => q(ㄝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ea),
					result  => q(ㄝ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(ai),
					result  => q(ㄞ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ai),
					result  => q(ㄞ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(ei),
					result  => q(ㄟ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ei),
					result  => q(ㄟ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(ao),
					result  => q(ㄠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ao),
					result  => q(ㄠ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(au),
					result  => q(ㄠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(au),
					result  => q(ㄠ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(ou),
					result  => q(ㄡ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ou),
					result  => q(ㄡ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(an),
					result  => q(ㄢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(an),
					result  => q(ㄢ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(en),
					result  => q(ㄣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(en),
					result  => q(ㄣ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(er),
					result  => q(ㄦ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(er),
					result  => q(ㄦ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(a),
					result  => q(ㄚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(a),
					result  => q(ㄚ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(o),
					result  => q(ㄛ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(o),
					result  => q(ㄛ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(e),
					result  => q(ㄜ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(e),
					result  => q(ㄜ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(iu),
					result  => q(ㄩ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(iu),
					result  => q(ㄩ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(i),
					result  => q(ㄧ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(i),
					result  => q(ㄧ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(u),
					result  => q(ㄨ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(u),
					result  => q(ㄨ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(m),
					result  => q(ㄇ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(m),
					result  => q(ㄇ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([1-5]),
					replace => q(n),
					result  => q(ㄋ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(n),
					result  => q(ㄋ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(b),
					result  => q(ㄅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(p),
					result  => q(ㄆ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(f),
					result  => q(ㄈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(d),
					result  => q(ㄉ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(t),
					result  => q(ㄊ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(l),
					result  => q(ㄌ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(g),
					result  => q(ㄍ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(k),
					result  => q(ㄎ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(h),
					result  => q(ㄏ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(j),
					result  => q(ㄐ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(q),
					result  => q(ㄑ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(x),
					result  => q(ㄒ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(zh),
					result  => q(ㄓ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ch),
					result  => q(ㄔ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(sh),
					result  => q(ㄕ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(r),
					result  => q(ㄖ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(z),
					result  => q(ㄗ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(c),
					result  => q(ㄘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(s),
					result  => q(ㄙ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(1),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(2),
					result  => q(ˊ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(3),
					result  => q(ˇ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(4),
					result  => q(ˋ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(5),
					result  => q(˙),
					revisit => 0,
				},
			]
		},
	] },
);

no Moo;

1;

# vim: tabstop=4
