package Locale::CLDR::Transformations::Any::Ro::Ro_fonipa;
# This file auto generated from Data\common\transforms\ro-ro_FONIPA.xml
#	on Sun  3 Dec 10:05:00 am GMT

use strict;
use warnings;
use version;

our $VERSION = version->declare('v0.34.4');

use v5.10.1;
use mro 'c3';
use utf8;
use if $^V ge v5.12.0, feature => 'unicode_strings';
use Types::Standard qw( Str Int HashRef ArrayRef CodeRef RegexpRef );
use Moo;

BEGIN {
	die "Transliteration requires Perl 5.18 or above"
		unless $^V ge v5.18.0;
}

no warnings 'experimental::regex_sets';
has 'transforms' => (
	is => 'ro',
	isa => ArrayRef,
	init_arg => undef,
	default => sub { [
		qr/(?^um:\G.)/,
		{
			type => 'transform',
			data => [
				{
					from => q(Any),
					to => q(NFC),
				},
				{
					from => q(Any),
					to => q(Lower),
				},
			],
		},
		{
			type => 'conversion',
			data => [
				{
					before  => q(),
					after   => q(),
					replace => q(eoai),
					result  => q(eo̯aj),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(eai),
					result  => q(e̯aj),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(eau),
					result  => q(e̯aw),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(eoa),
					result  => q(e̯o̯a),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(i\-ai),
					result  => q(jaj),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ia\-i),
					result  => q(jaj),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(iau),
					result  => q(jaw),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(iei),
					result  => q(jej),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ieu),
					result  => q(jew),
					revisit => 0,
				},
				{
					before  => q([^ \p{L} \p{M} \p{N}]),
					after   => q(),
					replace => q(eu),
					result  => q(jew),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ioa),
					result  => q(jo̯a),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ioi),
					result  => q(joj),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(i\-oi),
					result  => q(joj),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(iou),
					result  => q(jow),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(oai),
					result  => q(o̯aj),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(uai),
					result  => q(waj),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(uau),
					result  => q(waw),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(uăi),
					result  => q(wəj),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ai),
					result  => q(aj),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(âi),
					result  => q(ɨj),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ăi),
					result  => q(əj),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(r),
					replace => q(au),
					result  => q(au),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(au),
					result  => q(aw),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(âu),
					result  => q(ɨw),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ău),
					result  => q(əw),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ea),
					result  => q(e̯a),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ei),
					result  => q(ej),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(eo),
					result  => q(e̯o),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(e\-o),
					result  => q(e̯o),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(eu),
					result  => q(ew),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(e\-u),
					result  => q(e̯u),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ia),
					result  => q(ja),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(i\-a),
					result  => q(ja),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ie),
					result  => q(je),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ii),
					result  => q(ij),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(io),
					result  => q(jo),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?:(?:[eiî]|[aâăou])|(?:(?![\p{L}\p{M}\p{N}])(?s:.)))),
					replace => q(iu),
					result  => q(iw),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(iu),
					result  => q(ju),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(oa),
					result  => q(o̯a),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(oi),
					result  => q(oj),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ou),
					result  => q(ow),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ua),
					result  => q(wa),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(uâ),
					result  => q(wɨ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(uă),
					result  => q(wə),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ue),
					result  => q(we),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ui),
					result  => q(uj),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(uu),
					result  => q(uw),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(a),
					result  => q(a),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(â),
					result  => q(ɨ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ă),
					result  => q(ə),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(b),
					result  => q(b),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ch),
					result  => q(k),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ei]),
					replace => q(c),
					result  => q(t͡ʃ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(c),
					result  => q(k),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(d),
					result  => q(d),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(e),
					result  => q(e),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(f),
					result  => q(f),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(gh),
					result  => q(ɡ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ei]),
					replace => q(g),
					result  => q(d͡ʒ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(g),
					result  => q(ɡ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(h),
					result  => q(h),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(i),
					result  => q(i),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(î),
					result  => q(ɨ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(j),
					result  => q(ʒ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(k),
					result  => q(k),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(l),
					result  => q(l),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(m),
					result  => q(m),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ng),
					result  => q(ŋ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(n),
					result  => q(n),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(o),
					result  => q(o),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(p),
					result  => q(p),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(q),
					result  => q(k),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(r),
					result  => q(r),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(s),
					result  => q(s),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ş),
					result  => q(ʃ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ș),
					result  => q(ʃ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(t),
					result  => q(t),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ţ),
					result  => q(t͡s),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ț),
					result  => q(t͡s),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(u),
					result  => q(u),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(v),
					result  => q(v),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(x),
					result  => q(ks),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(y),
					result  => q(i),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(z),
					result  => q(z),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q([:P:]+),
					result  => q(\'),
					revisit => 0,
				},
			],
		},
		{
			type => 'transform',
			data => [
				{
					from => q(Any),
					to => q(null),
				},
			],
		},
		{
			type => 'conversion',
			data => [
				{
					before  => q(),
					after   => q(),
					replace => q(pp+),
					result  => q(p),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(bb+),
					result  => q(b),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(tt+),
					result  => q(t),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(dd+),
					result  => q(d),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(kk+),
					result  => q(k),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(dd+),
					result  => q(d),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ɡɡ+),
					result  => q(ɡ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ff+),
					result  => q(f),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(vv+),
					result  => q(v),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(hh+),
					result  => q(h),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ss+),
					result  => q(s),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(zz+),
					result  => q(z),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ʃʃ+),
					result  => q(ʃ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ʒʒ+),
					result  => q(ʒ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(rr+),
					result  => q(r),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ll+),
					result  => q(l),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(jj+),
					result  => q(j),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ww+),
					result  => q(w),
					revisit => 0,
				},
			]
		},
	] },
);

no Moo;

1;

# vim: tabstop=4
