package Locale::CLDR::Transformations::Any::Hans::Hant;
# This file auto generated from Data\common\transforms\Simplified-Traditional.xml
#	on Sun  3 Dec 10:04:57 am GMT

use strict;
use warnings;
use version;

our $VERSION = version->declare('v0.34.4');

use v5.10.1;
use mro 'c3';
use utf8;
use if $^V ge v5.12.0, feature => 'unicode_strings';
use Types::Standard qw( Str Int HashRef ArrayRef CodeRef RegexpRef );
use Moo;

BEGIN {
	die "Transliteration requires Perl 5.18 or above"
		unless $^V ge v5.18.0;
}

no warnings 'experimental::regex_sets';
has 'transforms' => (
	is => 'ro',
	isa => ArrayRef,
	init_arg => undef,
	default => sub { [
		qr/(?^um:\G.)/,
		{
			type => 'transform',
			data => [
			],
		},
		{
			type => 'conversion',
			data => [
				{
					before  => q(),
					after   => q(),
					replace => q(于飞),
					result  => q(于飛),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(于归),
					result  => q(于歸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(于思),
					result  => q(于思),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(单于),
					result  => q(單于),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鲜于),
					result  => q(鮮于),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(姜片),
					result  => q(薑片),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(姜末),
					result  => q(薑末),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(生姜),
					result  => q(生薑),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鬼子姜),
					result  => q(鬼子薑),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(姜),
					result  => q(姜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(赤皮仑),
					result  => q(赤皮崙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(金仑溪),
					result  => q(金崙溪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(下仑),
					result  => q(下崙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(中仑),
					result  => q(中崙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(仑顶),
					result  => q(崙頂),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(昆山),
					result  => q(崑山),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(昆仑),
					result  => q(崑崙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(昆曲),
					result  => q(崑曲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(仑),
					result  => q(侖),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(曲),
					result  => q(曲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(茶余饭后),
					result  => q(茶餘飯後),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(余怒未消),
					result  => q(餘怒未消),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(余音绕梁),
					result  => q(餘音繞梁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(余勇可贾),
					result  => q(餘勇可賈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(余波),
					result  => q(餘波),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(余地),
					result  => q(餘地),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(余额),
					result  => q(餘額),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(余角),
					result  => q(餘角),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(余烬),
					result  => q(餘燼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(余款),
					result  => q(餘款),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(余量),
					result  => q(餘量),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(余粮),
					result  => q(餘糧),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(余年),
					result  => q(餘年),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(余力),
					result  => q(餘力),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(余生),
					result  => q(餘生),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(余兴),
					result  => q(餘興),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(余切),
					result  => q(餘切),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(余庆),
					result  => q(餘慶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(余裕),
					result  => q(餘裕),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(余杭),
					result  => q(餘杭),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(余孽),
					result  => q(餘孽),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(余音),
					result  => q(餘音),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(余钱),
					result  => q(餘錢),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(余震),
					result  => q(餘震),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(结余),
					result  => q(結餘),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(多余),
					result  => q(多餘),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(有余),
					result  => q(有餘),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(残余),
					result  => q(殘餘),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(剩余),
					result  => q(剩餘),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(其余),
					result  => q(其餘),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(业余),
					result  => q(業餘),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(盈余),
					result  => q(盈餘),
					revisit => 0,
				},
				{
					before  => q([零一二三四五六七八九十百千万亿两]),
					after   => q(),
					replace => q(余),
					result  => q(餘),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(余),
					result  => q(余),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(馀),
					result  => q(餘),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(什么),
					result  => q(甚麼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(么),
					result  => q(麼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(复数),
					result  => q(複數),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(复分数),
					result  => q(複分數),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(复杂),
					result  => q(複雜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(复制),
					result  => q(複製),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(复),
					result  => q(復),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(了然),
					result  => q(瞭然),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(了解),
					result  => q(瞭解),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(了望),
					result  => q(瞭望),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(明了),
					result  => q(明瞭),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(了),
					result  => q(了),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(解铃系铃),
					result  => q(解鈴繫鈴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(系词),
					result  => q(繫詞),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(系辞),
					result  => q(繫辭),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(系念),
					result  => q(繫念),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(关系),
					result  => q(關係),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(联系),
					result  => q(聯繫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(系于),
					result  => q(繫於),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(维系),
					result  => q(維繫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(连系),
					result  => q(連繫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(系),
					result  => q(系),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(糊里糊涂),
					result  => q(糊裡糊塗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(稀里糊涂),
					result  => q(稀裡糊塗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(蒙在鼓里),
					result  => q(蒙在鼓裡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(怪里怪气),
					result  => q(怪裡怪氣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(傻里傻气),
					result  => q(傻裡傻氣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(俗里俗气),
					result  => q(俗裡俗氣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(嗲里嗲气),
					result  => q(嗲裡嗲氣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(女里女气),
					result  => q(女裡女氣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(妖里妖气),
					result  => q(妖裡妖氣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(娇里娇气),
					result  => q(嬌裡嬌氣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(洋里洋气),
					result  => q(洋裡洋氣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(宝里宝气),
					result  => q(寶裡寶氣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(土里土气),
					result  => q(土裡土氣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(稀里哗啦),
					result  => q(稀裡嘩啦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(由表及里),
					result  => q(由表及裡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(百里挑一),
					result  => q(百裡挑一),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(白里透红),
					result  => q(白裡透紅),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(私下里),
					result  => q(私下裡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(骨子里),
					result  => q(骨子裡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(窝里斗),
					result  => q(窩裡鬥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(忙里),
					result  => q(忙裡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(闻里),
					result  => q(聞裡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(死里),
					result  => q(死裡),
					revisit => 0,
				},
				{
					before  => q([零一二三四五六七八九十百千万亿两]),
					after   => q(),
					replace => q(海里),
					result  => q(海里),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(海里),
					result  => q(海裡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(浪里),
					result  => q(浪裡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(山里),
					result  => q(山裡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(地里),
					result  => q(地裡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(花里),
					result  => q(花裡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(田里),
					result  => q(田裡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(沟里),
					result  => q(溝裡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(河里),
					result  => q(河裡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(江里),
					result  => q(江裡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(沙里),
					result  => q(沙裡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(雪里),
					result  => q(雪裡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(风里),
					result  => q(風裡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(雨里),
					result  => q(雨裡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(雾里),
					result  => q(霧裡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(夜里),
					result  => q(夜裡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(省里),
					result  => q(省裡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(镇里),
					result  => q(鎮裡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(城里),
					result  => q(城裡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(市里),
					result  => q(市裡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(村里),
					result  => q(村裡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(站里),
					result  => q(站裡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(段里),
					result  => q(段裡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(厂里),
					result  => q(廠裡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(店里),
					result  => q(店裡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(馆里),
					result  => q(館裡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(部里),
					result  => q(部裡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(队里),
					result  => q(隊裡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(班里),
					result  => q(班裡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(关里),
					result  => q(關裡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(门里),
					result  => q(門裡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(家里),
					result  => q(家裡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(屋里),
					result  => q(屋裡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(房里),
					result  => q(房裡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(连里),
					result  => q(連裡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(院里),
					result  => q(院裡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(行里),
					result  => q(行裡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(园里),
					result  => q(園裡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(苑里),
					result  => q(苑裡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(明里),
					result  => q(明裡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(暗里),
					result  => q(暗裡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(字里),
					result  => q(字裡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(表里),
					result  => q(表裡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(內里),
					result  => q(內裡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(手里),
					result  => q(手裡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(眼里),
					result  => q(眼裡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(嘴里),
					result  => q(嘴裡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(口里),
					result  => q(口裡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(心里),
					result  => q(心裡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(头里),
					result  => q(頭裡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(怀里),
					result  => q(懷裡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(肚里),
					result  => q(肚裡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(这里),
					result  => q(這裡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(那里),
					result  => q(那裡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(哪里),
					result  => q(哪裡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(入里),
					result  => q(入裡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(里里外外),
					result  => q(裡裡外外),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(里应外合),
					result  => q(裡應外合),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(里通外国),
					result  => q(裡通外國),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(里衬),
					result  => q(裡襯),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(里子),
					result  => q(裡子),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(里海),
					result  => q(裡海),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(里手),
					result  => q(裡手),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(里快),
					result  => q(裡快),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(里面),
					result  => q(裡面),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(里层),
					result  => q(裡層),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(里间),
					result  => q(裡間),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(里屋),
					result  => q(裡屋),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(里头),
					result  => q(裡頭),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(里边),
					result  => q(裡邊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(里外),
					result  => q(裡外),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(干什么),
					result  => q(幹甚麼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(干部),
					result  => q(幹部),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(干才),
					result  => q(幹才),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(干道),
					result  => q(幹道),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(干劲),
					result  => q(幹勁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(干练),
					result  => q(幹練),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(干吗),
					result  => q(幹嗎),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(干事),
					result  => q(幹事),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(干线),
					result  => q(幹線),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(包干),
					result  => q(包幹),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(才干),
					result  => q(才幹),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(高干),
					result  => q(高幹),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(骨干),
					result  => q(骨幹),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(苦干),
					result  => q(苦幹),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(脑干),
					result  => q(腦幹),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(能干),
					result  => q(能幹),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(强干),
					result  => q(強幹),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(实干),
					result  => q(實幹),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(树干),
					result  => q(樹幹),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(调干),
					result  => q(單幹),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(枝干),
					result  => q(枝幹),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(主干),
					result  => q(主幹),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(干贝),
					result  => q(干貝),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(干犯),
					result  => q(干犯),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(干戈),
					result  => q(干戈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(干涉),
					result  => q(干涉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(干支),
					result  => q(干支),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(干连),
					result  => q(干連),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(干扰),
					result  => q(干擾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(干预),
					result  => q(干預),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(干系),
					result  => q(干系),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(若干),
					result  => q(若干),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(天干),
					result  => q(天干),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(无干),
					result  => q(無干),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(相干),
					result  => q(相干),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(干面),
					result  => q(乾麵),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(乾坤),
					result  => q(乾坤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(干),
					result  => q(乾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(划时代),
					result  => q(劃時代),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(划分),
					result  => q(劃分),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(划开),
					result  => q(劃開),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(划一),
					result  => q(劃一),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(划界),
					result  => q(劃界),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(划策),
					result  => q(劃策),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(划归),
					result  => q(劃歸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(划清),
					result  => q(劃清),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(规划),
					result  => q(規劃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(策划),
					result  => q(策劃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(筹划),
					result  => q(籌劃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(计划),
					result  => q(計劃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(比划),
					result  => q(比劃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(谋划),
					result  => q(謀劃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(区划),
					result  => q(區劃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(版画),
					result  => q(版畫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(划),
					result  => q(划),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(画),
					result  => q(畫),
					revisit => 0,
				},
				{
					before  => q([零一二三四五六七八九十百千万亿两]),
					after   => q(),
					replace => q(斗),
					result  => q(斗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(斗量),
					result  => q(斗量),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(斗胆),
					result  => q(斗胆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(斗室),
					result  => q(斗室),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(斗城),
					result  => q(斗城),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(斗拱),
					result  => q(斗拱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(斗子),
					result  => q(斗子),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(阿斗),
					result  => q(阿斗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(北斗),
					result  => q(北斗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(漏斗),
					result  => q(漏斗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(熨斗),
					result  => q(熨斗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(南斗),
					result  => q(南斗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(墨斗),
					result  => q(墨斗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(市斗),
					result  => q(市斗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(泰斗),
					result  => q(泰斗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(星斗),
					result  => q(星斗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(斗),
					result  => q(鬥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([零一二三四五六七八九十百千万亿两]),
					replace => q(周),
					result  => q(週),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(周末),
					result  => q(週末),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(周刊),
					result  => q(週刊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(周期),
					result  => q(週期),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(周岁),
					result  => q(週歲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(周年),
					result  => q(週年),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(周游),
					result  => q(周遊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(周转),
					result  => q(週轉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(本周),
					result  => q(本週),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(周),
					result  => q(周),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(松球),
					result  => q(松毬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(球花),
					result  => q(毬花),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(球果),
					result  => q(毬果),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(松动),
					result  => q(鬆動),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(松紧),
					result  => q(鬆緊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(松散),
					result  => q(鬆散),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(松手),
					result  => q(鬆手),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(松软),
					result  => q(鬆軟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(松绑),
					result  => q(鬆綁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(松弛),
					result  => q(鬆弛),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(疏松),
					result  => q(酥鬆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(放松),
					result  => q(放鬆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(轻松),
					result  => q(輕鬆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(肉松),
					result  => q(肉鬆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(松),
					result  => q(松),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(果),
					result  => q(果),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(老板),
					result  => q(老闆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(板),
					result  => q(板),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(面条),
					result  => q(麵條),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(面粉),
					result  => q(麵粉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(面包),
					result  => q(麵包),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(面筋),
					result  => q(麵筋),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(面食),
					result  => q(麵食),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(炸酱面),
					result  => q(炸醬麵),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(担担面),
					result  => q(擔擔麵),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(刀削面),
					result  => q(刀削麵),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(空心面),
					result  => q(空心麵),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(阳春面),
					result  => q(陽春麵),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(甜面酱),
					result  => q(甜麵醬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(炒面),
					result  => q(炒麵),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(擀面),
					result  => q(擀麵),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(拉面),
					result  => q(拉麵),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(凉面),
					result  => q(涼麵),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(汤面),
					result  => q(湯麵),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(寿面),
					result  => q(壽麵),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(碱面),
					result  => q(鹼麵),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(发面),
					result  => q(發麵),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(白面),
					result  => q(白麵),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(面),
					result  => q(面),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(防御),
					result  => q(防禦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(御敌),
					result  => q(禦敵),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(御寒),
					result  => q(禦寒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(御),
					result  => q(御),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(腼腆),
					result  => q(靦腆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(䩄),
					result  => q(靦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(宫商角徵羽),
					result  => q(宮商角徵羽),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(征伐),
					result  => q(征伐),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(征服),
					result  => q(征服),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(征途),
					result  => q(征途),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(征讨),
					result  => q(征討),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(长征),
					result  => q(長征),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(出征),
					result  => q(出征),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(亲征),
					result  => q(親征),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(征),
					result  => q(徵),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(台风),
					result  => q(颱風),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(写字台),
					result  => q(寫字檯),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(台),
					result  => q(台),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(胡同),
					result  => q(衚衕),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(胡子),
					result  => q(鬍子),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(胡须),
					result  => q(鬍鬚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(胡),
					result  => q(胡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(须根),
					result  => q(鬚根),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(须鲸),
					result  => q(鬚鯨),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(须眉),
					result  => q(鬚眉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(龙须),
					result  => q(龍鬚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(触须),
					result  => q(觸鬚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(须),
					result  => q(須),
					revisit => 0,
				},
				{
					before  => q([零一二三四五六七八九十百千万亿两]),
					after   => q(),
					replace => q(只),
					result  => q(隻),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(形单影只),
					result  => q(形單影隻),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(只身),
					result  => q(隻身),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(只眼),
					result  => q(隻眼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(船只),
					result  => q(船隻),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(舰只),
					result  => q(艦隻),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(祇),
					result  => q(祇),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(只),
					result  => q(只),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(并发),
					result  => q(併發),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(并拢),
					result  => q(併攏),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(并入),
					result  => q(併入),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(并吞),
					result  => q(併吞),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(并力),
					result  => q(併力),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(合并),
					result  => q(合併),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(吞并),
					result  => q(吞併),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(并),
					result  => q(並),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(当),
					result  => q(當),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(药),
					result  => q(藥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(布道),
					result  => q(佈道),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(布景),
					result  => q(佈景),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(布局),
					result  => q(佈局),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(布雷),
					result  => q(佈雷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(布施),
					result  => q(佈施),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(布置),
					result  => q(佈置),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(布谷),
					result  => q(布穀),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(发布),
					result  => q(發佈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(公布),
					result  => q(公佈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(宣布),
					result  => q(宣佈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(布),
					result  => q(布),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(开天辟地),
					result  => q(開天闢地),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(开辟),
					result  => q(開闢),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(辟邪),
					result  => q(闢邪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(辟),
					result  => q(辟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(人言藉藉),
					result  => q(人言藉藉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(借口),
					result  => q(藉口),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(借故),
					result  => q(藉故),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(借使),
					result  => q(藉使),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(凭藉),
					result  => q(憑藉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(骀藉),
					result  => q(駘藉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(慰借),
					result  => q(慰藉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(狼藉),
					result  => q(狼藉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(蕴藉),
					result  => q(藴藉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(枕藉),
					result  => q(枕藉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(借),
					result  => q(借),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(藉),
					result  => q(藉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(尽管),
					result  => q(儘管),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(尽),
					result  => q(盡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(叶韵),
					result  => q(叶韻),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(叶),
					result  => q(葉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(伙计),
					result  => q(夥計),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(伙伴),
					result  => q(夥伴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(伙),
					result  => q(伙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(家具),
					result  => q(傢具),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(家伙),
					result  => q(傢伙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(家),
					result  => q(家),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(奸夫),
					result  => q(姦夫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(奸妇),
					result  => q(姦婦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(奸情),
					result  => q(姦情),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(奸污),
					result  => q(姦污),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(奸淫),
					result  => q(姦淫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鸡奸),
					result  => q(雞姦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(轮奸),
					result  => q(輪姦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(强奸),
					result  => q(強姦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(通奸),
					result  => q(通姦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(诱奸),
					result  => q(誘姦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(奸),
					result  => q(奸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(历书),
					result  => q(曆書),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(历法),
					result  => q(曆法),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(公历),
					result  => q(公曆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(旧历),
					result  => q(舊曆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(黄历),
					result  => q(黃曆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(日历),
					result  => q(日曆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(西历),
					result  => q(西曆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(夏历),
					result  => q(夏曆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(新历),
					result  => q(新曆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(阳历),
					result  => q(陽曆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(阴历),
					result  => q(陰曆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(月历),
					result  => q(月曆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(游历),
					result  => q(遊歷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(万年历),
					result  => q(萬年曆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(万历),
					result  => q(萬曆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(历),
					result  => q(歷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(万俟),
					result  => q(万俟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(气冲冲),
					result  => q(氣沖沖),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(气焰),
					result  => q(氣燄),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(气),
					result  => q(氣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(细致),
					result  => q(細緻),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(精致),
					result  => q(精緻),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(标致),
					result  => q(標緻),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(别致),
					result  => q(別緻),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(致),
					result  => q(致),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(制版),
					result  => q(製版),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(制成),
					result  => q(製成),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(制品),
					result  => q(製品),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(制片),
					result  => q(製片),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(制造),
					result  => q(製造),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(制图),
					result  => q(製圖),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(制作),
					result  => q(製作),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(缝制),
					result  => q(縫製),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(巨制),
					result  => q(巨製),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(炼制),
					result  => q(煉製),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(酿制),
					result  => q(釀製),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(炮制),
					result  => q(炮製),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(特制),
					result  => q(特製),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(预制),
					result  => q(預製),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(制),
					result  => q(制),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(谷贱伤农),
					result  => q(穀賤傷農),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(谷神星),
					result  => q(穀神星),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鬼谷子),
					result  => q(鬼谷子),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(谷子),
					result  => q(穀子),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(打谷),
					result  => q(打穀),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(谷场),
					result  => q(穀場),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(谷物),
					result  => q(穀物),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(谷粒),
					result  => q(穀粒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(谷类),
					result  => q(穀類),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(谷草),
					result  => q(穀草),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(谷仓),
					result  => q(穀倉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(谷苗),
					result  => q(穀苗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(谷种),
					result  => q(穀種),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(谷穗),
					result  => q(穀穗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(谷壳),
					result  => q(穀殻),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(包谷),
					result  => q(包穀),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(稻谷),
					result  => q(稻穀),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(五谷),
					result  => q(五穀),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(米谷),
					result  => q(米穀),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(秕谷),
					result  => q(秕穀),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(晒谷),
					result  => q(曬穀),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(谷),
					result  => q(谷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(后妃),
					result  => q(后妃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(后稷),
					result  => q(后稷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(后土),
					result  => q(后土),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(后羿),
					result  => q(后羿),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(皇后),
					result  => q(皇后),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(母后),
					result  => q(母后),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(王后),
					result  => q(王后),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(太后),
					result  => q(太后),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(后),
					result  => q(後),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(地方志),
					result  => q(地方誌),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(标志),
					result  => q(標誌),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(墓志),
					result  => q(墓誌),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(日志),
					result  => q(日誌),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(碑志),
					result  => q(碑誌),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(县志),
					result  => q(縣誌),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(杂志),
					result  => q(雜誌),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(志),
					result  => q(志),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(别扭),
					result  => q(彆扭),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(别),
					result  => q(別),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(汇报),
					result  => q(彙報),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(词汇),
					result  => q(詞彙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(字汇),
					result  => q(字彙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(汇),
					result  => q(匯),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(辞),
					result  => q(辭),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(词),
					result  => q(詞),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(机),
					result  => q(機),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(发廊),
					result  => q(髮廊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(发妻),
					result  => q(髮妻),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(发型),
					result  => q(髮型),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(发困),
					result  => q(發睏),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(卷土重来),
					result  => q(捲土重來),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(卷心菜),
					result  => q(捲心菜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(卷铺盖),
					result  => q(捲鋪蓋),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(卷尺),
					result  => q(捲尺),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(卷入),
					result  => q(捲入),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(卷动),
					result  => q(捲動),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(卷成),
					result  => q(捲成),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(卷曲),
					result  => q(捲曲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(卷款),
					result  => q(捲款),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(卷帘),
					result  => q(捲簾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(卷纸),
					result  => q(捲紙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(卷缩),
					result  => q(捲縮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(卷舌),
					result  => q(捲舌),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(卷袖),
					result  => q(捲袖),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(卷走),
					result  => q(捲走),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(卷起),
					result  => q(捲起),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(卷门),
					result  => q(捲門),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(卷云),
					result  => q(捲雲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(卷须),
					result  => q(捲鬚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(春卷),
					result  => q(春捲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(烟卷),
					result  => q(煙捲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(纸卷),
					result  => q(紙捲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(卷轴),
					result  => q(捲軸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(席卷),
					result  => q(席捲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(舒卷),
					result  => q(舒捲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(风卷残云),
					result  => q(風捲殘雲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(风驰电卷),
					result  => q(風馳電捲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(龙卷风),
					result  => q(龍捲風),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(蛋卷),
					result  => q(蛋捲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(朱卷),
					result  => q(硃卷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(怒发冲冠),
					result  => q(怒髮衝冠),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(长发),
					result  => q(長髮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(短发),
					result  => q(短髮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(白发),
					result  => q(白髮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(黑发),
					result  => q(黑髮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(金发),
					result  => q(金髮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(红发),
					result  => q(紅髮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(銀发),
					result  => q(銀髮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(染发),
					result  => q(染髮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(编发),
					result  => q(編髮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(毫发),
					result  => q(毫髮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(护发),
					result  => q(護髮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(假发),
					result  => q(假髮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(结发),
					result  => q(結髮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(卷发),
					result  => q(捲髮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(理发),
					result  => q(理髮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(落发),
					result  => q(落髮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(毛发),
					result  => q(毛髮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(美发),
					result  => q(美髮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(散发),
					result  => q(散髮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(烫发),
					result  => q(燙髮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(势头),
					result  => q(勢頭),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(头发),
					result  => q(頭髮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(秀发),
					result  => q(秀髮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(剃髮),
					result  => q(剃发),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(一发),
					result  => q(一髮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(发),
					result  => q(發),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(人云亦云),
					result  => q(人云亦云),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(不知所云),
					result  => q(不知所云),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(云游),
					result  => q(雲遊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(云),
					result  => q(雲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(子丑寅卯),
					result  => q(子丑寅卯),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(生旦淨末丑),
					result  => q(生旦净末丑),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(丑时),
					result  => q(丑時),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(丑旦),
					result  => q(丑旦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(丑角),
					result  => q(丑角),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(小丑),
					result  => q(小丑),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(丑),
					result  => q(醜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(萝卜),
					result  => q(蘿蔔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(卜),
					result  => q(卜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(冲茶),
					result  => q(沖茶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(冲淡),
					result  => q(沖淡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(冲服),
					result  => q(沖服),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(冲积),
					result  => q(沖積),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(冲凉),
					result  => q(沖涼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(冲天),
					result  => q(沖天),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(冲绳),
					result  => q(沖繩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(冲洗),
					result  => q(沖洗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(冲毁),
					result  => q(沖毀),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(喜冲冲),
					result  => q(喜沖沖),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(冲),
					result  => q(衝),
					revisit => 0,
				},
				{
					before  => q([零一二三四五六七八九十百千万亿两]),
					after   => q(戏),
					replace => q(出),
					result  => q(齣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(出游),
					result  => q(出遊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(出),
					result  => q(出),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(线),
					result  => q(線),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(核实),
					result  => q(覈實),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(核算),
					result  => q(覈算),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(核),
					result  => q(核),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(回路),
					result  => q(迴路),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(回廊),
					result  => q(迴廊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(回游),
					result  => q(回遊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(萦回),
					result  => q(縈迴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(迂回),
					result  => q(迂迴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(回),
					result  => q(回),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(冬冬),
					result  => q(鼕鼕),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(冬),
					result  => q(冬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(咸菜),
					result  => q(鹹菜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(咸),
					result  => q(咸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(清心寡欲),
					result  => q(清心寡慾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(克欲修行),
					result  => q(克慾修行),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(欲不可纵),
					result  => q(慾不可縱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(人之大欲),
					result  => q(人之大慾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(求知欲),
					result  => q(求知慾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(欲火),
					result  => q(慾火),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(欲望),
					result  => q(慾望),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(禁欲),
					result  => q(禁慾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(利欲),
					result  => q(利慾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(情欲),
					result  => q(情慾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(肉欲),
					result  => q(肉慾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(色欲),
					result  => q(色慾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(食欲),
					result  => q(食慾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(私欲),
					result  => q(私慾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(兽欲),
					result  => q(獸慾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(纵欲),
					result  => q(縱慾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(性欲),
					result  => q(性慾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(六欲),
					result  => q(六慾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(嗜欲),
					result  => q(嗜慾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(欲),
					result  => q(欲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(准绳),
					result  => q(準繩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(准时),
					result  => q(準時),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(准头),
					result  => q(準頭),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(准备),
					result  => q(準備),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(准确),
					result  => q(準確),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(为准),
					result  => q(為準),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(标准),
					result  => q(標準),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(标签),
					result  => q(標籤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(水准),
					result  => q(水準),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(基准),
					result  => q(基準),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(对准),
					result  => q(對準),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(准),
					result  => q(准),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(标),
					result  => q(標),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(注册),
					result  => q(註冊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(注销),
					result  => q(註銷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(注解),
					result  => q(註解),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(注疏),
					result  => q(註疏),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(评注),
					result  => q(評註),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(附注),
					result  => q(附註),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(加注),
					result  => q(加註),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(注),
					result  => q(注),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(凶暴),
					result  => q(兇暴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(凶器),
					result  => q(兇器),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(凶手),
					result  => q(兇手),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(元凶),
					result  => q(元兇),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(正凶),
					result  => q(正兇),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(逞凶),
					result  => q(逞兇),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(凶),
					result  => q(凶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(扬),
					result  => q(揚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(飏),
					result  => q(颺),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(宴),
					result  => q(宴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(䜩),
					result  => q(讌),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(咬),
					result  => q(咬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(豆),
					result  => q(豆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(韭),
					result  => q(韭),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(笺),
					result  => q(箋),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(团),
					result  => q(團),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(卤鸡),
					result  => q(滷雞),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(卤味),
					result  => q(滷味),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(卤菜),
					result  => q(滷菜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(茶卤),
					result  => q(茶滷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(盐卤),
					result  => q(鹽滷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(卤),
					result  => q(鹵),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(呆),
					result  => q(呆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(泛),
					result  => q(泛),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(妫),
					result  => q(媯),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(众),
					result  => q(眾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(钩),
					result  => q(鈎),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(绱),
					result  => q(緔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(锐),
					result  => q(銳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(赝),
					result  => q(贋),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(赃),
					result  => q(贓),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(粗),
					result  => q(粗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(关),
					result  => q(關),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(饥),
					result  => q(飢),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(款),
					result  => q(款),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(胧),
					result  => q(朧),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(蒙),
					result  => q(蒙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(骂),
					result  => q(罵),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(脏),
					result  => q(臟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鳄),
					result  => q(鰐),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(凫),
					result  => q(鳧),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鸡),
					result  => q(雞),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(赍),
					result  => q(賫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(筘),
					result  => q(筘),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(吣),
					result  => q(唚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(群),
					result  => q(群),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(叹),
					result  => q(嘆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(剃),
					result  => q(剃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(颓),
					result  => q(頹),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(颜),
					result  => q(顏),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(炮),
					result  => q(炮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(启),
					result  => q(啓),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(茶几),
					result  => q(茶几),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(几),
					result  => q(幾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(德),
					result  => q(德),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(悫),
					result  => q(愨),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(克),
					result  => q(克),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(坛坛罐罐),
					result  => q(罈罈罐罐),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(瓶瓶坛坛),
					result  => q(瓶瓶罈罈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(醋坛),
					result  => q(醋罈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(坛子),
					result  => q(罈子),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(酒坛),
					result  => q(酒罈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(坛),
					result  => q(壇),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(升华),
					result  => q(昇華),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(毕升),
					result  => q(畢昇),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(高升),
					result  => q(高昇),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(歌舞升平),
					result  => q(歌舞昇平),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(升),
					result  => q(升),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(伪),
					result  => q(偽),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(收获),
					result  => q(收穫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(获),
					result  => q(獲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(绦),
					result  => q(縧),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(绣),
					result  => q(繡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(钵),
					result  => q(鉢),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(蜡),
					result  => q(蠟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(采薪之忧),
					result  => q(采薪之憂),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(兴高采烈),
					result  => q(興高采烈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(无精打采),
					result  => q(無精打采),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(采风),
					result  => q(采風),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(风采),
					result  => q(風采),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(精采),
					result  => q(精采),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(神采),
					result  => q(神采),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(多采),
					result  => q(多采),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(喝采),
					result  => q(喝采),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(采缉),
					result  => q(采緝),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(彩),
					result  => q(彩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(䌽),
					result  => q(綵),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(采),
					result  => q(採),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(厕),
					result  => q(廁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(捣),
					result  => q(搗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(沩),
					result  => q(溈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(为),
					result  => q(為),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(产),
					result  => q(產),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(瘘),
					result  => q(瘻),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(灶),
					result  => q(灶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(绝),
					result  => q(絕),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(绿),
					result  => q(綠),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(绷),
					result  => q(繃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(凼),
					result  => q(凼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(床),
					result  => q(床),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(墙),
					result  => q(牆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(奖),
					result  => q(獎),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(眦),
					result  => q(眥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(秆),
					result  => q(稈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(耻),
					result  => q(恥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(苧),
					result  => q(薴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(苹),
					result  => q(蘋),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(蕴),
					result  => q(蘊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(说),
					result  => q(說),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(谣),
					result  => q(謠),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(谫),
					result  => q(謭),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(竖),
					result  => q(竪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(酝),
					result  => q(醖),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(录),
					result  => q(錄),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(锈),
					result  => q(鏽),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(镢),
					result  => q(鐝),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(阅),
					result  => q(閱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(妆),
					result  => q(妝),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(闲静),
					result  => q(閑靜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(闲居),
					result  => q(閑居),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(闲),
					result  => q(閒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(游山玩水),
					result  => q(遊山玩水),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(游伴),
					result  => q(遊伴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(游程),
					result  => q(遊程),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(游春),
					result  => q(遊春),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(游方),
					result  => q(遊方),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(游记),
					result  => q(遊記),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(游街),
					result  => q(遊街),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(游客),
					result  => q(遊客),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(游乐),
					result  => q(遊樂),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(游廊),
					result  => q(遊廊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(游牧),
					result  => q(遊牧),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(游人),
					result  => q(遊人),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(游子),
					result  => q(遊子),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(游侠),
					result  => q(遊俠),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(游民),
					result  => q(遊民),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(游荡),
					result  => q(遊蕩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(游说),
					result  => q(遊說),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(游仙),
					result  => q(遊仙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(游憩),
					result  => q(遊憩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(游闲),
					result  => q(遊閑),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(游戏),
					result  => q(遊戲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(游手),
					result  => q(遊手),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(游魂),
					result  => q(遊魂),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(游猎),
					result  => q(遊獵),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(游玩),
					result  => q(遊玩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(游园),
					result  => q(遊園),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(游遍),
					result  => q(遊遍),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(游兴),
					result  => q(遊興),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(游舫),
					result  => q(遊舫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(游艇),
					result  => q(遊艇),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(游艺),
					result  => q(遊藝),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(游行),
					result  => q(遊行),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(游览),
					result  => q(遊覽),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(游逛),
					result  => q(遊逛),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(游医),
					result  => q(遊醫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(游学),
					result  => q(遊學),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(畅游),
					result  => q(暢遊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(串游),
					result  => q(串遊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(春游),
					result  => q(春遊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(导游),
					result  => q(導遊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(交游),
					result  => q(交遊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(郊游),
					result  => q(郊遊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(倦游),
					result  => q(倦遊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(冶游),
					result  => q(冶遊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(漫游),
					result  => q(漫遊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(梦游),
					result  => q(夢遊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(嬉游),
					result  => q(嬉遊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(巡游),
					result  => q(巡遊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(环游),
					result  => q(環遊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(旅游),
					result  => q(旅遊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(浪游),
					result  => q(浪遊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(神游),
					result  => q(神遊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(秋游),
					result  => q(秋遊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(仙游),
					result  => q(仙遊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(遨游),
					result  => q(遨遊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(野游),
					result  => q(野遊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(夜游),
					result  => q(夜遊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(游),
					result  => q(游),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(表蒙子),
					result  => q(錶蒙子),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(表带),
					result  => q(錶帶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(表链),
					result  => q(錶鏈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(表盘),
					result  => q(錶盤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(表针),
					result  => q(錶針),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(电子表),
					result  => q(電子錶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(电度表),
					result  => q(電鍍錶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(防水表),
					result  => q(防水錶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(马蹄表),
					result  => q(馬蹄錶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(夜光表),
					result  => q(夜光錶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(挂表),
					result  => q(掛錶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(怀表),
					result  => q(懷錶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(秒表),
					result  => q(秒錶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(马表),
					result  => q(馬錶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(钟表),
					result  => q(鐘錶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(跑表),
					result  => q(跑錶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(手表),
					result  => q(手錶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(停表),
					result  => q(停錶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(表),
					result  => q(表),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(症结),
					result  => q(癥結),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(症),
					result  => q(症),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(痴),
					result  => q(痴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(白洋淀),
					result  => q(白洋淀),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(荷花淀),
					result  => q(荷花淀),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(水淀),
					result  => q(水淀),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(海淀),
					result  => q(海淀),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(东淀),
					result  => q(東淀),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(淀),
					result  => q(澱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(向导),
					result  => q(嚮導),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(向往),
					result  => q(嚮往),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(向),
					result  => q(向),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(扎营),
					result  => q(紮營),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(驻扎),
					result  => q(駐紮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(扎),
					result  => q(扎),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(占卜),
					result  => q(占卜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(占卦),
					result  => q(占卦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(占梦),
					result  => q(占夢),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(占星),
					result  => q(占星),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(占),
					result  => q(佔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(托名),
					result  => q(託名),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(托收),
					result  => q(託收),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(信托),
					result  => q(信託),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(委托),
					result  => q(委託),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(拜托),
					result  => q(拜託),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(付托),
					result  => q(付託),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(寄托),
					result  => q(寄託),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(请托),
					result  => q(請託),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(受托),
					result  => q(受託),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(依托),
					result  => q(依託),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(嘱托),
					result  => q(囑託),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(转托),
					result  => q(轉託),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(托),
					result  => q(托),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(讬),
					result  => q(託),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(涌),
					result  => q(湧),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(累),
					result  => q(累),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(困惫),
					result  => q(睏憊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(困乏),
					result  => q(睏乏),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(困),
					result  => q(困),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(左邻右舍),
					result  => q(左鄰右舍),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(舍利),
					result  => q(舍利),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(舍弟),
					result  => q(舍弟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(宿舍),
					result  => q(宿舍),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(屋舍),
					result  => q(屋舍),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(田舍),
					result  => q(田舍),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(校舍),
					result  => q(校舍),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(民舍),
					result  => q(民舍),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(茅舍),
					result  => q(茅舍),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(老舍),
					result  => q(老舍),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(房舍),
					result  => q(房舍),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(农舍),
					result  => q(農舍),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(猪舍),
					result  => q(豬舍),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(舍),
					result  => q(捨),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(杠),
					result  => q(槓),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(雇员),
					result  => q(僱員),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(雇),
					result  => q(雇),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(刮倒),
					result  => q(颳倒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(刮),
					result  => q(刮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(狸),
					result  => q(狸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(跌交),
					result  => q(跌跤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(交),
					result  => q(交),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(侄媳妇),
					result  => q(姪媳婦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(侄女),
					result  => q(姪女),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(侄孙),
					result  => q(姪孫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(侄),
					result  => q(侄),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(勋),
					result  => q(勳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(秋千),
					result  => q(鞦韆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(荡秋千),
					result  => q(盪鞦韆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(荡),
					result  => q(蕩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(秋),
					result  => q(秋),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(不寒而栗),
					result  => q(不寒而慄),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(颤栗),
					result  => q(顫慄),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(战栗),
					result  => q(戰慄),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(栗),
					result  => q(栗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(细嚼慢咽),
					result  => q(細嚼慢嚥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(狼吞虎咽),
					result  => q(狼吞虎嚥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(咽气),
					result  => q(嚥氣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(下咽),
					result  => q(下嚥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(咽),
					result  => q(咽),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(吊民伐罪),
					result  => q(弔民伐罪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(形影相吊),
					result  => q(形影相弔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(提心吊胆),
					result  => q(提心弔膽),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(吊丧),
					result  => q(弔喪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(吊慰),
					result  => q(弔慰),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(吊唁),
					result  => q(弔唁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(吊),
					result  => q(吊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(英寸),
					result  => q(英吋),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(方腊),
					result  => q(方腊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(腊),
					result  => q(臘),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(乡愿),
					result  => q(鄉愿),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(愿),
					result  => q(願),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(古迹),
					result  => q(古蹟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(史迹),
					result  => q(史蹟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(迹),
					result  => q(跡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(净),
					result  => q(淨),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(侥幸),
					result  => q(僥倖),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(侥),
					result  => q(僥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(幸),
					result  => q(幸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(蚝),
					result  => q(蠔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(柜柳),
					result  => q(柜柳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(柜),
					result  => q(櫃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(拉纤),
					result  => q(拉縴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(纤夫),
					result  => q(縴夫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(纤路),
					result  => q(縴路),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(纤绳),
					result  => q(縴繩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(纤),
					result  => q(纖),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(厚朴),
					result  => q(厚朴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(朴刀),
					result  => q(朴刀),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(朴硝),
					result  => q(朴硝),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(朴),
					result  => q(樸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(钟灵毓秀),
					result  => q(鍾靈毓秀),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(一见钟情),
					result  => q(一見鍾情),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(千钟粟),
					result  => q(千鍾粟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(龙钟),
					result  => q(龍鍾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(独钟),
					result  => q(獨鍾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(汉钟离),
					result  => q(漢鍾離),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(所钟),
					result  => q(所鍾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(钟离),
					result  => q(鍾離),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(钟爱),
					result  => q(鍾愛),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(钟馗),
					result  => q(鍾馗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(钟山),
					result  => q(鍾山),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(钟),
					result  => q(鐘),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(锺),
					result  => q(鍾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(沾恩),
					result  => q(霑恩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(沾霈),
					result  => q(霑霈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(沾濡),
					result  => q(霑濡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(沾渥),
					result  => q(霑渥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(沾衣),
					result  => q(霑衣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(沾醉),
					result  => q(霑醉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(著名),
					result  => q(著名),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(著称),
					result  => q(著稱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(著述),
					result  => q(著述),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(著作),
					result  => q(著作),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(著书),
					result  => q(著書),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(著绩),
					result  => q(著績),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(著录),
					result  => q(著錄),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(著文),
					result  => q(著文),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(著有),
					result  => q(著有),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(著者),
					result  => q(著者),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(见微知著),
					result  => q(見微知著),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(信义素著),
					result  => q(信義素著),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(显著),
					result  => q(顯著),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(论著),
					result  => q(論著),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(编著),
					result  => q(編著),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(炳著),
					result  => q(炳著),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(昭著),
					result  => q(昭著),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(大著),
					result  => q(大著),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(合著),
					result  => q(合著),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(巨著),
					result  => q(巨著),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(钜著),
					result  => q(鉅著),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(较著),
					result  => q(較著),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(旧著),
					result  => q(舊著),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(毛著),
					result  => q(毛著),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(名著),
					result  => q(名著),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(暴著),
					result  => q(暴著),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(卓著),
					result  => q(卓著),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(土著),
					result  => q(土著),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(新著),
					result  => q(新著),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(玄著),
					result  => q(玄著),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(遗著),
					result  => q(遺著),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(译著),
					result  => q(譯著),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(原著),
					result  => q(原著),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(专著),
					result  => q(專著),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(撰著),
					result  => q(撰著),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(拙著),
					result  => q(拙著),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(着),
					result  => q(著),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(著),
					result  => q(著),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(扭转乾坤),
					result  => q(扭轉乾坤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(旋乾转坤),
					result  => q(旋乾轉坤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(朗朗乾坤),
					result  => q(朗朗乾坤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(搜罗),
					result  => q(蒐羅),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(搜集),
					result  => q(蒐集),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(搜录),
					result  => q(蒐錄),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(搜),
					result  => q(搜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(抽签),
					result  => q(抽籤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(签诗),
					result  => q(籤詩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(签条),
					result  => q(籤條),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(签筒),
					result  => q(籤筒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(签文),
					result  => q(籤文),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(签语),
					result  => q(籤語),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(求签),
					result  => q(求籤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(竹签),
					result  => q(竹籤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(芸签缥带),
					result  => q(芸籤縹帶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(芸),
					result  => q(芸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(万签插架),
					result  => q(萬籤插架),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(万),
					result  => q(萬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(解签),
					result  => q(解籤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(签谱),
					result  => q(籤譜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(中签),
					result  => q(中籤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(签),
					result  => q(簽),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(炼石补天),
					result  => q(鍊石補天),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(炼而愈精),
					result  => q(鍊而愈精),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(久炼成钢),
					result  => q(久鍊成鋼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(千锤百炼),
					result  => q(千錘百鍊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(百炼),
					result  => q(百鍊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(炼铝),
					result  => q(鍊鋁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(炼铜),
					result  => q(鍊銅),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(炼句),
					result  => q(鍊句),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(淬炼),
					result  => q(焠鍊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(锻炼),
					result  => q(鍛鍊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(锤炼),
					result  => q(錘鍊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(锤),
					result  => q(錘),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(金链),
					result  => q(金鍊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(链子),
					result  => q(鍊子),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(拉链),
					result  => q(拉鍊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(手链),
					result  => q(手鍊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(铁链),
					result  => q(鐵鍊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(项链),
					result  => q(項鍊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(炼),
					result  => q(煉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(练),
					result  => q(練),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(链),
					result  => q(鏈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(荧光),
					result  => q(螢光),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(荧幕),
					result  => q(螢幕),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(荧屏),
					result  => q(螢屏),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(荧),
					result  => q(熒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(萤),
					result  => q(螢),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(霉),
					result  => q(霉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(艳),
					result  => q(艷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(证),
					result  => q(證),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(尝),
					result  => q(嘗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(吃),
					result  => q(吃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(铺),
					result  => q(鋪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(唇),
					result  => q(唇),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(壳),
					result  => q(殼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(遁),
					result  => q(遁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(姐),
					result  => q(姐),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(污),
					result  => q(污),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(个),
					result  => q(個),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(哗),
					result  => q(嘩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(焊),
					result  => q(焊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(馈),
					result  => q(饋),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(梁),
					result  => q(梁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(具),
					result  => q(具),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(私),
					result  => q(私),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鉴),
					result  => q(鑒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(湿),
					result  => q(濕),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(局),
					result  => q(局),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(钜),
					result  => q(鉅),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(啰),
					result  => q(囉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(袅),
					result  => q(裊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(叠),
					result  => q(疊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(钳),
					result  => q(鉗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(镕),
					result  => q(鎔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(沙金),
					result  => q(砂金),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(沙土),
					result  => q(砂土),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(相片),
					result  => q(像片),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(毁),
					result  => q(毀),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(虱目鱼),
					result  => q(虱目魚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(虱),
					result  => q(蝨),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(赞),
					result  => q(贊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(绔),
					result  => q(絝),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(绉褶),
					result  => q(縐摺),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(皱褶),
					result  => q(皺摺),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(折纸),
					result  => q(摺紙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(绉),
					result  => q(縐),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(五岳),
					result  => q(五嶽),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(东岳),
					result  => q(東嶽),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(南岳),
					result  => q(南嶽),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(西岳),
					result  => q(西嶽),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(北岳),
					result  => q(北嶽),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(山岳),
					result  => q(山嶽),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(中岳),
					result  => q(中嶽),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(岱岳),
					result  => q(岱嶽),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(奇岩),
					result  => q(奇巖),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(峭壁巉岩),
					result  => q(峭壁巉巖),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(岩穴),
					result  => q(巖穴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(凿岩成室),
					result  => q(鑿巖成室),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(凿通岩洞),
					result  => q(鑿通巖洞),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(掸),
					result  => q(撣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(久病不愈),
					result  => q(久病不癒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(不药而愈),
					result  => q(不藥而癒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(固疾痊愈),
					result  => q(固疾痊癒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(疗愈),
					result  => q(療癒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(愈复),
					result  => q(癒復),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(病愈),
					result  => q(病癒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(痊愈),
					result  => q(痊癒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(治愈),
					result  => q(治癒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(棂),
					result  => q(櫺),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(呼吁),
					result  => q(呼籲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(吁求),
					result  => q(籲求),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(吁请),
					result  => q(籲請),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(吁防),
					result  => q(籲防),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(叮当),
					result  => q(叮噹),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(叮叮当当),
					result  => q(叮叮噹噹),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(疏浚),
					result  => q(疏濬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(铲),
					result  => q(鏟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(炭烟),
					result  => q(碳煙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(烟熏),
					result  => q(煙薰),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(烟),
					result  => q(煙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(羡),
					result  => q(羨),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(徭役),
					result  => q(繇役),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(弥漫),
					result  => q(瀰漫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(弥),
					result  => q(彌),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(谘),
					result  => q(諮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(缰),
					result  => q(繮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(昵),
					result  => q(暱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(瓮),
					result  => q(甕),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(名噪一时),
					result  => q(名譟一時),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鼓噪),
					result  => q(鼓譟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(礴),
					result  => q(礡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(膻),
					result  => q(羶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(蝎),
					result  => q(蠍),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(棱),
					result  => q(稜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(喂),
					result  => q(餵),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(腌),
					result  => q(醃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(排泄),
					result  => q(排泄),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(泄),
					result  => q(洩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(昌言),
					result  => q(倡言),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(依傍),
					result  => q(依徬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(彷),
					result  => q(徬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(仿如),
					result  => q(彷如),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(仿佛),
					result  => q(彷彿),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(仿),
					result  => q(仿),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(抚恤),
					result  => q(撫卹),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(恤养),
					result  => q(卹養),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(啮),
					result  => q(嚙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(敛),
					result  => q(斂),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(埙),
					result  => q(塤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(构),
					result  => q(構),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鳌),
					result  => q(鰲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(珐琅),
					result  => q(琺瑯),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(谥),
					result  => q(謚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(蓝),
					result  => q(藍),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(缕),
					result  => q(縷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(褴),
					result  => q(襤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(褛),
					result  => q(褸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(挂碍),
					result  => q(罣礙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(挂),
					result  => q(掛),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(积肴于案),
					result  => q(積餚於案),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(佳肴),
					result  => q(佳餚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(酒肴),
					result  => q(酒餚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(肴馔),
					result  => q(餚饌),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(菜肴),
					result  => q(菜餚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(枪),
					result  => q(槍),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鳖),
					result  => q(鱉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(睾),
					result  => q(睪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(镌),
					result  => q(鐫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(于),
					result  => q(於),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(亘),
					result  => q(亙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(铝),
					result  => q(鋁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(极),
					result  => q(極),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(锨),
					result  => q(鍁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(咏),
					result  => q(詠),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(琼),
					result  => q(瓊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(莼),
					result  => q(蒓),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鲞),
					result  => q(鮝),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鹚),
					result  => q(鷀),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(种),
					result  => q(種),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(妒),
					result  => q(妒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(和),
					result  => q(和),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(傥),
					result  => q(儻),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(倘),
					result  => q(倘),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(硷),
					result  => q(礆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鲇),
					result  => q(鮎),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(㟆),
					result  => q(㠏),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(㨫),
					result  => q(㩜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(䌶),
					result  => q(䊷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(䌺),
					result  => q(䋙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(䌾),
					result  => q(䋻),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(䞍),
					result  => q(䝼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(䯅),
					result  => q(䯀),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(䲝),
					result  => q(䱽),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鲃),
					result  => q(䰾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鳚),
					result  => q(䲁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(丢),
					result  => q(丟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(乱),
					result  => q(亂),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(亚),
					result  => q(亞),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(卧),
					result  => q(臥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(伫),
					result  => q(佇),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(来),
					result  => q(來),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(侣),
					result  => q(侶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(俣),
					result  => q(俁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(伣),
					result  => q(俔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(侠),
					result  => q(俠),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(伥),
					result  => q(倀),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(俩),
					result  => q(倆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(俫),
					result  => q(倈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(仓),
					result  => q(倉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(们),
					result  => q(們),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(伦),
					result  => q(倫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(伟),
					result  => q(偉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(侧),
					result  => q(側),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(侦),
					result  => q(偵),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(杰),
					result  => q(傑),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(伧),
					result  => q(傖),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(伞),
					result  => q(傘),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(备),
					result  => q(備),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(佣),
					result  => q(傭),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(偬),
					result  => q(傯),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(传),
					result  => q(傳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(伛),
					result  => q(傴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(债),
					result  => q(債),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(伤),
					result  => q(傷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(倾),
					result  => q(傾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(偻),
					result  => q(僂),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(仅),
					result  => q(僅),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(佥),
					result  => q(僉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(侨),
					result  => q(僑),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(仆),
					result  => q(僕),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(偾),
					result  => q(僨),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(价),
					result  => q(價),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(仪),
					result  => q(儀),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(侬),
					result  => q(儂),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(亿),
					result  => q(億),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(侩),
					result  => q(儈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(俭),
					result  => q(儉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(傧),
					result  => q(儐),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(俦),
					result  => q(儔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(侪),
					result  => q(儕),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(偿),
					result  => q(償),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(优),
					result  => q(優),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(储),
					result  => q(儲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(俪),
					result  => q(儷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(㑩),
					result  => q(儸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(傩),
					result  => q(儺),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(俨),
					result  => q(儼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(丰标不凡),
					result  => q(丰標不凡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([度情茸姿神采]),
					replace => q(丰),
					result  => q(丰),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(丰仪),
					result  => q(丰儀),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(丰韵),
					result  => q(丰韻),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(张三丰),
					result  => q(張三丰),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(丰),
					result  => q(豐),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(兑),
					result  => q(兌),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(儿),
					result  => q(兒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(兖),
					result  => q(兗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(内),
					result  => q(內),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(两),
					result  => q(兩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(册),
					result  => q(冊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(幂),
					result  => q(冪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(冻),
					result  => q(凍),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(凛),
					result  => q(凜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(凯),
					result  => q(凱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(删),
					result  => q(刪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(刭),
					result  => q(剄),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(则),
					result  => q(則),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(刹),
					result  => q(剎),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(刬),
					result  => q(剗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(刚),
					result  => q(剛),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(剥),
					result  => q(剝),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(剐),
					result  => q(剮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(剀),
					result  => q(剴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(创),
					result  => q(創),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(剧),
					result  => q(劇),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(刘),
					result  => q(劉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(刽),
					result  => q(劊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(刿),
					result  => q(劌),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(剑),
					result  => q(劍),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(㓥),
					result  => q(劏),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(剂),
					result  => q(劑),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(㔉),
					result  => q(劚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(劲),
					result  => q(勁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(动),
					result  => q(動),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(务),
					result  => q(務),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(胜),
					result  => q(勝),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(劳),
					result  => q(勞),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(势),
					result  => q(勢),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(勚),
					result  => q(勩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(劢),
					result  => q(勱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(励),
					result  => q(勵),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(劝),
					result  => q(勸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(匀),
					result  => q(勻),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(匦),
					result  => q(匭),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(匮),
					result  => q(匱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(区),
					result  => q(區),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(协),
					result  => q(協),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(却),
					result  => q(卻),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(厍),
					result  => q(厙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(厌),
					result  => q(厭),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(厉),
					result  => q(厲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(厣),
					result  => q(厴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(参),
					result  => q(參),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(叁),
					result  => q(叄),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(丛),
					result  => q(叢),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(咤),
					result  => q(吒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(吴),
					result  => q(吳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(呐),
					result  => q(吶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(吕),
					result  => q(呂),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(呙),
					result  => q(咼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(员),
					result  => q(員),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(呗),
					result  => q(唄),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(问),
					result  => q(問),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(哑),
					result  => q(啞),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(唡),
					result  => q(啢),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(㖞),
					result  => q(喎),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(唤),
					result  => q(喚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(丧),
					result  => q(喪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(乔),
					result  => q(喬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(单),
					result  => q(單),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(哟),
					result  => q(喲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(呛),
					result  => q(嗆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(啬),
					result  => q(嗇),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(唝),
					result  => q(嗊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(吗),
					result  => q(嗎),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(呜),
					result  => q(嗚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(唢),
					result  => q(嗩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(哔),
					result  => q(嗶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(喽),
					result  => q(嘍),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(呕),
					result  => q(嘔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(啧),
					result  => q(嘖),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(唛),
					result  => q(嘜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(唠),
					result  => q(嘮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(啸),
					result  => q(嘯),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(叽),
					result  => q(嘰),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(哓),
					result  => q(嘵),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(呒),
					result  => q(嘸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(啴),
					result  => q(嘽),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(嘘),
					result  => q(噓),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(㖊),
					result  => q(噚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(咝),
					result  => q(噝),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(哒),
					result  => q(噠),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(哝),
					result  => q(噥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(哕),
					result  => q(噦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(嗳),
					result  => q(噯),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(哙),
					result  => q(噲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(喷),
					result  => q(噴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(吨),
					result  => q(噸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(咛),
					result  => q(嚀),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(吓),
					result  => q(嚇),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(哜),
					result  => q(嚌),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(噜),
					result  => q(嚕),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(呖),
					result  => q(嚦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(咙),
					result  => q(嚨),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(亸),
					result  => q(嚲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(喾),
					result  => q(嚳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(严),
					result  => q(嚴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(嘤),
					result  => q(嚶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(啭),
					result  => q(囀),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(嗫),
					result  => q(囁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(嚣),
					result  => q(囂),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(冁),
					result  => q(囅),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(呓),
					result  => q(囈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(嘱),
					result  => q(囑),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(囱),
					result  => q(囪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(囵),
					result  => q(圇),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(国),
					result  => q(國),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(围),
					result  => q(圍),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(园),
					result  => q(園),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(圆),
					result  => q(圓),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(图),
					result  => q(圖),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(埯),
					result  => q(垵),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(垭),
					result  => q(埡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(执),
					result  => q(執),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(坚),
					result  => q(堅),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(垩),
					result  => q(堊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(垴),
					result  => q(堖),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(埚),
					result  => q(堝),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(尧),
					result  => q(堯),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(报),
					result  => q(報),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(场),
					result  => q(場),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(块),
					result  => q(塊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(茔),
					result  => q(塋),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(垲),
					result  => q(塏),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(埘),
					result  => q(塒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(涂),
					result  => q(塗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(坞),
					result  => q(塢),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(尘),
					result  => q(塵),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(堑),
					result  => q(塹),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(垫),
					result  => q(墊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(坠),
					result  => q(墜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(堕),
					result  => q(墮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(坟),
					result  => q(墳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(垦),
					result  => q(墾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(垱),
					result  => q(壋),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(压),
					result  => q(壓),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(垒),
					result  => q(壘),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(圹),
					result  => q(壙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(垆),
					result  => q(壚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(坏),
					result  => q(壞),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(垄),
					result  => q(壟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(垅),
					result  => q(壠),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(坜),
					result  => q(壢),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(坝),
					result  => q(壩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(壮),
					result  => q(壯),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(壶),
					result  => q(壺),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(壸),
					result  => q(壼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(寿),
					result  => q(壽),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(够),
					result  => q(夠),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(梦),
					result  => q(夢),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(夹),
					result  => q(夾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(奂),
					result  => q(奐),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(奥),
					result  => q(奧),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(奁),
					result  => q(奩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(夺),
					result  => q(奪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(奋),
					result  => q(奮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(姹),
					result  => q(奼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(姗),
					result  => q(姍),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(娱),
					result  => q(娛),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(娄),
					result  => q(婁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(妇),
					result  => q(婦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(娅),
					result  => q(婭),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(娲),
					result  => q(媧),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(媪),
					result  => q(媼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(妈),
					result  => q(媽),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(妪),
					result  => q(嫗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(妩),
					result  => q(嫵),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(娴),
					result  => q(嫻),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(婳),
					result  => q(嫿),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(娆),
					result  => q(嬈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(婵),
					result  => q(嬋),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(娇),
					result  => q(嬌),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(嫱),
					result  => q(嬙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(嫒),
					result  => q(嬡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(嬷),
					result  => q(嬤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(嫔),
					result  => q(嬪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(婴),
					result  => q(嬰),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(婶),
					result  => q(嬸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(娈),
					result  => q(孌),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(孙),
					result  => q(孫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(学),
					result  => q(學),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(孪),
					result  => q(孿),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(宫),
					result  => q(宮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(寝),
					result  => q(寢),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(实),
					result  => q(實),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(宁),
					result  => q(寧),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(审),
					result  => q(審),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(写),
					result  => q(寫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(宽),
					result  => q(寬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(宠),
					result  => q(寵),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(宝),
					result  => q(寶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(将),
					result  => q(將),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(专),
					result  => q(專),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(寻),
					result  => q(尋),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(对),
					result  => q(對),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(导),
					result  => q(導),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(尴),
					result  => q(尷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(届),
					result  => q(屆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(尸),
					result  => q(屍),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(屃),
					result  => q(屓),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(屉),
					result  => q(屜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(屡),
					result  => q(屢),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(层),
					result  => q(層),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(屦),
					result  => q(屨),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(属),
					result  => q(屬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(冈),
					result  => q(岡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(岘),
					result  => q(峴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(岛),
					result  => q(島),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(峡),
					result  => q(峽),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(崃),
					result  => q(崍),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(岗),
					result  => q(崗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(峥),
					result  => q(崢),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(岽),
					result  => q(崬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(岚),
					result  => q(嵐),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(嵝),
					result  => q(嶁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(崭),
					result  => q(嶄),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(岖),
					result  => q(嶇),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(嵚),
					result  => q(嶔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(崂),
					result  => q(嶗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(峤),
					result  => q(嶠),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(峣),
					result  => q(嶢),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(峄),
					result  => q(嶧),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(崄),
					result  => q(嶮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(岙),
					result  => q(嶴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(嵘),
					result  => q(嶸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(岭),
					result  => q(嶺),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(屿),
					result  => q(嶼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(岿),
					result  => q(巋),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(峦),
					result  => q(巒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(巅),
					result  => q(巔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(巯),
					result  => q(巰),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(帅),
					result  => q(帥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(师),
					result  => q(師),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(帐),
					result  => q(帳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(带),
					result  => q(帶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(帧),
					result  => q(幀),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(帏),
					result  => q(幃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(帼),
					result  => q(幗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(帻),
					result  => q(幘),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(帜),
					result  => q(幟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(币),
					result  => q(幣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(帮),
					result  => q(幫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(帱),
					result  => q(幬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(库),
					result  => q(庫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(厢),
					result  => q(廂),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(厩),
					result  => q(廄),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(厦),
					result  => q(廈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(厨),
					result  => q(廚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(厮),
					result  => q(廝),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(庙),
					result  => q(廟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(厂),
					result  => q(廠),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(庑),
					result  => q(廡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(废),
					result  => q(廢),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(广),
					result  => q(廣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(廪),
					result  => q(廩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(庐),
					result  => q(廬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(厅),
					result  => q(廳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(弑),
					result  => q(弒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(弪),
					result  => q(弳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(张),
					result  => q(張),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(强),
					result  => q(強),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(弹),
					result  => q(彈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(弯),
					result  => q(彎),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(彦),
					result  => q(彥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(径),
					result  => q(徑),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(从),
					result  => q(從),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(徕),
					result  => q(徠),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(彻),
					result  => q(徹),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(恒),
					result  => q(恆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(悦),
					result  => q(悅),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(悮),
					result  => q(悞),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(怅),
					result  => q(悵),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(闷),
					result  => q(悶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(恶),
					result  => q(惡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(恼),
					result  => q(惱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(恽),
					result  => q(惲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(恻),
					result  => q(惻),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(爱),
					result  => q(愛),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(惬),
					result  => q(愜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(怆),
					result  => q(愴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(恺),
					result  => q(愷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(忾),
					result  => q(愾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(态),
					result  => q(態),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(愠),
					result  => q(慍),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(惨),
					result  => q(慘),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(惭),
					result  => q(慚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(恸),
					result  => q(慟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(惯),
					result  => q(慣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(怄),
					result  => q(慪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(怂),
					result  => q(慫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(虑),
					result  => q(慮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(悭),
					result  => q(慳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(庆),
					result  => q(慶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(惫),
					result  => q(憊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(怜),
					result  => q(憐),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(凭),
					result  => q(憑),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(愦),
					result  => q(憒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(惮),
					result  => q(憚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(愤),
					result  => q(憤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(悯),
					result  => q(憫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(怃),
					result  => q(憮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(宪),
					result  => q(憲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(忆),
					result  => q(憶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(恳),
					result  => q(懇),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(应),
					result  => q(應),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(怿),
					result  => q(懌),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(懔),
					result  => q(懍),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(怼),
					result  => q(懟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(懑),
					result  => q(懣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(恹),
					result  => q(懨),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(惩),
					result  => q(懲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(懒),
					result  => q(懶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(怀),
					result  => q(懷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(悬),
					result  => q(懸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(忏),
					result  => q(懺),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(惧),
					result  => q(懼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(慑),
					result  => q(懾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(恋),
					result  => q(戀),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(戆),
					result  => q(戇),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(戋),
					result  => q(戔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(戗),
					result  => q(戧),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(戬),
					result  => q(戩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(战),
					result  => q(戰),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(戯),
					result  => q(戱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(戏),
					result  => q(戲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(户),
					result  => q(戶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(抛),
					result  => q(拋),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(捝),
					result  => q(挩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(挟),
					result  => q(挾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(扪),
					result  => q(捫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(扫),
					result  => q(掃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(抡),
					result  => q(掄),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(挜),
					result  => q(掗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(挣),
					result  => q(掙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(拣),
					result  => q(揀),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(换),
					result  => q(換),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(挥),
					result  => q(揮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(损),
					result  => q(損),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(摇),
					result  => q(搖),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(揾),
					result  => q(搵),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(抢),
					result  => q(搶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(掴),
					result  => q(摑),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(掼),
					result  => q(摜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(搂),
					result  => q(摟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(挚),
					result  => q(摯),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(抠),
					result  => q(摳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(抟),
					result  => q(摶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(掺),
					result  => q(摻),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(捞),
					result  => q(撈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(挦),
					result  => q(撏),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(撑),
					result  => q(撐),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(挠),
					result  => q(撓),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(㧑),
					result  => q(撝),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(挢),
					result  => q(撟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(拨),
					result  => q(撥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(抚),
					result  => q(撫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(扑),
					result  => q(撲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(揿),
					result  => q(撳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(挞),
					result  => q(撻),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(挝),
					result  => q(撾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(捡),
					result  => q(撿),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(拥),
					result  => q(擁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(掳),
					result  => q(擄),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(择),
					result  => q(擇),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(击),
					result  => q(擊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(挡),
					result  => q(擋),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(㧟),
					result  => q(擓),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(担),
					result  => q(擔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(据),
					result  => q(據),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(挤),
					result  => q(擠),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(拟),
					result  => q(擬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(摈),
					result  => q(擯),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(拧),
					result  => q(擰),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(搁),
					result  => q(擱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(掷),
					result  => q(擲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(扩),
					result  => q(擴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(撷),
					result  => q(擷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(摆),
					result  => q(擺),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(擞),
					result  => q(擻),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(撸),
					result  => q(擼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(扰),
					result  => q(擾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(摅),
					result  => q(攄),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(撵),
					result  => q(攆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(拢),
					result  => q(攏),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(拦),
					result  => q(攔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(撄),
					result  => q(攖),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(搀),
					result  => q(攙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(撺),
					result  => q(攛),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(携),
					result  => q(攜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(摄),
					result  => q(攝),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(攒),
					result  => q(攢),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(挛),
					result  => q(攣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(摊),
					result  => q(攤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(搅),
					result  => q(攪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(揽),
					result  => q(攬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(败),
					result  => q(敗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(叙),
					result  => q(敘),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(敌),
					result  => q(敵),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(数),
					result  => q(數),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(毙),
					result  => q(斃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(斓),
					result  => q(斕),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(斩),
					result  => q(斬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(断),
					result  => q(斷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(时),
					result  => q(時),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(晋),
					result  => q(晉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(昼),
					result  => q(晝),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(晕),
					result  => q(暈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(晖),
					result  => q(暉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(旸),
					result  => q(暘),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(畅),
					result  => q(暢),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(暂),
					result  => q(暫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(晔),
					result  => q(曄),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(昙),
					result  => q(曇),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(晓),
					result  => q(曉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(暧),
					result  => q(曖),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(旷),
					result  => q(曠),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(昽),
					result  => q(曨),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(晒),
					result  => q(曬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(书),
					result  => q(書),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(会),
					result  => q(會),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(东),
					result  => q(東),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(栅),
					result  => q(柵),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(杆),
					result  => q(桿),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(栀),
					result  => q(梔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(枧),
					result  => q(梘),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(条),
					result  => q(條),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(枭),
					result  => q(梟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(棁),
					result  => q(梲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(弃),
					result  => q(棄),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(枨),
					result  => q(棖),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(枣),
					result  => q(棗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(栋),
					result  => q(棟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(栈),
					result  => q(棧),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(栖),
					result  => q(棲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(梾),
					result  => q(棶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(桠),
					result  => q(椏),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(杨),
					result  => q(楊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(枫),
					result  => q(楓),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(桢),
					result  => q(楨),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(业),
					result  => q(業),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(杩),
					result  => q(榪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(荣),
					result  => q(榮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(榅),
					result  => q(榲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(桤),
					result  => q(榿),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(梿),
					result  => q(槤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(椠),
					result  => q(槧),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(椁),
					result  => q(槨),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(桨),
					result  => q(槳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(桩),
					result  => q(樁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(乐),
					result  => q(樂),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(枞),
					result  => q(樅),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(楼),
					result  => q(樓),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(枢),
					result  => q(樞),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(样),
					result  => q(樣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(树),
					result  => q(樹),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(桦),
					result  => q(樺),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(桡),
					result  => q(橈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(桥),
					result  => q(橋),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(椭),
					result  => q(橢),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(横),
					result  => q(橫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(檩),
					result  => q(檁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(柽),
					result  => q(檉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(档),
					result  => q(檔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(桧),
					result  => q(檜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(槚),
					result  => q(檟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(检),
					result  => q(檢),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(樯),
					result  => q(檣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(梼),
					result  => q(檮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(槟),
					result  => q(檳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(柠),
					result  => q(檸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(槛),
					result  => q(檻),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(橹),
					result  => q(櫓),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(榈),
					result  => q(櫚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(栉),
					result  => q(櫛),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(椟),
					result  => q(櫝),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(橼),
					result  => q(櫞),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(栎),
					result  => q(櫟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(橱),
					result  => q(櫥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(槠),
					result  => q(櫧),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(栌),
					result  => q(櫨),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(枥),
					result  => q(櫪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(橥),
					result  => q(櫫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(榇),
					result  => q(櫬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(蘖),
					result  => q(櫱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(栊),
					result  => q(櫳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(榉),
					result  => q(櫸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(樱),
					result  => q(櫻),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(栏),
					result  => q(欄),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(权),
					result  => q(權),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(椤),
					result  => q(欏),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(栾),
					result  => q(欒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(榄),
					result  => q(欖),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(钦),
					result  => q(欽),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(欧),
					result  => q(歐),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(欤),
					result  => q(歟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(欢),
					result  => q(歡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(岁),
					result  => q(歲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(归),
					result  => q(歸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(殁),
					result  => q(歿),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(残),
					result  => q(殘),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(殒),
					result  => q(殞),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(殇),
					result  => q(殤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(㱮),
					result  => q(殨),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(殚),
					result  => q(殫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(殓),
					result  => q(殮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(殡),
					result  => q(殯),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(㱩),
					result  => q(殰),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(歼),
					result  => q(殲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(杀),
					result  => q(殺),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(殴),
					result  => q(毆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(毵),
					result  => q(毿),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(牦),
					result  => q(氂),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(毡),
					result  => q(氈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(氇),
					result  => q(氌),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(氢),
					result  => q(氫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(氩),
					result  => q(氬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(氲),
					result  => q(氳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(郁金香),
					result  => q(鬱金香),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(郁闷),
					result  => q(鬱悶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(郁郁),
					result  => q(鬱鬱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(阴郁),
					result  => q(陰鬱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(沉郁),
					result  => q(沈鬱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(苍郁),
					result  => q(蒼鬱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(忧郁),
					result  => q(憂鬱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(悒郁),
					result  => q(悒鬱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(抑郁),
					result  => q(抑鬱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(积郁),
					result  => q(積鬱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(忧),
					result  => q(憂),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(沈大铁路),
					result  => q(瀋大鐵路),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(沈大高速),
					result  => q(瀋大高速),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(沈大线),
					result  => q(瀋大線),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(沈吉铁路),
					result  => q(瀋吉鐵路),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(沈吉高速),
					result  => q(瀋吉高速),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(沈吉线),
					result  => q(瀋吉線),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(沈山高速),
					result  => q(瀋山高速),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(沈山铁路),
					result  => q(瀋山鐵路),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(沈山线),
					result  => q(瀋山線),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(沈阳),
					result  => q(瀋陽),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(沈哈),
					result  => q(瀋哈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(京沈),
					result  => q(京瀋),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(辽沈),
					result  => q(遼瀋),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(墨渖未干),
					result  => q(墨瀋未乾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(渖),
					result  => q(瀋),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(石沉大海),
					result  => q(石沈大海),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鱼沉雁杳),
					result  => q(魚沈雁杳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(破釜沉舟),
					result  => q(破釜沈舟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(沉沉浮浮),
					result  => q(沈沈浮浮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(沉浮),
					result  => q(沈浮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(沉默),
					result  => q(沈默),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(沉重),
					result  => q(沈重),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(沉思),
					result  => q(沈思),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(沉淀),
					result  => q(沈澱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(沉稳),
					result  => q(沈穩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(沉浸),
					result  => q(沈浸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(沉闷),
					result  => q(沈悶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(沉静),
					result  => q(沈靜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(沉醉),
					result  => q(沈醉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(沉迷),
					result  => q(沈迷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(沉寂),
					result  => q(沈寂),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(沉入),
					result  => q(沈入),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(沉沉),
					result  => q(沈沈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(沉落),
					result  => q(沈落),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(沉睡),
					result  => q(沈睡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(沉潜),
					result  => q(沈潛),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(沉沦),
					result  => q(沈淪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(沉吟),
					result  => q(沈吟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(沉积),
					result  => q(沈積),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(沉着),
					result  => q(沈著),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(沉没),
					result  => q(沈沒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(低沉),
					result  => q(低沈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(消沉),
					result  => q(消沈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(深沉),
					result  => q(深沈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(浮沉),
					result  => q(浮沈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(沉),
					result  => q(沈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(决),
					result  => q(決),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(没),
					result  => q(沒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(况),
					result  => q(況),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(汹),
					result  => q(洶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(浃),
					result  => q(浹),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(泾),
					result  => q(涇),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(凄),
					result  => q(淒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(凉),
					result  => q(涼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(泪),
					result  => q(淚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(渌),
					result  => q(淥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(沦),
					result  => q(淪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(渊),
					result  => q(淵),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(涞),
					result  => q(淶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(浅),
					result  => q(淺),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(涣),
					result  => q(渙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(减),
					result  => q(減),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(涡),
					result  => q(渦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(测),
					result  => q(測),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(浑),
					result  => q(渾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(凑),
					result  => q(湊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(浈),
					result  => q(湞),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(汤),
					result  => q(湯),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(沟),
					result  => q(溝),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(温),
					result  => q(溫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(沧),
					result  => q(滄),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(灭),
					result  => q(滅),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(涤),
					result  => q(滌),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(荥),
					result  => q(滎),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(沪),
					result  => q(滬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(滞),
					result  => q(滯),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(渗),
					result  => q(滲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(浒),
					result  => q(滸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(浐),
					result  => q(滻),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(滚),
					result  => q(滾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(满),
					result  => q(滿),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(渔),
					result  => q(漁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(沤),
					result  => q(漚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(汉),
					result  => q(漢),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(涟),
					result  => q(漣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(渍),
					result  => q(漬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(涨),
					result  => q(漲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(溆),
					result  => q(漵),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(渐),
					result  => q(漸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(浆),
					result  => q(漿),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(颍),
					result  => q(潁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(泼),
					result  => q(潑),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(洁),
					result  => q(潔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(潜),
					result  => q(潛),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(润),
					result  => q(潤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(浔),
					result  => q(潯),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(溃),
					result  => q(潰),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(滗),
					result  => q(潷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(涠),
					result  => q(潿),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(涩),
					result  => q(澀),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(浇),
					result  => q(澆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(涝),
					result  => q(澇),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(涧),
					result  => q(澗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(渑),
					result  => q(澠),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(泽),
					result  => q(澤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(滪),
					result  => q(澦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(泶),
					result  => q(澩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(浍),
					result  => q(澮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(浊),
					result  => q(濁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(浓),
					result  => q(濃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(泞),
					result  => q(濘),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(济),
					result  => q(濟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(涛),
					result  => q(濤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(滥),
					result  => q(濫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(潍),
					result  => q(濰),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(滨),
					result  => q(濱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(溅),
					result  => q(濺),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(泺),
					result  => q(濼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(滤),
					result  => q(濾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(滢),
					result  => q(瀅),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(渎),
					result  => q(瀆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(㲿),
					result  => q(瀇),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(泻),
					result  => q(瀉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(浏),
					result  => q(瀏),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(濒),
					result  => q(瀕),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(泸),
					result  => q(瀘),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(沥),
					result  => q(瀝),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(潇),
					result  => q(瀟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(潆),
					result  => q(瀠),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(潴),
					result  => q(瀦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(泷),
					result  => q(瀧),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(濑),
					result  => q(瀨),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(潋),
					result  => q(瀲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(澜),
					result  => q(瀾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(沣),
					result  => q(灃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(滠),
					result  => q(灄),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(洒),
					result  => q(灑),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(漓),
					result  => q(灕),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(滩),
					result  => q(灘),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(灏),
					result  => q(灝),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(漤),
					result  => q(灠),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(湾),
					result  => q(灣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(滦),
					result  => q(灤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(滟),
					result  => q(灧),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(灾),
					result  => q(災),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(乌),
					result  => q(烏),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(烃),
					result  => q(烴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(无),
					result  => q(無),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(炜),
					result  => q(煒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(茕),
					result  => q(煢),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(焕),
					result  => q(煥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(烦),
					result  => q(煩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(炀),
					result  => q(煬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(㶽),
					result  => q(煱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(煴),
					result  => q(熅),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(炝),
					result  => q(熗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(热),
					result  => q(熱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(颎),
					result  => q(熲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(炽),
					result  => q(熾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(烨),
					result  => q(燁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(灯),
					result  => q(燈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(炖),
					result  => q(燉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(烧),
					result  => q(燒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(烫),
					result  => q(燙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(焖),
					result  => q(燜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(营),
					result  => q(營),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(灿),
					result  => q(燦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(烛),
					result  => q(燭),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(烩),
					result  => q(燴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(㶶),
					result  => q(燶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(烬),
					result  => q(燼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(焘),
					result  => q(燾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(烁),
					result  => q(爍),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(炉),
					result  => q(爐),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(烂),
					result  => q(爛),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(争),
					result  => q(爭),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(爷),
					result  => q(爺),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(尔),
					result  => q(爾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(牍),
					result  => q(牘),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(牵),
					result  => q(牽),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(荦),
					result  => q(犖),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(犊),
					result  => q(犢),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(牺),
					result  => q(犧),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(状),
					result  => q(狀),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(狭),
					result  => q(狹),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(狈),
					result  => q(狽),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(狰),
					result  => q(猙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(犹),
					result  => q(猶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(狲),
					result  => q(猻),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(犸),
					result  => q(獁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(狱),
					result  => q(獄),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(狮),
					result  => q(獅),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(独),
					result  => q(獨),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(狯),
					result  => q(獪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(猃),
					result  => q(獫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(狝),
					result  => q(獮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(狞),
					result  => q(獰),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(㺍),
					result  => q(獱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(猎),
					result  => q(獵),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(犷),
					result  => q(獷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(兽),
					result  => q(獸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(獭),
					result  => q(獺),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(献),
					result  => q(獻),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(猕),
					result  => q(獼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(猡),
					result  => q(玀),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(现),
					result  => q(現),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(珐),
					result  => q(琺),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(珲),
					result  => q(琿),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(玮),
					result  => q(瑋),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(玚),
					result  => q(瑒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(琐),
					result  => q(瑣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(瑶),
					result  => q(瑤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(莹),
					result  => q(瑩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(玛),
					result  => q(瑪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(玱),
					result  => q(瑲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(琏),
					result  => q(璉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(玑),
					result  => q(璣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(瑷),
					result  => q(璦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(珰),
					result  => q(璫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(环),
					result  => q(環),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(玺),
					result  => q(璽),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(珑),
					result  => q(瓏),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(璎),
					result  => q(瓔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(瓒),
					result  => q(瓚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(瓯),
					result  => q(甌),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(亩),
					result  => q(畝),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(毕),
					result  => q(畢),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(异),
					result  => q(異),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(畴),
					result  => q(疇),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(痉),
					result  => q(痙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(疴),
					result  => q(痾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(痖),
					result  => q(瘂),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(疯),
					result  => q(瘋),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(疡),
					result  => q(瘍),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(痪),
					result  => q(瘓),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(瘗),
					result  => q(瘞),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(疮),
					result  => q(瘡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(疟),
					result  => q(瘧),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(瘆),
					result  => q(瘮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(疭),
					result  => q(瘲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(疗),
					result  => q(療),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(痨),
					result  => q(癆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(痫),
					result  => q(癇),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(瘅),
					result  => q(癉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(疠),
					result  => q(癘),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(瘪),
					result  => q(癟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(痒),
					result  => q(癢),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(疖),
					result  => q(癤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(疬),
					result  => q(癧),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(癞),
					result  => q(癩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(癣),
					result  => q(癬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(瘿),
					result  => q(癭),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(瘾),
					result  => q(癮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(痈),
					result  => q(癰),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(瘫),
					result  => q(癱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(癫),
					result  => q(癲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(皑),
					result  => q(皚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(疱),
					result  => q(皰),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(皲),
					result  => q(皸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(皱),
					result  => q(皺),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(盗),
					result  => q(盜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(盏),
					result  => q(盞),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(监),
					result  => q(監),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(盘),
					result  => q(盤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(卢),
					result  => q(盧),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(睁),
					result  => q(睜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(睐),
					result  => q(睞),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(眍),
					result  => q(瞘),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(䁖),
					result  => q(瞜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(瞒),
					result  => q(瞞),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(瞆),
					result  => q(瞶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(睑),
					result  => q(瞼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(眬),
					result  => q(矓),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(瞩),
					result  => q(矚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(矫),
					result  => q(矯),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(硁),
					result  => q(硜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(硖),
					result  => q(硤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(砗),
					result  => q(硨),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(砚),
					result  => q(硯),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(硕),
					result  => q(碩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(砀),
					result  => q(碭),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(砜),
					result  => q(碸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(确),
					result  => q(確),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(码),
					result  => q(碼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(硙),
					result  => q(磑),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(砖),
					result  => q(磚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(碜),
					result  => q(磣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(碛),
					result  => q(磧),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(矶),
					result  => q(磯),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(硗),
					result  => q(磽),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(础),
					result  => q(礎),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(碍),
					result  => q(礙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(矿),
					result  => q(礦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(砺),
					result  => q(礪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(砾),
					result  => q(礫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(矾),
					result  => q(礬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(砻),
					result  => q(礱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(禄),
					result  => q(祿),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(祸),
					result  => q(禍),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(祯),
					result  => q(禎),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(祎),
					result  => q(禕),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(祃),
					result  => q(禡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(禅),
					result  => q(禪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(礼),
					result  => q(禮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(祢),
					result  => q(禰),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(祷),
					result  => q(禱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(秃),
					result  => q(禿),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(籼),
					result  => q(秈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(税),
					result  => q(稅),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(䅉),
					result  => q(稏),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(禀),
					result  => q(稟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(称),
					result  => q(稱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(稣),
					result  => q(穌),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(积),
					result  => q(積),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(颖),
					result  => q(穎),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(秾),
					result  => q(穠),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(穑),
					result  => q(穡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(秽),
					result  => q(穢),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(稳),
					result  => q(穩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(稆),
					result  => q(穭),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(窝),
					result  => q(窩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(洼),
					result  => q(窪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(穷),
					result  => q(窮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(窑),
					result  => q(窯),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(窎),
					result  => q(窵),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(窭),
					result  => q(窶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(窥),
					result  => q(窺),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(窜),
					result  => q(竄),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(窍),
					result  => q(竅),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(窦),
					result  => q(竇),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(窃),
					result  => q(竊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(竞),
					result  => q(競),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(笔),
					result  => q(筆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(笋),
					result  => q(筍),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(笕),
					result  => q(筧),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(䇲),
					result  => q(筴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(筝),
					result  => q(箏),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(节),
					result  => q(節),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(范),
					result  => q(範),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(筑),
					result  => q(築),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(箧),
					result  => q(篋),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(筼),
					result  => q(篔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(笃),
					result  => q(篤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(筛),
					result  => q(篩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(筚),
					result  => q(篳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(箦),
					result  => q(簀),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(篓),
					result  => q(簍),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(箪),
					result  => q(簞),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(简),
					result  => q(簡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(篑),
					result  => q(簣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(箫),
					result  => q(簫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(筜),
					result  => q(簹),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(帘),
					result  => q(簾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(篮),
					result  => q(籃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(筹),
					result  => q(籌),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(箓),
					result  => q(籙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(箨),
					result  => q(籜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(籁),
					result  => q(籟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(笼),
					result  => q(籠),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(笾),
					result  => q(籩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(簖),
					result  => q(籪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(篱),
					result  => q(籬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(箩),
					result  => q(籮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(粤),
					result  => q(粵),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(糁),
					result  => q(糝),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(粪),
					result  => q(糞),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(粮),
					result  => q(糧),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(粝),
					result  => q(糲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(籴),
					result  => q(糴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(粜),
					result  => q(糶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(纟),
					result  => q(糹),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(纠),
					result  => q(糾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(纪),
					result  => q(紀),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(纣),
					result  => q(紂),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(约),
					result  => q(約),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(红),
					result  => q(紅),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(纡),
					result  => q(紆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(纥),
					result  => q(紇),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(纨),
					result  => q(紈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(纫),
					result  => q(紉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(纹),
					result  => q(紋),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(纳),
					result  => q(納),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(纽),
					result  => q(紐),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(纾),
					result  => q(紓),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(纯),
					result  => q(純),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(纰),
					result  => q(紕),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(纼),
					result  => q(紖),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(纱),
					result  => q(紗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(纮),
					result  => q(紘),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(纸),
					result  => q(紙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(级),
					result  => q(級),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(纷),
					result  => q(紛),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(纭),
					result  => q(紜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(纴),
					result  => q(紝),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(纺),
					result  => q(紡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(䌷),
					result  => q(紬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(细),
					result  => q(細),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(绂),
					result  => q(紱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(绁),
					result  => q(紲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(绅),
					result  => q(紳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(纻),
					result  => q(紵),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(绍),
					result  => q(紹),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(绀),
					result  => q(紺),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(绋),
					result  => q(紼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(绐),
					result  => q(紿),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(绌),
					result  => q(絀),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(终),
					result  => q(終),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(组),
					result  => q(組),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(䌹),
					result  => q(絅),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(绊),
					result  => q(絆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(绗),
					result  => q(絎),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(结),
					result  => q(結),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(绞),
					result  => q(絞),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(络),
					result  => q(絡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(绚),
					result  => q(絢),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(给),
					result  => q(給),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(绒),
					result  => q(絨),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(绖),
					result  => q(絰),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(统),
					result  => q(統),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(丝),
					result  => q(絲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(绛),
					result  => q(絳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(绢),
					result  => q(絹),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(绑),
					result  => q(綁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(绡),
					result  => q(綃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(绠),
					result  => q(綆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(绨),
					result  => q(綈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(绤),
					result  => q(綌),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(绥),
					result  => q(綏),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(䌼),
					result  => q(綐),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(经),
					result  => q(經),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(综),
					result  => q(綜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(缍),
					result  => q(綞),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(绸),
					result  => q(綢),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(绻),
					result  => q(綣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(绶),
					result  => q(綬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(维),
					result  => q(維),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(绹),
					result  => q(綯),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(绾),
					result  => q(綰),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(纲),
					result  => q(綱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(网),
					result  => q(網),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(缀),
					result  => q(綴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(纶),
					result  => q(綸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(绺),
					result  => q(綹),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(绮),
					result  => q(綺),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(绽),
					result  => q(綻),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(绰),
					result  => q(綽),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(绫),
					result  => q(綾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(绵),
					result  => q(綿),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(绲),
					result  => q(緄),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(缁),
					result  => q(緇),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(紧),
					result  => q(緊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(绯),
					result  => q(緋),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(绪),
					result  => q(緒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(绬),
					result  => q(緓),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(缃),
					result  => q(緗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(缄),
					result  => q(緘),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(缂),
					result  => q(緙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(缉),
					result  => q(緝),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(缎),
					result  => q(緞),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(缔),
					result  => q(締),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(缗),
					result  => q(緡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(缘),
					result  => q(緣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(缌),
					result  => q(緦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(编),
					result  => q(編),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(缓),
					result  => q(緩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(缅),
					result  => q(緬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(纬),
					result  => q(緯),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(缑),
					result  => q(緱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(缈),
					result  => q(緲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(缏),
					result  => q(緶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(缇),
					result  => q(緹),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(萦),
					result  => q(縈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(缙),
					result  => q(縉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(缢),
					result  => q(縊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(缒),
					result  => q(縋),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(缣),
					result  => q(縑),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(缊),
					result  => q(縕),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(缞),
					result  => q(縗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(缚),
					result  => q(縛),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(缜),
					result  => q(縝),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(缟),
					result  => q(縞),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(缛),
					result  => q(縟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(县),
					result  => q(縣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(缝),
					result  => q(縫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(缡),
					result  => q(縭),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(缩),
					result  => q(縮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(纵),
					result  => q(縱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(缧),
					result  => q(縲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(䌸),
					result  => q(縳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(缦),
					result  => q(縵),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(絷),
					result  => q(縶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(缥),
					result  => q(縹),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(总),
					result  => q(總),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(绩),
					result  => q(績),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(缫),
					result  => q(繅),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(缪),
					result  => q(繆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(缯),
					result  => q(繒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(织),
					result  => q(織),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(缮),
					result  => q(繕),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(缭),
					result  => q(繚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(绕),
					result  => q(繞),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(缋),
					result  => q(繢),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(绳),
					result  => q(繩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(绘),
					result  => q(繪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(茧),
					result  => q(繭),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(缳),
					result  => q(繯),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(缲),
					result  => q(繰),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(缴),
					result  => q(繳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(䍁),
					result  => q(繸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(绎),
					result  => q(繹),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(继),
					result  => q(繼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(缤),
					result  => q(繽),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(缱),
					result  => q(繾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(䍀),
					result  => q(繿),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(缬),
					result  => q(纈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(纩),
					result  => q(纊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(续),
					result  => q(續),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(缠),
					result  => q(纏),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(缨),
					result  => q(纓),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(缵),
					result  => q(纘),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(缆),
					result  => q(纜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(罂),
					result  => q(罌),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(罚),
					result  => q(罰),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(罢),
					result  => q(罷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(罗),
					result  => q(羅),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(罴),
					result  => q(羆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(羁),
					result  => q(羈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(芈),
					result  => q(羋),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(羟),
					result  => q(羥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(义),
					result  => q(義),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(习),
					result  => q(習),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(翘),
					result  => q(翹),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(耧),
					result  => q(耬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(耢),
					result  => q(耮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(圣),
					result  => q(聖),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(闻),
					result  => q(聞),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(联),
					result  => q(聯),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(聪),
					result  => q(聰),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(声),
					result  => q(聲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(耸),
					result  => q(聳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(聩),
					result  => q(聵),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(聂),
					result  => q(聶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(职),
					result  => q(職),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(聍),
					result  => q(聹),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(听),
					result  => q(聽),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(聋),
					result  => q(聾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(肃),
					result  => q(肅),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(胁),
					result  => q(脅),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(脉),
					result  => q(脈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(胫),
					result  => q(脛),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(脱),
					result  => q(脫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(胀),
					result  => q(脹),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(肾),
					result  => q(腎),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(胨),
					result  => q(腖),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(脶),
					result  => q(腡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(脑),
					result  => q(腦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(肿),
					result  => q(腫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(脚),
					result  => q(腳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(肠),
					result  => q(腸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(腽),
					result  => q(膃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(肤),
					result  => q(膚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(胶),
					result  => q(膠),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(腻),
					result  => q(膩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(胆),
					result  => q(膽),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(脍),
					result  => q(膾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(脓),
					result  => q(膿),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(脸),
					result  => q(臉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(脐),
					result  => q(臍),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(膑),
					result  => q(臏),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(胪),
					result  => q(臚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(脔),
					result  => q(臠),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(臜),
					result  => q(臢),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(临),
					result  => q(臨),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(与),
					result  => q(與),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(兴),
					result  => q(興),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(举),
					result  => q(舉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(旧),
					result  => q(舊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(舱),
					result  => q(艙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(舣),
					result  => q(艤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(舰),
					result  => q(艦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(舻),
					result  => q(艫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(艰),
					result  => q(艱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(刍),
					result  => q(芻),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(苎),
					result  => q(苧),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(兹),
					result  => q(茲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(荆),
					result  => q(荊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(庄),
					result  => q(莊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(茎),
					result  => q(莖),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(荚),
					result  => q(莢),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(苋),
					result  => q(莧),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(华),
					result  => q(華),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(苌),
					result  => q(萇),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(莱),
					result  => q(萊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(莴),
					result  => q(萵),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(荭),
					result  => q(葒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(荮),
					result  => q(葤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(苇),
					result  => q(葦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(荤),
					result  => q(葷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(莳),
					result  => q(蒔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(莅),
					result  => q(蒞),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(苍),
					result  => q(蒼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(荪),
					result  => q(蓀),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(盖),
					result  => q(蓋),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(莲),
					result  => q(蓮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(苁),
					result  => q(蓯),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(荜),
					result  => q(蓽),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(蒌),
					result  => q(蔞),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(蒋),
					result  => q(蔣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(葱),
					result  => q(蔥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(茑),
					result  => q(蔦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(荫),
					result  => q(蔭),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(荨),
					result  => q(蕁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(蒇),
					result  => q(蕆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(荞),
					result  => q(蕎),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(荬),
					result  => q(蕒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(莸),
					result  => q(蕕),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(荛),
					result  => q(蕘),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(蒉),
					result  => q(蕢),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(芜),
					result  => q(蕪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(萧),
					result  => q(蕭),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(蓣),
					result  => q(蕷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(蕰),
					result  => q(薀),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(荟),
					result  => q(薈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(蓟),
					result  => q(薊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(芗),
					result  => q(薌),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(蔷),
					result  => q(薔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(荙),
					result  => q(薘),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(莶),
					result  => q(薟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(荐),
					result  => q(薦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(萨),
					result  => q(薩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(䓕),
					result  => q(薳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(荠),
					result  => q(薺),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(荩),
					result  => q(藎),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(艺),
					result  => q(藝),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(薮),
					result  => q(藪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(苈),
					result  => q(藶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(蔼),
					result  => q(藹),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(蔺),
					result  => q(藺),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(蕲),
					result  => q(蘄),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(芦),
					result  => q(蘆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(苏),
					result  => q(蘇),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(藓),
					result  => q(蘚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(蔹),
					result  => q(蘞),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(茏),
					result  => q(蘢),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(兰),
					result  => q(蘭),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(蓠),
					result  => q(蘺),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(萝),
					result  => q(蘿),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(蔂),
					result  => q(虆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(处),
					result  => q(處),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(虚),
					result  => q(虛),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(虏),
					result  => q(虜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(号),
					result  => q(號),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(亏),
					result  => q(虧),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(虬),
					result  => q(虯),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(蛱),
					result  => q(蛺),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(蜕),
					result  => q(蛻),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(蚬),
					result  => q(蜆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(蚀),
					result  => q(蝕),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(猬),
					result  => q(蝟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(虾),
					result  => q(蝦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(蜗),
					result  => q(蝸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(蛳),
					result  => q(螄),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(蚂),
					result  => q(螞),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(䗖),
					result  => q(螮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(蝼),
					result  => q(螻),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(螀),
					result  => q(螿),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(蛰),
					result  => q(蟄),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(蝈),
					result  => q(蟈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(螨),
					result  => q(蟎),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(虮),
					result  => q(蟣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(蝉),
					result  => q(蟬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(蛲),
					result  => q(蟯),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(虫),
					result  => q(蟲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(蛏),
					result  => q(蟶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(蚁),
					result  => q(蟻),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(蝇),
					result  => q(蠅),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(虿),
					result  => q(蠆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(蛴),
					result  => q(蠐),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(蝾),
					result  => q(蠑),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(蛎),
					result  => q(蠣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(蟏),
					result  => q(蠨),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(蛊),
					result  => q(蠱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(蚕),
					result  => q(蠶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(蛮),
					result  => q(蠻),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(术),
					result  => q(術),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(卫),
					result  => q(衛),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(衮),
					result  => q(袞),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(补),
					result  => q(補),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(装),
					result  => q(裝),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(裈),
					result  => q(褌),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(袆),
					result  => q(褘),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(裤),
					result  => q(褲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(裢),
					result  => q(褳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(亵),
					result  => q(褻),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(裥),
					result  => q(襇),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(袯),
					result  => q(襏),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(袄),
					result  => q(襖),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(裣),
					result  => q(襝),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(裆),
					result  => q(襠),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(袜),
					result  => q(襪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(䙓),
					result  => q(襬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(衬),
					result  => q(襯),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(袭),
					result  => q(襲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(见),
					result  => q(見),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(觃),
					result  => q(覎),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(规),
					result  => q(規),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(觅),
					result  => q(覓),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(视),
					result  => q(視),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(觇),
					result  => q(覘),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(觋),
					result  => q(覡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(觍),
					result  => q(覥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(觎),
					result  => q(覦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(亲),
					result  => q(親),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(觊),
					result  => q(覬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(觏),
					result  => q(覯),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(觐),
					result  => q(覲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(觑),
					result  => q(覷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(觉),
					result  => q(覺),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(览),
					result  => q(覽),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(觌),
					result  => q(覿),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(观),
					result  => q(觀),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(觞),
					result  => q(觴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(觯),
					result  => q(觶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(触),
					result  => q(觸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(讠),
					result  => q(訁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(订),
					result  => q(訂),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(讣),
					result  => q(訃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(计),
					result  => q(計),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(讯),
					result  => q(訊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(讧),
					result  => q(訌),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(讨),
					result  => q(討),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(讦),
					result  => q(訐),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(讱),
					result  => q(訒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(训),
					result  => q(訓),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(讪),
					result  => q(訕),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(讫),
					result  => q(訖),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(记),
					result  => q(記),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(讹),
					result  => q(訛),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(讶),
					result  => q(訝),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(讼),
					result  => q(訟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(䜣),
					result  => q(訢),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(诀),
					result  => q(訣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(讷),
					result  => q(訥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(讻),
					result  => q(訩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(访),
					result  => q(訪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(设),
					result  => q(設),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(许),
					result  => q(許),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(诉),
					result  => q(訴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(诃),
					result  => q(訶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(诊),
					result  => q(診),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(诂),
					result  => q(詁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(诋),
					result  => q(詆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(讵),
					result  => q(詎),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(诈),
					result  => q(詐),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(诒),
					result  => q(詒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(诏),
					result  => q(詔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(评),
					result  => q(評),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(诐),
					result  => q(詖),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(诇),
					result  => q(詗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(诎),
					result  => q(詘),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(诅),
					result  => q(詛),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(诩),
					result  => q(詡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(询),
					result  => q(詢),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(诣),
					result  => q(詣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(试),
					result  => q(試),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(诗),
					result  => q(詩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(诧),
					result  => q(詫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(诟),
					result  => q(詬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(诡),
					result  => q(詭),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(诠),
					result  => q(詮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(诘),
					result  => q(詰),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(话),
					result  => q(話),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(该),
					result  => q(該),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(详),
					result  => q(詳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(诜),
					result  => q(詵),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(诙),
					result  => q(詼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(诖),
					result  => q(詿),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(诔),
					result  => q(誄),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(诛),
					result  => q(誅),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(诓),
					result  => q(誆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(夸),
					result  => q(誇),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(认),
					result  => q(認),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(诳),
					result  => q(誑),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(诶),
					result  => q(誒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(诞),
					result  => q(誕),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(诱),
					result  => q(誘),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(诮),
					result  => q(誚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(语),
					result  => q(語),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(诚),
					result  => q(誠),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(诫),
					result  => q(誡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(诬),
					result  => q(誣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(误),
					result  => q(誤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(诰),
					result  => q(誥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(诵),
					result  => q(誦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(诲),
					result  => q(誨),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(谁),
					result  => q(誰),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(课),
					result  => q(課),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(谇),
					result  => q(誶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(诽),
					result  => q(誹),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(谊),
					result  => q(誼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(訚),
					result  => q(誾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(调),
					result  => q(調),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(谄),
					result  => q(諂),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(谆),
					result  => q(諄),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(谈),
					result  => q(談),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(诿),
					result  => q(諉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(请),
					result  => q(請),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(诤),
					result  => q(諍),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(诹),
					result  => q(諏),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(诼),
					result  => q(諑),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(谅),
					result  => q(諒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(论),
					result  => q(論),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(谂),
					result  => q(諗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(谀),
					result  => q(諛),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(谍),
					result  => q(諜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(谞),
					result  => q(諝),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(谝),
					result  => q(諞),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(诨),
					result  => q(諢),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(谔),
					result  => q(諤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(谛),
					result  => q(諦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(谐),
					result  => q(諧),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(谏),
					result  => q(諫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(谕),
					result  => q(諭),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(讳),
					result  => q(諱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(谙),
					result  => q(諳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(谌),
					result  => q(諶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(讽),
					result  => q(諷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(诸),
					result  => q(諸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(谚),
					result  => q(諺),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(谖),
					result  => q(諼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(诺),
					result  => q(諾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(谋),
					result  => q(謀),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(谒),
					result  => q(謁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(谓),
					result  => q(謂),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(誊),
					result  => q(謄),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(诌),
					result  => q(謅),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(谎),
					result  => q(謊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(谜),
					result  => q(謎),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(谧),
					result  => q(謐),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(谑),
					result  => q(謔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(谡),
					result  => q(謖),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(谤),
					result  => q(謗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(谦),
					result  => q(謙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(讲),
					result  => q(講),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(谢),
					result  => q(謝),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(谟),
					result  => q(謨),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(谪),
					result  => q(謫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(谬),
					result  => q(謬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(讴),
					result  => q(謳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(谨),
					result  => q(謹),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(谩),
					result  => q(謾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(䜧),
					result  => q(譅),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(谲),
					result  => q(譎),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(讥),
					result  => q(譏),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(谮),
					result  => q(譖),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(识),
					result  => q(識),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(谯),
					result  => q(譙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(谭),
					result  => q(譚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(谱),
					result  => q(譜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(谵),
					result  => q(譫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(译),
					result  => q(譯),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(议),
					result  => q(議),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(谴),
					result  => q(譴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(护),
					result  => q(護),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(诪),
					result  => q(譸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(誉),
					result  => q(譽),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(读),
					result  => q(讀),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(变),
					result  => q(變),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(雠),
					result  => q(讎),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(谗),
					result  => q(讒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(让),
					result  => q(讓),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(谰),
					result  => q(讕),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(谶),
					result  => q(讖),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(谠),
					result  => q(讜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(谳),
					result  => q(讞),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(岂),
					result  => q(豈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(猪),
					result  => q(豬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(豮),
					result  => q(豶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(猫),
					result  => q(貓),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(䝙),
					result  => q(貙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(贝),
					result  => q(貝),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(贞),
					result  => q(貞),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(贠),
					result  => q(貟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(负),
					result  => q(負),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(财),
					result  => q(財),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(贡),
					result  => q(貢),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(贫),
					result  => q(貧),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(货),
					result  => q(貨),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(贩),
					result  => q(販),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(贪),
					result  => q(貪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(贯),
					result  => q(貫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(责),
					result  => q(責),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(贮),
					result  => q(貯),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(贳),
					result  => q(貰),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(赀),
					result  => q(貲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(贰),
					result  => q(貳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(贵),
					result  => q(貴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(贬),
					result  => q(貶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(买),
					result  => q(買),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(贷),
					result  => q(貸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(贶),
					result  => q(貺),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(费),
					result  => q(費),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(贴),
					result  => q(貼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(贻),
					result  => q(貽),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(贸),
					result  => q(貿),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(贺),
					result  => q(賀),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(贲),
					result  => q(賁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(赂),
					result  => q(賂),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(赁),
					result  => q(賃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(贿),
					result  => q(賄),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(赅),
					result  => q(賅),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(资),
					result  => q(資),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(贾),
					result  => q(賈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(贼),
					result  => q(賊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(赈),
					result  => q(賑),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(赊),
					result  => q(賒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(宾),
					result  => q(賓),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(赇),
					result  => q(賕),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(赒),
					result  => q(賙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(赉),
					result  => q(賚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(赐),
					result  => q(賜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(赏),
					result  => q(賞),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(赔),
					result  => q(賠),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(赓),
					result  => q(賡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(贤),
					result  => q(賢),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(卖),
					result  => q(賣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(贱),
					result  => q(賤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(赋),
					result  => q(賦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(赕),
					result  => q(賧),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(质),
					result  => q(質),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(账),
					result  => q(賬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(赌),
					result  => q(賭),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(䞐),
					result  => q(賰),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(赖),
					result  => q(賴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(赗),
					result  => q(賵),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(赚),
					result  => q(賺),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(赙),
					result  => q(賻),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(购),
					result  => q(購),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(赛),
					result  => q(賽),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(赜),
					result  => q(賾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(贽),
					result  => q(贄),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(赘),
					result  => q(贅),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(赟),
					result  => q(贇),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(赠),
					result  => q(贈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(赡),
					result  => q(贍),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(赢),
					result  => q(贏),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(赆),
					result  => q(贐),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(赑),
					result  => q(贔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(赎),
					result  => q(贖),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(赣),
					result  => q(贛),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(赪),
					result  => q(赬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(赶),
					result  => q(趕),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(赵),
					result  => q(趙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(趋),
					result  => q(趨),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(趱),
					result  => q(趲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(践),
					result  => q(踐),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(踊),
					result  => q(踴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(跄),
					result  => q(蹌),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(跸),
					result  => q(蹕),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(蹒),
					result  => q(蹣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(踪),
					result  => q(蹤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(跷),
					result  => q(蹺),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(跶),
					result  => q(躂),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(趸),
					result  => q(躉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(踌),
					result  => q(躊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(跻),
					result  => q(躋),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(跃),
					result  => q(躍),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(踯),
					result  => q(躑),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(跞),
					result  => q(躒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(踬),
					result  => q(躓),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(蹰),
					result  => q(躕),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(跹),
					result  => q(躚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(蹑),
					result  => q(躡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(蹿),
					result  => q(躥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(躜),
					result  => q(躦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(躏),
					result  => q(躪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(躯),
					result  => q(軀),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(车),
					result  => q(車),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(轧),
					result  => q(軋),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(轨),
					result  => q(軌),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(军),
					result  => q(軍),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(轪),
					result  => q(軑),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(轩),
					result  => q(軒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(轫),
					result  => q(軔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(轭),
					result  => q(軛),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(软),
					result  => q(軟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(轷),
					result  => q(軤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(轸),
					result  => q(軫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(轱),
					result  => q(軲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(轴),
					result  => q(軸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(轵),
					result  => q(軹),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(轺),
					result  => q(軺),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(轲),
					result  => q(軻),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(轶),
					result  => q(軼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(轼),
					result  => q(軾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(较),
					result  => q(較),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(辂),
					result  => q(輅),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(辁),
					result  => q(輇),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(辀),
					result  => q(輈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(载),
					result  => q(載),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(轾),
					result  => q(輊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(辄),
					result  => q(輒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(挽),
					result  => q(輓),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(辅),
					result  => q(輔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(轻),
					result  => q(輕),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(辆),
					result  => q(輛),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(辎),
					result  => q(輜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(辉),
					result  => q(輝),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(辋),
					result  => q(輞),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(辍),
					result  => q(輟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(辊),
					result  => q(輥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(辇),
					result  => q(輦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(辈),
					result  => q(輩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(轮),
					result  => q(輪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(辌),
					result  => q(輬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(辑),
					result  => q(輯),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(辏),
					result  => q(輳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(输),
					result  => q(輸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(辐),
					result  => q(輻),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(辗),
					result  => q(輾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(舆),
					result  => q(輿),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(辒),
					result  => q(轀),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(毂),
					result  => q(轂),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(辖),
					result  => q(轄),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(辕),
					result  => q(轅),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(辘),
					result  => q(轆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(转),
					result  => q(轉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(辙),
					result  => q(轍),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(轿),
					result  => q(轎),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(辚),
					result  => q(轔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(轰),
					result  => q(轟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(辔),
					result  => q(轡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(轹),
					result  => q(轢),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(轳),
					result  => q(轤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(办),
					result  => q(辦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(辫),
					result  => q(辮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(辩),
					result  => q(辯),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(农),
					result  => q(農),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(迳),
					result  => q(逕),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(这),
					result  => q(這),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(连),
					result  => q(連),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(进),
					result  => q(進),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(运),
					result  => q(運),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(过),
					result  => q(過),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(达),
					result  => q(達),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(违),
					result  => q(違),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(遥),
					result  => q(遙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(逊),
					result  => q(遜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(递),
					result  => q(遞),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(远),
					result  => q(遠),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(适),
					result  => q(適),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(迟),
					result  => q(遲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(迁),
					result  => q(遷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(选),
					result  => q(選),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(遗),
					result  => q(遺),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(辽),
					result  => q(遼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(迈),
					result  => q(邁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(还),
					result  => q(還),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(迩),
					result  => q(邇),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(边),
					result  => q(邊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(逻),
					result  => q(邏),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(逦),
					result  => q(邐),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(郏),
					result  => q(郟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(邮),
					result  => q(郵),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(郓),
					result  => q(鄆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(乡),
					result  => q(鄉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(邹),
					result  => q(鄒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(邬),
					result  => q(鄔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(郧),
					result  => q(鄖),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(邓),
					result  => q(鄧),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(郑),
					result  => q(鄭),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(邻),
					result  => q(鄰),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(郸),
					result  => q(鄲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(邺),
					result  => q(鄴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(郐),
					result  => q(鄶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(邝),
					result  => q(鄺),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(酂),
					result  => q(酇),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(郦),
					result  => q(酈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(医),
					result  => q(醫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(酱),
					result  => q(醬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(酦),
					result  => q(醱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(酿),
					result  => q(釀),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(衅),
					result  => q(釁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(酾),
					result  => q(釃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(酽),
					result  => q(釅),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(释),
					result  => q(釋),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(厘),
					result  => q(釐),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(钅),
					result  => q(釒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(钆),
					result  => q(釓),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(钇),
					result  => q(釔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(钌),
					result  => q(釕),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(钊),
					result  => q(釗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(钉),
					result  => q(釘),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(钋),
					result  => q(釙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(针),
					result  => q(針),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(钓),
					result  => q(釣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(钐),
					result  => q(釤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(钏),
					result  => q(釧),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(钒),
					result  => q(釩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(钗),
					result  => q(釵),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(钍),
					result  => q(釷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(钕),
					result  => q(釹),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(钎),
					result  => q(釺),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(钯),
					result  => q(鈀),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(钫),
					result  => q(鈁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(钘),
					result  => q(鈃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(钭),
					result  => q(鈄),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(钚),
					result  => q(鈈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(钠),
					result  => q(鈉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(钝),
					result  => q(鈍),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(钤),
					result  => q(鈐),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(钣),
					result  => q(鈑),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(钑),
					result  => q(鈒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(钞),
					result  => q(鈔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(钮),
					result  => q(鈕),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(钧),
					result  => q(鈞),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(钙),
					result  => q(鈣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(钬),
					result  => q(鈥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(钛),
					result  => q(鈦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(钪),
					result  => q(鈧),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(铌),
					result  => q(鈮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(铈),
					result  => q(鈰),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(钶),
					result  => q(鈳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(铃),
					result  => q(鈴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(钴),
					result  => q(鈷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(钹),
					result  => q(鈸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(铍),
					result  => q(鈹),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(钰),
					result  => q(鈺),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(钸),
					result  => q(鈽),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(铀),
					result  => q(鈾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(钿),
					result  => q(鈿),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(钾),
					result  => q(鉀),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(铊),
					result  => q(鉈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(铉),
					result  => q(鉉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(铇),
					result  => q(鉋),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(铋),
					result  => q(鉍),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(铂),
					result  => q(鉑),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(钷),
					result  => q(鉕),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(铆),
					result  => q(鉚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(铅),
					result  => q(鉛),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(钺),
					result  => q(鉞),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(钲),
					result  => q(鉦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(钼),
					result  => q(鉬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(钽),
					result  => q(鉭),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(铏),
					result  => q(鉶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(铰),
					result  => q(鉸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(铒),
					result  => q(鉺),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(铬),
					result  => q(鉻),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(铪),
					result  => q(鉿),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(银),
					result  => q(銀),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(铳),
					result  => q(銃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(铜),
					result  => q(銅),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(铚),
					result  => q(銍),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(铣),
					result  => q(銑),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(铨),
					result  => q(銓),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(铢),
					result  => q(銖),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(铭),
					result  => q(銘),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(铫),
					result  => q(銚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(铦),
					result  => q(銛),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(衔),
					result  => q(銜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(铑),
					result  => q(銠),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(铷),
					result  => q(銣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(铱),
					result  => q(銥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(铟),
					result  => q(銦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(铵),
					result  => q(銨),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(铥),
					result  => q(銩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(铕),
					result  => q(銪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(铯),
					result  => q(銫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(铐),
					result  => q(銬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(铞),
					result  => q(銱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(销),
					result  => q(銷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(锑),
					result  => q(銻),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(锉),
					result  => q(銼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(锒),
					result  => q(鋃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(锌),
					result  => q(鋅),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(钡),
					result  => q(鋇),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(铤),
					result  => q(鋌),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(铗),
					result  => q(鋏),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(锋),
					result  => q(鋒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(铻),
					result  => q(鋙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(锊),
					result  => q(鋝),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(锓),
					result  => q(鋟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(铘),
					result  => q(鋣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(锄),
					result  => q(鋤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(锃),
					result  => q(鋥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(锔),
					result  => q(鋦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(锇),
					result  => q(鋨),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(铓),
					result  => q(鋩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(铖),
					result  => q(鋮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(锆),
					result  => q(鋯),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(锂),
					result  => q(鋰),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(铽),
					result  => q(鋱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(锍),
					result  => q(鋶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(锯),
					result  => q(鋸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(钢),
					result  => q(鋼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(锞),
					result  => q(錁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(锖),
					result  => q(錆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(锫),
					result  => q(錇),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(锩),
					result  => q(錈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(铔),
					result  => q(錏),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(锥),
					result  => q(錐),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(锕),
					result  => q(錒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(锟),
					result  => q(錕),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(锱),
					result  => q(錙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(铮),
					result  => q(錚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(锛),
					result  => q(錛),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(锬),
					result  => q(錟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(锭),
					result  => q(錠),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(锜),
					result  => q(錡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(钱),
					result  => q(錢),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(锦),
					result  => q(錦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(锚),
					result  => q(錨),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(锠),
					result  => q(錩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(锡),
					result  => q(錫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(锢),
					result  => q(錮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(错),
					result  => q(錯),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(锰),
					result  => q(錳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(铼),
					result  => q(錸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(锝),
					result  => q(鍀),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(锪),
					result  => q(鍃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(钔),
					result  => q(鍆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(锴),
					result  => q(鍇),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(锳),
					result  => q(鍈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(锅),
					result  => q(鍋),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(镀),
					result  => q(鍍),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(锷),
					result  => q(鍔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(铡),
					result  => q(鍘),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(钖),
					result  => q(鍚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(锻),
					result  => q(鍛),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(锽),
					result  => q(鍠),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(锸),
					result  => q(鍤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(锲),
					result  => q(鍥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(锘),
					result  => q(鍩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(锹),
					result  => q(鍬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(锾),
					result  => q(鍰),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(键),
					result  => q(鍵),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(锶),
					result  => q(鍶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(锗),
					result  => q(鍺),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(镁),
					result  => q(鎂),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(锿),
					result  => q(鎄),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(镅),
					result  => q(鎇),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(镑),
					result  => q(鎊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(锁),
					result  => q(鎖),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(镉),
					result  => q(鎘),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(镈),
					result  => q(鎛),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(镃),
					result  => q(鎡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(钨),
					result  => q(鎢),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(蓥),
					result  => q(鎣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(镏),
					result  => q(鎦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(铠),
					result  => q(鎧),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(铩),
					result  => q(鎩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(锼),
					result  => q(鎪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(镐),
					result  => q(鎬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(镇),
					result  => q(鎮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(镒),
					result  => q(鎰),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(镋),
					result  => q(鎲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(镍),
					result  => q(鎳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(镓),
					result  => q(鎵),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(镎),
					result  => q(鎿),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(镞),
					result  => q(鏃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(镟),
					result  => q(鏇),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(镆),
					result  => q(鏌),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(镙),
					result  => q(鏍),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(镠),
					result  => q(鏐),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(镝),
					result  => q(鏑),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(铿),
					result  => q(鏗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(锵),
					result  => q(鏘),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(镗),
					result  => q(鏜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(镘),
					result  => q(鏝),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(镛),
					result  => q(鏞),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(镜),
					result  => q(鏡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(镖),
					result  => q(鏢),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(镂),
					result  => q(鏤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(錾),
					result  => q(鏨),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(镚),
					result  => q(鏰),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(铧),
					result  => q(鏵),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(镤),
					result  => q(鏷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(镪),
					result  => q(鏹),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(铙),
					result  => q(鐃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(铴),
					result  => q(鐋),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(镣),
					result  => q(鐐),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(铹),
					result  => q(鐒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(镦),
					result  => q(鐓),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(镡),
					result  => q(鐔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(镫),
					result  => q(鐙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(镨),
					result  => q(鐠),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(锎),
					result  => q(鐦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(锏),
					result  => q(鐧),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(镄),
					result  => q(鐨),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(镰),
					result  => q(鐮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(镯),
					result  => q(鐲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(镭),
					result  => q(鐳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(铁),
					result  => q(鐵),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(镮),
					result  => q(鐶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(铎),
					result  => q(鐸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(铛),
					result  => q(鐺),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(镱),
					result  => q(鐿),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(铸),
					result  => q(鑄),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(镬),
					result  => q(鑊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(镔),
					result  => q(鑌),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(镲),
					result  => q(鑔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(锧),
					result  => q(鑕),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(镴),
					result  => q(鑞),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(铄),
					result  => q(鑠),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(镳),
					result  => q(鑣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(镥),
					result  => q(鑥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(镧),
					result  => q(鑭),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(钥),
					result  => q(鑰),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(镵),
					result  => q(鑱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(镶),
					result  => q(鑲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(镊),
					result  => q(鑷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(镩),
					result  => q(鑹),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(锣),
					result  => q(鑼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(钻),
					result  => q(鑽),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(銮),
					result  => q(鑾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(凿),
					result  => q(鑿),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(长),
					result  => q(長),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(门),
					result  => q(門),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(闩),
					result  => q(閂),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(闪),
					result  => q(閃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(闫),
					result  => q(閆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(闬),
					result  => q(閈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(闭),
					result  => q(閉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(开),
					result  => q(開),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(闶),
					result  => q(閌),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(闳),
					result  => q(閎),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(闰),
					result  => q(閏),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(间),
					result  => q(間),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(闵),
					result  => q(閔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(闸),
					result  => q(閘),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(阂),
					result  => q(閡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(阁),
					result  => q(閣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(阀),
					result  => q(閥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(闺),
					result  => q(閨),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(闽),
					result  => q(閩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(阃),
					result  => q(閫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(阆),
					result  => q(閬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(闾),
					result  => q(閭),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(阊),
					result  => q(閶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(阉),
					result  => q(閹),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(阎),
					result  => q(閻),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(阏),
					result  => q(閼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(阍),
					result  => q(閽),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(阈),
					result  => q(閾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(阌),
					result  => q(閿),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(阒),
					result  => q(闃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(闱),
					result  => q(闈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(阔),
					result  => q(闊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(阕),
					result  => q(闋),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(阑),
					result  => q(闌),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(阇),
					result  => q(闍),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(阗),
					result  => q(闐),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(阘),
					result  => q(闒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(闿),
					result  => q(闓),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(阖),
					result  => q(闔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(阙),
					result  => q(闕),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(闯),
					result  => q(闖),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(阚),
					result  => q(闞),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(阓),
					result  => q(闠),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(阐),
					result  => q(闡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(阛),
					result  => q(闤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(闼),
					result  => q(闥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(坂),
					result  => q(阪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(陉),
					result  => q(陘),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(陕),
					result  => q(陝),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(阵),
					result  => q(陣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(阴),
					result  => q(陰),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(陈),
					result  => q(陳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(陆),
					result  => q(陸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(阳),
					result  => q(陽),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(陧),
					result  => q(隉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(队),
					result  => q(隊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(阶),
					result  => q(階),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(陨),
					result  => q(隕),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(际),
					result  => q(際),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(随),
					result  => q(隨),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(险),
					result  => q(險),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(隐),
					result  => q(隱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(陇),
					result  => q(隴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(隶),
					result  => q(隸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(隽),
					result  => q(雋),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(虽),
					result  => q(雖),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(双),
					result  => q(雙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(雏),
					result  => q(雛),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(杂),
					result  => q(雜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(离),
					result  => q(離),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(难),
					result  => q(難),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(电),
					result  => q(電),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(霡),
					result  => q(霢),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(雾),
					result  => q(霧),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(霁),
					result  => q(霽),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(雳),
					result  => q(靂),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(霭),
					result  => q(靄),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(灵),
					result  => q(靈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(靓),
					result  => q(靚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(静),
					result  => q(靜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(靥),
					result  => q(靨),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鼗),
					result  => q(鞀),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(巩),
					result  => q(鞏),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鞒),
					result  => q(鞽),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鞑),
					result  => q(韃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鞯),
					result  => q(韉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(韦),
					result  => q(韋),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(韧),
					result  => q(韌),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(韨),
					result  => q(韍),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(韩),
					result  => q(韓),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(韪),
					result  => q(韙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(韬),
					result  => q(韜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(韫),
					result  => q(韞),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(韵),
					result  => q(韻),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(响),
					result  => q(響),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(页),
					result  => q(頁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(顶),
					result  => q(頂),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(顷),
					result  => q(頃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(项),
					result  => q(項),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(顺),
					result  => q(順),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(顸),
					result  => q(頇),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(顼),
					result  => q(頊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(颂),
					result  => q(頌),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(颀),
					result  => q(頎),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(颃),
					result  => q(頏),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(预),
					result  => q(預),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(顽),
					result  => q(頑),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(颁),
					result  => q(頒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(顿),
					result  => q(頓),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(颇),
					result  => q(頗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(领),
					result  => q(領),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(颌),
					result  => q(頜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(颉),
					result  => q(頡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(颐),
					result  => q(頤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(颏),
					result  => q(頦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(头),
					result  => q(頭),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(颒),
					result  => q(頮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(颊),
					result  => q(頰),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(颋),
					result  => q(頲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(颕),
					result  => q(頴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(颔),
					result  => q(頷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(颈),
					result  => q(頸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(频),
					result  => q(頻),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(颗),
					result  => q(顆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(题),
					result  => q(題),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(额),
					result  => q(額),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(颚),
					result  => q(顎),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(颙),
					result  => q(顒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(颛),
					result  => q(顓),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(颡),
					result  => q(顙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(颠),
					result  => q(顛),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(类),
					result  => q(類),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(颟),
					result  => q(顢),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(颢),
					result  => q(顥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(顾),
					result  => q(顧),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(颤),
					result  => q(顫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(颥),
					result  => q(顬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(显),
					result  => q(顯),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(颦),
					result  => q(顰),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(颅),
					result  => q(顱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(颞),
					result  => q(顳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(颧),
					result  => q(顴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(风),
					result  => q(風),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(飐),
					result  => q(颭),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(飑),
					result  => q(颮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(飒),
					result  => q(颯),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(飓),
					result  => q(颶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(飔),
					result  => q(颸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(飖),
					result  => q(颻),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(飕),
					result  => q(颼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(飗),
					result  => q(飀),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(飘),
					result  => q(飄),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(飙),
					result  => q(飆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(飚),
					result  => q(飈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(飞),
					result  => q(飛),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(饣),
					result  => q(飠),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(饤),
					result  => q(飣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(饦),
					result  => q(飥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(饨),
					result  => q(飩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(饪),
					result  => q(飪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(饫),
					result  => q(飫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(饬),
					result  => q(飭),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(饭),
					result  => q(飯),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(饮),
					result  => q(飲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(饴),
					result  => q(飴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(饲),
					result  => q(飼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(饱),
					result  => q(飽),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(饰),
					result  => q(飾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(饳),
					result  => q(飿),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(饺),
					result  => q(餃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(饸),
					result  => q(餄),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(饼),
					result  => q(餅),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(饷),
					result  => q(餉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(养),
					result  => q(養),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(饵),
					result  => q(餌),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(饹),
					result  => q(餎),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(饻),
					result  => q(餏),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(饽),
					result  => q(餑),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(馁),
					result  => q(餒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(饿),
					result  => q(餓),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(馂),
					result  => q(餕),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(饾),
					result  => q(餖),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(馄),
					result  => q(餛),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(馃),
					result  => q(餜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(饯),
					result  => q(餞),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(馅),
					result  => q(餡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(馆),
					result  => q(館),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(糇),
					result  => q(餱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(饧),
					result  => q(餳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(馉),
					result  => q(餶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(馇),
					result  => q(餷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(馎),
					result  => q(餺),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(饩),
					result  => q(餼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(馏),
					result  => q(餾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(馊),
					result  => q(餿),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(馌),
					result  => q(饁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(馍),
					result  => q(饃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(馒),
					result  => q(饅),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(馐),
					result  => q(饈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(馑),
					result  => q(饉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(馓),
					result  => q(饊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(馔),
					result  => q(饌),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(饶),
					result  => q(饒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(飨),
					result  => q(饗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(餍),
					result  => q(饜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(馋),
					result  => q(饞),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(馕),
					result  => q(饢),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(马),
					result  => q(馬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(驭),
					result  => q(馭),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(冯),
					result  => q(馮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(驮),
					result  => q(馱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(驰),
					result  => q(馳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(驯),
					result  => q(馴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(驲),
					result  => q(馹),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(驳),
					result  => q(駁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(驻),
					result  => q(駐),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(驽),
					result  => q(駑),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(驹),
					result  => q(駒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(驵),
					result  => q(駔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(驾),
					result  => q(駕),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(骀),
					result  => q(駘),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(驸),
					result  => q(駙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(驶),
					result  => q(駛),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(驼),
					result  => q(駝),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(驷),
					result  => q(駟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(骈),
					result  => q(駢),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(骇),
					result  => q(駭),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(骃),
					result  => q(駰),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(骆),
					result  => q(駱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(骎),
					result  => q(駸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(骏),
					result  => q(駿),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(骋),
					result  => q(騁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(骍),
					result  => q(騂),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(骓),
					result  => q(騅),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(骔),
					result  => q(騌),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(骒),
					result  => q(騍),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(骑),
					result  => q(騎),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(骐),
					result  => q(騏),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(骛),
					result  => q(騖),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(骗),
					result  => q(騙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(骙),
					result  => q(騤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(䯄),
					result  => q(騧),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(骞),
					result  => q(騫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(骘),
					result  => q(騭),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(骝),
					result  => q(騮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(腾),
					result  => q(騰),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(驺),
					result  => q(騶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(骚),
					result  => q(騷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(骟),
					result  => q(騸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(骡),
					result  => q(騾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(蓦),
					result  => q(驀),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(骜),
					result  => q(驁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(骖),
					result  => q(驂),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(骠),
					result  => q(驃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(骢),
					result  => q(驄),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(驱),
					result  => q(驅),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(骅),
					result  => q(驊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(骕),
					result  => q(驌),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(骁),
					result  => q(驍),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(骣),
					result  => q(驏),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(骄),
					result  => q(驕),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(验),
					result  => q(驗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(惊),
					result  => q(驚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(驿),
					result  => q(驛),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(骤),
					result  => q(驟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(驴),
					result  => q(驢),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(骧),
					result  => q(驤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(骥),
					result  => q(驥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(骦),
					result  => q(驦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(骊),
					result  => q(驪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(骉),
					result  => q(驫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(肮),
					result  => q(骯),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(髅),
					result  => q(髏),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(体),
					result  => q(體),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(髌),
					result  => q(髕),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(髋),
					result  => q(髖),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鬓),
					result  => q(鬢),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(闹),
					result  => q(鬧),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(阋),
					result  => q(鬩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(阄),
					result  => q(鬮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(魉),
					result  => q(魎),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(魇),
					result  => q(魘),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鱼),
					result  => q(魚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鱽),
					result  => q(魛),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鱾),
					result  => q(魢),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鲀),
					result  => q(魨),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鲁),
					result  => q(魯),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鲂),
					result  => q(魴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鱿),
					result  => q(魷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鲄),
					result  => q(魺),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鲅),
					result  => q(鮁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鲆),
					result  => q(鮃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鲌),
					result  => q(鮊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鲉),
					result  => q(鮋),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鲏),
					result  => q(鮍),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鲐),
					result  => q(鮐),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鲍),
					result  => q(鮑),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鲋),
					result  => q(鮒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鲊),
					result  => q(鮓),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鲒),
					result  => q(鮚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鲘),
					result  => q(鮜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鲕),
					result  => q(鮞),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鲖),
					result  => q(鮦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鲔),
					result  => q(鮪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鲛),
					result  => q(鮫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鲑),
					result  => q(鮭),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鲜),
					result  => q(鮮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鲓),
					result  => q(鮳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鲪),
					result  => q(鮶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鲝),
					result  => q(鮺),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鲧),
					result  => q(鯀),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鲠),
					result  => q(鯁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鲩),
					result  => q(鯇),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鲤),
					result  => q(鯉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鲨),
					result  => q(鯊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鲬),
					result  => q(鯒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鲻),
					result  => q(鯔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鲯),
					result  => q(鯕),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鲭),
					result  => q(鯖),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鲷),
					result  => q(鯛),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鲴),
					result  => q(鯝),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鲱),
					result  => q(鯡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鲵),
					result  => q(鯢),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鲲),
					result  => q(鯤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鲳),
					result  => q(鯧),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鲸),
					result  => q(鯨),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鲮),
					result  => q(鯪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鲰),
					result  => q(鯫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鲶),
					result  => q(鯰),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鲺),
					result  => q(鯴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鳀),
					result  => q(鯷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鲫),
					result  => q(鯽),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鳊),
					result  => q(鯿),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鳈),
					result  => q(鰁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鲗),
					result  => q(鰂),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鳂),
					result  => q(鰃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鲽),
					result  => q(鰈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鳇),
					result  => q(鰉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鳅),
					result  => q(鰍),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鲾),
					result  => q(鰏),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鳆),
					result  => q(鰒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鳃),
					result  => q(鰓),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鳒),
					result  => q(鰜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鳑),
					result  => q(鰟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鳋),
					result  => q(鰠),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鲥),
					result  => q(鰣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鳏),
					result  => q(鰥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鳎),
					result  => q(鰨),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鳐),
					result  => q(鰩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鳍),
					result  => q(鰭),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鳁),
					result  => q(鰮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鲢),
					result  => q(鰱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鳓),
					result  => q(鰳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鳘),
					result  => q(鰵),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鲦),
					result  => q(鰷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鲣),
					result  => q(鰹),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鲹),
					result  => q(鰺),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鳗),
					result  => q(鰻),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鳛),
					result  => q(鰼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鳔),
					result  => q(鰾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鳉),
					result  => q(鱂),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鳙),
					result  => q(鱅),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鳕),
					result  => q(鱈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鳟),
					result  => q(鱒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鳝),
					result  => q(鱔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鳜),
					result  => q(鱖),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鳞),
					result  => q(鱗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鲟),
					result  => q(鱘),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鲼),
					result  => q(鱝),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鲎),
					result  => q(鱟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鲙),
					result  => q(鱠),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鳣),
					result  => q(鱣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鳡),
					result  => q(鱤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鳢),
					result  => q(鱧),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鲿),
					result  => q(鱨),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鲚),
					result  => q(鱭),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鳠),
					result  => q(鱯),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鲈),
					result  => q(鱸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鲡),
					result  => q(鱺),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鸟),
					result  => q(鳥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鸠),
					result  => q(鳩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鸤),
					result  => q(鳲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(凤),
					result  => q(鳳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鸣),
					result  => q(鳴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鸢),
					result  => q(鳶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(䴓),
					result  => q(鳾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鸩),
					result  => q(鴆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鸨),
					result  => q(鴇),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鸦),
					result  => q(鴉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鸰),
					result  => q(鴒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鸵),
					result  => q(鴕),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鸳),
					result  => q(鴛),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鸲),
					result  => q(鴝),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鸮),
					result  => q(鴞),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鸱),
					result  => q(鴟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鸪),
					result  => q(鴣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鸯),
					result  => q(鴦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鸭),
					result  => q(鴨),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鸸),
					result  => q(鴯),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鸹),
					result  => q(鴰),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鸻),
					result  => q(鴴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(䴕),
					result  => q(鴷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鸿),
					result  => q(鴻),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鸽),
					result  => q(鴿),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(䴔),
					result  => q(鵁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鸺),
					result  => q(鵂),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鸼),
					result  => q(鵃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鹀),
					result  => q(鵐),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鹃),
					result  => q(鵑),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鹆),
					result  => q(鵒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鹁),
					result  => q(鵓),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鹈),
					result  => q(鵜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鹅),
					result  => q(鵝),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鹄),
					result  => q(鵠),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鹉),
					result  => q(鵡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鹌),
					result  => q(鵪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鹏),
					result  => q(鵬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鹐),
					result  => q(鵮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鹎),
					result  => q(鵯),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鹊),
					result  => q(鵲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鹓),
					result  => q(鵷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鹍),
					result  => q(鵾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(䴖),
					result  => q(鶄),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鸫),
					result  => q(鶇),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鹑),
					result  => q(鶉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鹒),
					result  => q(鶊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鹋),
					result  => q(鶓),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鹙),
					result  => q(鶖),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鹕),
					result  => q(鶘),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鹗),
					result  => q(鶚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鹖),
					result  => q(鶡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鹛),
					result  => q(鶥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鹜),
					result  => q(鶩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(䴗),
					result  => q(鶪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鸧),
					result  => q(鶬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(莺),
					result  => q(鶯),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鹟),
					result  => q(鶲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鹤),
					result  => q(鶴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鹠),
					result  => q(鶹),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鹡),
					result  => q(鶺),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鹘),
					result  => q(鶻),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鹣),
					result  => q(鶼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鹢),
					result  => q(鷁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鹞),
					result  => q(鷂),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(䴘),
					result  => q(鷈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鹝),
					result  => q(鷊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鹧),
					result  => q(鷓),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鹥),
					result  => q(鷖),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鸥),
					result  => q(鷗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鸷),
					result  => q(鷙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鹨),
					result  => q(鷚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鸶),
					result  => q(鷥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鹪),
					result  => q(鷦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鹔),
					result  => q(鷫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鹩),
					result  => q(鷯),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鹫),
					result  => q(鷲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鹇),
					result  => q(鷳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鹬),
					result  => q(鷸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鹰),
					result  => q(鷹),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鹭),
					result  => q(鷺),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鸴),
					result  => q(鷽),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(䴙),
					result  => q(鷿),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(㶉),
					result  => q(鸂),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鹯),
					result  => q(鸇),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鹱),
					result  => q(鸌),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鹲),
					result  => q(鸏),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鸬),
					result  => q(鸕),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鹴),
					result  => q(鸘),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鹦),
					result  => q(鸚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鹳),
					result  => q(鸛),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鹂),
					result  => q(鸝),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鸾),
					result  => q(鸞),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鹾),
					result  => q(鹺),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(碱),
					result  => q(鹼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(盐),
					result  => q(鹽),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(丽),
					result  => q(麗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(麦),
					result  => q(麥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(麸),
					result  => q(麩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(黄),
					result  => q(黃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(黉),
					result  => q(黌),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(点),
					result  => q(點),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(党),
					result  => q(黨),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(黪),
					result  => q(黲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(黡),
					result  => q(黶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(黩),
					result  => q(黷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(黾),
					result  => q(黽),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鼋),
					result  => q(黿),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鼍),
					result  => q(鼉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(鼹),
					result  => q(鼴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(齐),
					result  => q(齊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(斋),
					result  => q(齋),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(齑),
					result  => q(齏),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(齿),
					result  => q(齒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(龀),
					result  => q(齔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(龁),
					result  => q(齕),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(龂),
					result  => q(齗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(龅),
					result  => q(齙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(龇),
					result  => q(齜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(龃),
					result  => q(齟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(龆),
					result  => q(齠),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(龄),
					result  => q(齡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(龈),
					result  => q(齦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(龊),
					result  => q(齪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(龉),
					result  => q(齬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(龋),
					result  => q(齲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(腭),
					result  => q(齶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(龌),
					result  => q(齷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(龙),
					result  => q(龍),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(厐),
					result  => q(龎),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(庞),
					result  => q(龐),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(龚),
					result  => q(龔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(龛),
					result  => q(龕),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(龟),
					result  => q(龜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(“),
					result  => q(「),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(”),
					result  => q(」),
					revisit => 0,
				},
			]
		},
	] },
);

no Moo;

1;

# vim: tabstop=4
